#!/usr/bin/env python
# SPDX-License-Identifier: AGPL-3.0-or-later
# lint: pylint
# pyright: basic
"""WebbApp

"""
# pylint: disable=use-dict-literal

import hashlib
import hmac
import json
import os
import sys
import base64
import requests
import markdown
import re
import datetime

from timeit import default_timer
from html import escape
from io import StringIO
import typing
from typing import List, Dict, Iterable

import urllib
import urllib.parse
from urllib.parse import urlencode, unquote

import httpx

from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters import HtmlFormatter  # pylint: disable=no-name-in-module

import flask

from flask import (
    Flask,
    render_template,
    url_for,
    make_response,
    redirect,
    send_from_directory,
)
from flask.wrappers import Response
from flask.json import jsonify

from flask_babel import (
    Babel,
    gettext,
    format_decimal,
)

from searx import (
    logger,
    get_setting,
    settings,
    searx_debug,
)

from searx import infopage
from searx.data import ENGINE_DESCRIPTIONS
from searx.results import Timing, UnresponsiveEngine
from searx.settings_defaults import OUTPUT_FORMATS
from searx.settings_loader import get_default_settings_path
from searx.exceptions import SearxParameterException
from searx.engines import (
    OTHER_CATEGORY,
    categories,
    engines,
    engine_shortcuts,
)
from searx.webutils import (
    UnicodeWriter,
    highlight_content,
    get_static_files,
    get_result_templates,
    get_themes,
    prettify_url,
    new_hmac,
    is_hmac_of,
    is_flask_run_cmdline,
    group_engines_in_tab,
    searxng_l10n_timespan,
)
from searx.webadapter import (
    get_search_query_from_webapp,
    get_selected_categories,
)
from searx.utils import (
    html_to_text,
    gen_useragent,
    dict_subset,
    match_language,
)
from searx.version import VERSION_STRING, GIT_URL, GIT_BRANCH
from searx.query import RawTextQuery
from searx.plugins import Plugin, plugins, initialize as plugin_initialize
from searx.plugins.oa_doi_rewrite import get_doi_resolver
from searx.preferences import (
    Preferences,
    ValidationException,
)
from searx.answerers import (
    answerers,
    ask,
)
from searx.metrics import (
    get_engines_stats,
    get_engine_errors,
    get_reliabilities,
    histogram,
    counter,
)
from searx.flaskfix import patch_application

from searx.locales import (
    LOCALE_NAMES,
    RTL_LOCALES,
    localeselector,
    locales_initialize,
)

# renaming names from searx imports ...
from searx.autocomplete import search_autocomplete, backends as autocomplete_backends
from searx.languages import language_codes as languages
from searx.redisdb import initialize as redis_initialize
from searx.search import SearchWithPlugins, initialize as search_initialize
from searx.network import stream as http_stream, set_context_network_name
from searx.search.checker import get_result as checker_get_result

logger = logger.getChild('webapp')

# check secret_key
if not searx_debug and settings['server']['secret_key'] == 'ultrasecretkey':
    logger.error('server.secret_key is not changed. Please use something else instead of ultrasecretkey.')
    sys.exit(1)

# about static
logger.debug('static directory is %s', settings['ui']['static_path'])
static_files = get_static_files(settings['ui']['static_path'])

# about templates
logger.debug('templates directory is %s', settings['ui']['templates_path'])
default_theme = settings['ui']['default_theme']
templates_path = settings['ui']['templates_path']
themes = get_themes(templates_path)
result_templates = get_result_templates(templates_path)

STATS_SORT_PARAMETERS = {
    'name': (False, 'name', ''),
    'score': (True, 'score_per_result', 0),
    'result_count': (True, 'result_count', 0),
    'time': (False, 'total', 0),
    'reliability': (False, 'reliability', 100),
}

# Flask app
app = Flask(__name__, static_folder=settings['ui']['static_path'], template_folder=templates_path)

app.jinja_env.trim_blocks = True
app.jinja_env.lstrip_blocks = True
app.jinja_env.add_extension('jinja2.ext.loopcontrols')  # pylint: disable=no-member
app.jinja_env.filters['group_engines_in_tab'] = group_engines_in_tab  # pylint: disable=no-member
app.secret_key = settings['server']['secret_key']

timeout_text = gettext('timeout')
parsing_error_text = gettext('parsing error')
http_protocol_error_text = gettext('HTTP protocol error')
network_error_text = gettext('network error')
ssl_cert_error_text = gettext("SSL error: certificate validation has failed")
exception_classname_to_text = {
    None: gettext('unexpected crash'),
    'timeout': timeout_text,
    'asyncio.TimeoutError': timeout_text,
    'httpx.TimeoutException': timeout_text,
    'httpx.ConnectTimeout': timeout_text,
    'httpx.ReadTimeout': timeout_text,
    'httpx.WriteTimeout': timeout_text,
    'httpx.HTTPStatusError': gettext('HTTP error'),
    'httpx.ConnectError': gettext("HTTP connection error"),
    'httpx.RemoteProtocolError': http_protocol_error_text,
    'httpx.LocalProtocolError': http_protocol_error_text,
    'httpx.ProtocolError': http_protocol_error_text,
    'httpx.ReadError': network_error_text,
    'httpx.WriteError': network_error_text,
    'httpx.ProxyError': gettext("proxy error"),
    'searx.exceptions.SearxEngineCaptchaException': gettext("CAPTCHA"),
    'searx.exceptions.SearxEngineTooManyRequestsException': gettext("too many requests"),
    'searx.exceptions.SearxEngineAccessDeniedException': gettext("access denied"),
    'searx.exceptions.SearxEngineAPIException': gettext("server API error"),
    'searx.exceptions.SearxEngineXPathException': parsing_error_text,
    'KeyError': parsing_error_text,
    'json.decoder.JSONDecodeError': parsing_error_text,
    'lxml.etree.ParserError': parsing_error_text,
    'ssl.SSLCertVerificationError': ssl_cert_error_text,  # for Python > 3.7
    'ssl.CertificateError': ssl_cert_error_text,  # for Python 3.7
}


class ExtendedRequest(flask.Request):
    """This class is never initialized and only used for type checking."""

    preferences: Preferences
    errors: List[str]
    user_plugins: List[Plugin]
    form: Dict[str, str]
    start_time: float
    render_time: float
    timings: List[Timing]


request = typing.cast(ExtendedRequest, flask.request)


def get_locale():
    locale = localeselector()
    logger.debug("%s uses locale `%s`", urllib.parse.quote(request.url), locale)
    return locale


babel = Babel(app, locale_selector=get_locale)


def _get_browser_language(req, lang_list):
    for lang in req.headers.get("Accept-Language", "en").split(","):
        if ';' in lang:
            lang = lang.split(';')[0]
        if '-' in lang:
            lang_parts = lang.split('-')
            lang = "{}-{}".format(lang_parts[0], lang_parts[-1].upper())
        locale = match_language(lang, lang_list, fallback=None)
        if locale is not None:
            return locale
    return 'en'


def _get_locale_rfc5646(locale):
    """Get locale name for <html lang="...">
    Chrom* browsers don't detect the language when there is a subtag (ie a territory).
    For example "zh-TW" is detected but not "zh-Hant-TW".
    This function returns a locale without the subtag.
    """
    parts = locale.split('-')
    return parts[0].lower() + '-' + parts[-1].upper()


# code-highlighter
@app.template_filter('code_highlighter')
def code_highlighter(codelines, language=None):
    if not language:
        language = 'text'

    try:
        # find lexer by programming language
        lexer = get_lexer_by_name(language, stripall=True)

    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        # if lexer is not found, using default one
        lexer = get_lexer_by_name('text', stripall=True)

    html_code = ''
    tmp_code = ''
    last_line = None
    line_code_start = None

    # parse lines
    for line, code in codelines:
        if not last_line:
            line_code_start = line

        # new codeblock is detected
        if last_line is not None and last_line + 1 != line:

            # highlight last codepart
            formatter = HtmlFormatter(linenos='inline', linenostart=line_code_start, cssclass="code-highlight")
            html_code = html_code + highlight(tmp_code, lexer, formatter)

            # reset conditions for next codepart
            tmp_code = ''
            line_code_start = line

        # add codepart
        tmp_code += code + '\n'

        # update line
        last_line = line

    # highlight last codepart
    formatter = HtmlFormatter(linenos='inline', linenostart=line_code_start, cssclass="code-highlight")
    html_code = html_code + highlight(tmp_code, lexer, formatter)

    return html_code


def get_result_template(theme_name: str, template_name: str):
    themed_path = theme_name + '/result_templates/' + template_name
    if themed_path in result_templates:
        return themed_path
    return 'result_templates/' + template_name


def custom_url_for(endpoint: str, **values):
    suffix = ""
    if endpoint == 'static' and values.get('filename'):
        file_hash = static_files.get(values['filename'])
        if not file_hash:
            # try file in the current theme
            theme_name = request.preferences.get_value('theme')
            filename_with_theme = "themes/{}/{}".format(theme_name, values['filename'])
            file_hash = static_files.get(filename_with_theme)
            if file_hash:
                values['filename'] = filename_with_theme
        if get_setting('ui.static_use_hash') and file_hash:
            suffix = "?" + file_hash
    if endpoint == 'info' and 'locale' not in values:
        locale = request.preferences.get_value('locale')
        if _INFO_PAGES.get_page(values['pagename'], locale) is None:
            locale = _INFO_PAGES.locale_default
        values['locale'] = locale
    return url_for(endpoint, **values) + suffix


def morty_proxify(url: str):
    if url.startswith('//'):
        url = 'https:' + url

    if not settings['result_proxy']['url']:
        return url

    url_params = dict(mortyurl=url)

    if settings['result_proxy']['key']:
        url_params['mortyhash'] = hmac.new(settings['result_proxy']['key'], url.encode(), hashlib.sha256).hexdigest()

    return '{0}?{1}'.format(settings['result_proxy']['url'], urlencode(url_params))


def image_proxify(url: str):

    if url.startswith('//'):
        url = 'https:' + url

    if not request.preferences.get_value('image_proxy'):
        return url

    if url.startswith('data:image/'):
        # 50 is an arbitrary number to get only the beginning of the image.
        partial_base64 = url[len('data:image/') : 50].split(';')
        if (
            len(partial_base64) == 2
            and partial_base64[0] in ['gif', 'png', 'jpeg', 'pjpeg', 'webp', 'tiff', 'bmp']
            and partial_base64[1].startswith('base64,')
        ):
            return url
        return None

    if settings['result_proxy']['url']:
        return morty_proxify(url)

    h = new_hmac(settings['server']['secret_key'], url.encode())

    return '{0}?{1}'.format(url_for('image_proxy'), urlencode(dict(url=url.encode(), h=h)))


def get_translations():
    return {
        # when there is autocompletion
        'no_item_found': gettext('No item found'),
        # /preferences: the source of the engine description (wikipedata, wikidata, website)
        'Source': gettext('Source'),
        # infinite scroll
        'error_loading_next_page': gettext('Error loading the next page'),
    }


def _get_enable_categories(all_categories: Iterable[str]):
    disabled_engines = request.preferences.engines.get_disabled()
    enabled_categories = set(
        # pylint: disable=consider-using-dict-items
        category
        for engine_name in engines
        for category in engines[engine_name].categories
        if (engine_name, category) not in disabled_engines
    )
    return [x for x in all_categories if x in enabled_categories]


def get_pretty_url(parsed_url: urllib.parse.ParseResult):
    path = parsed_url.path
    path = path[:-1] if len(path) > 0 and path[-1] == '/' else path
    path = unquote(path.replace("/", " › "))
    return [parsed_url.scheme + "://" + parsed_url.netloc, path]


def get_client_settings():
    req_pref = request.preferences
    return {
        'autocomplete_provider': req_pref.get_value('autocomplete'),
        'autocomplete_min': get_setting('search.autocomplete_min'),
        'http_method': req_pref.get_value('method'),
        'infinite_scroll': req_pref.get_value('infinite_scroll'),
        'translations': get_translations(),
        'search_on_category_select': req_pref.plugins.choices['searx.plugins.search_on_category_select'],
        'hotkeys': req_pref.plugins.choices['searx.plugins.vim_hotkeys'],
        'theme_static_path': custom_url_for('static', filename='themes/simple'),
    }


def render(template_name: str, **kwargs):

    kwargs['client_settings'] = str(
        base64.b64encode(
            bytes(
                json.dumps(get_client_settings()),
                encoding='utf-8',
            )
        ),
        encoding='utf-8',
    )

    # values from the HTTP requests
    kwargs['endpoint'] = 'results' if 'q' in kwargs else request.endpoint
    kwargs['cookies'] = request.cookies
    kwargs['errors'] = request.errors

    # values from the preferences
    kwargs['preferences'] = request.preferences
    kwargs['autocomplete'] = request.preferences.get_value('autocomplete')
    kwargs['infinite_scroll'] = request.preferences.get_value('infinite_scroll')
    kwargs['results_on_new_tab'] = request.preferences.get_value('results_on_new_tab')
    kwargs['advanced_search'] = request.preferences.get_value('advanced_search')
    kwargs['query_in_title'] = request.preferences.get_value('query_in_title')
    kwargs['safesearch'] = str(request.preferences.get_value('safesearch'))
    kwargs['theme'] = request.preferences.get_value('theme')
    kwargs['method'] = request.preferences.get_value('method')
    kwargs['categories_as_tabs'] = list(settings['categories_as_tabs'].keys())
    kwargs['categories'] = _get_enable_categories(categories.keys())
    kwargs['OTHER_CATEGORY'] = OTHER_CATEGORY

    # i18n
    kwargs['language_codes'] = [l for l in languages if l[0] in settings['search']['languages']]

    locale = request.preferences.get_value('locale')
    kwargs['locale_rfc5646'] = _get_locale_rfc5646(locale)

    if locale in RTL_LOCALES and 'rtl' not in kwargs:
        kwargs['rtl'] = True
    if 'current_language' not in kwargs:
        kwargs['current_language'] = match_language(
            request.preferences.get_value('language'), settings['search']['languages']
        )

    # values from settings
    kwargs['search_formats'] = [x for x in settings['search']['formats'] if x != 'html']
    kwargs['instance_name'] = get_setting('general.instance_name')
    kwargs['searx_version'] = VERSION_STRING
    kwargs['searx_git_url'] = GIT_URL
    kwargs['enable_metrics'] = get_setting('general.enable_metrics')
    kwargs['get_setting'] = get_setting
    kwargs['get_pretty_url'] = get_pretty_url

    # values from settings: donation_url
    donation_url = get_setting('general.donation_url')
    if donation_url is True:
        donation_url = custom_url_for('info', pagename='donate')
    kwargs['donation_url'] = donation_url

    # helpers to create links to other pages
    kwargs['url_for'] = custom_url_for  # override url_for function in templates
    kwargs['image_proxify'] = image_proxify
    kwargs['proxify'] = morty_proxify if settings['result_proxy']['url'] is not None else None
    kwargs['proxify_results'] = settings['result_proxy']['proxify_results']
    kwargs['cache_url'] = settings['ui']['cache_url']
    kwargs['get_result_template'] = get_result_template
    kwargs['doi_resolver'] = get_doi_resolver(request.preferences)
    kwargs['opensearch_url'] = (
        url_for('opensearch')
        + '?'
        + urlencode(
            {
                'method': request.preferences.get_value('method'),
                'autocomplete': request.preferences.get_value('autocomplete'),
            }
        )
    )

    # scripts from plugins
    kwargs['scripts'] = set()
    for plugin in request.user_plugins:
        for script in plugin.js_dependencies:
            kwargs['scripts'].add(script)

    # styles from plugins
    kwargs['styles'] = set()
    for plugin in request.user_plugins:
        for css in plugin.css_dependencies:
            kwargs['styles'].add(css)

    start_time = default_timer()
    result = render_template('{}/{}'.format(kwargs['theme'], template_name), **kwargs)
    request.render_time += default_timer() - start_time  # pylint: disable=assigning-non-slot

    return result


@app.before_request
def pre_request():
    request.start_time = default_timer()  # pylint: disable=assigning-non-slot
    request.render_time = 0  # pylint: disable=assigning-non-slot
    request.timings = []  # pylint: disable=assigning-non-slot
    request.errors = []  # pylint: disable=assigning-non-slot

    preferences = Preferences(themes, list(categories.keys()), engines, plugins)  # pylint: disable=redefined-outer-name
    user_agent = request.headers.get('User-Agent', '').lower()
    if 'webkit' in user_agent and 'android' in user_agent:
        preferences.key_value_settings['method'].value = 'GET'
    request.preferences = preferences  # pylint: disable=assigning-non-slot

    try:
        preferences.parse_dict(request.cookies)

    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        request.errors.append(gettext('Invalid settings, please edit your preferences'))

    # merge GET, POST vars
    # request.form
    request.form = dict(request.form.items())  # pylint: disable=assigning-non-slot
    for k, v in request.args.items():
        if k not in request.form:
            request.form[k] = v

    if request.form.get('preferences'):
        preferences.parse_encoded_data(request.form['preferences'])
    else:
        try:
            preferences.parse_dict(request.form)
        except Exception as e:  # pylint: disable=broad-except
            logger.exception(e, exc_info=True)
            request.errors.append(gettext('Invalid settings'))

    # language is defined neither in settings nor in preferences
    # use browser headers
    if not preferences.get_value("language"):
        language = _get_browser_language(request, settings['search']['languages'])
        preferences.parse_dict({"language": language})
        logger.debug('set language %s (from browser)', preferences.get_value("language"))

    # locale is defined neither in settings nor in preferences
    # use browser headers
    if not preferences.get_value("locale"):
        locale = _get_browser_language(request, LOCALE_NAMES.keys())
        preferences.parse_dict({"locale": locale})
        logger.debug('set locale %s (from browser)', preferences.get_value("locale"))

    # request.user_plugins
    request.user_plugins = []  # pylint: disable=assigning-non-slot
    allowed_plugins = preferences.plugins.get_enabled()
    disabled_plugins = preferences.plugins.get_disabled()
    for plugin in plugins:
        if (plugin.default_on and plugin.id not in disabled_plugins) or plugin.id in allowed_plugins:
            request.user_plugins.append(plugin)


@app.after_request
def add_default_headers(response: flask.Response):
    # set default http headers
    for header, value in settings['server']['default_http_headers'].items():
        if header in response.headers:
            continue
        response.headers[header] = value
    return response


@app.after_request
def post_request(response: flask.Response):
    total_time = default_timer() - request.start_time
    timings_all = [
        'total;dur=' + str(round(total_time * 1000, 3)),
        'render;dur=' + str(round(request.render_time * 1000, 3)),
    ]
    if len(request.timings) > 0:
        timings = sorted(request.timings, key=lambda t: t.total)
        timings_total = [
            'total_' + str(i) + '_' + t.engine + ';dur=' + str(round(t.total * 1000, 3)) for i, t in enumerate(timings)
        ]
        timings_load = [
            'load_' + str(i) + '_' + t.engine + ';dur=' + str(round(t.load * 1000, 3))
            for i, t in enumerate(timings)
            if t.load
        ]
        timings_all = timings_all + timings_total + timings_load
    # response.headers.add('Server-Timing', ', '.join(timings_all))
    return response


def index_error(output_format: str, error_message: str):
    if output_format == 'json':
        return Response(json.dumps({'error': error_message}), mimetype='application/json')
    if output_format == 'csv':
        response = Response('', mimetype='application/csv')
        cont_disp = 'attachment;Filename=searx.csv'
        response.headers.add('Content-Disposition', cont_disp)
        return response

    if output_format == 'rss':
        response_rss = render(
            'opensearch_response_rss.xml',
            results=[],
            q=request.form['q'] if 'q' in request.form else '',
            number_of_results=0,
            error_message=error_message,
        )
        return Response(response_rss, mimetype='text/xml')

    # html
    request.errors.append(gettext('search error'))
    return render(
        # fmt: off
        'index.html',
        selected_categories=get_selected_categories(request.preferences, request.form),
        # fmt: on
    )


@app.route('/', methods=['GET', 'POST'])
def index():
    """Render index page."""

    # redirect to search if there's a query in the request
    if request.form.get('q'):
        query = ('?' + request.query_string.decode()) if request.query_string else ''
        return redirect(url_for('search') + query, 308)

    return render(
        # fmt: off
        'index.html',
        selected_categories=get_selected_categories(request.preferences, request.form),
        current_locale = request.preferences.get_value("locale"),
        # fmt: on
    )


@app.route('/healthz', methods=['GET'])
def health():
    return Response('OK', mimetype='text/plain')


@app.route('/search', methods=['GET', 'POST'])
def search():
    """Search query in q and return results.

    Supported outputs: html, json, csv, rss.
    """
    # pylint: disable=too-many-locals, too-many-return-statements, too-many-branches
    # pylint: disable=too-many-statements

    # output_format
    output_format = request.form.get('format', 'html')
    if output_format not in OUTPUT_FORMATS:
        output_format = 'html'

    if output_format not in settings['search']['formats']:
        flask.abort(403)

    # check if there is query (not None and not an empty string)
    if not request.form.get('q'):
        if output_format == 'html':
            return render(
                # fmt: off
                'index.html',
                selected_categories=get_selected_categories(request.preferences, request.form),
                # fmt: on
            )
        return index_error(output_format, 'No query'), 400

    # search
    search_query = None
    raw_text_query = None
    result_container = None
    original_search_query = ""
    try:
        search_query, raw_text_query, _, _ = get_search_query_from_webapp(request.preferences, request.form)
        # search = Search(search_query) #  without plugins
        try:
            original_search_query = search_query.query
            if "请推荐" in search_query.query or "帮我" in search_query.query or "写一段" in search_query.query or "写一个" in search_query.query or "请问" in search_query.query or "请给" in search_query.query or "请你" in search_query.query  or "请推荐" in search_query.query or "是谁" in search_query.query or "能帮忙" in search_query.query or "介绍一下" in search_query.query or "为什么" in search_query.query or "什么是" in search_query.query or "有什么" in search_query.query or "怎样" in search_query.query or "给我" in search_query.query or "如何" in search_query.query or "谁是" in search_query.query or "查询" in search_query.query or "告诉我" in search_query.query or "查一下" in search_query.query or "找一个" in search_query.query or "什么样" in search_query.query or "哪个" in search_query.query or "哪些" in search_query.query or "哪一个" in search_query.query or "哪一些" in search_query.query  or "啥是" in search_query.query or "为啥" in search_query.query or "怎么" in search_query.query:
                if len(search_query.query)>5 and "谁是" in search_query.query:
                    search_query.query = search_query.query.replace("谁是","")
                if len(search_query.query)>5 and "是谁" in search_query.query:
                    search_query.query = search_query.query.replace("是谁","")
                if len(search_query.query)>5 and not "谁是" in search_query.query and not "是谁" in search_query.query:
                    prompt = search_query.query + "\n对以上问题生成一个Google搜索词：\n"
                    if "今年" in prompt or "今天" in prompt:
                        now = datetime.datetime.now()
                        prompt = prompt.replace("今年",now.strftime('%Y年'))
                        prompt = prompt.replace("今天",now.strftime('%Y年%m月%d日'))
                    gpt = ""
                    gpt_url = "https://api.openai.com/v1/engines/text-davinci-003/completions"
                    gpt_headers = {
                        "Authorization": "Bearer "+os.environ['GPTKEY'],
                        "Content-Type": "application/json",    
                    }
                    gpt_data = {
                        "prompt": prompt,
                        "max_tokens": 256,
                        "temperature": 0.9,
                        "top_p": 1,
                        "frequency_penalty": 0,
                        "presence_penalty": 0,
                        "best_of": 1,
                        "echo": False,
                        "logprobs": 0,
                        "stream": False
                    }
                    gpt_response = requests.post(gpt_url, headers=gpt_headers, data=json.dumps(gpt_data))
                    gpt_json = gpt_response.json()
                    if 'choices' in gpt_json:
                        gpt = gpt_json['choices'][0]['text']
                    for word in gpt.split('\n'):
                        if word != "":
                            gpt = word.replace("\"","").replace("\'","").replace("“","").replace("”","").replace("‘","").replace("’","")
                            break
                    if gpt!="":
                        search_query.query = gpt
        except Exception as ee:
            logger.exception(ee, exc_info=True)
        search = SearchWithPlugins(search_query, request.user_plugins, request)  # pylint: disable=redefined-outer-name

        result_container = search.search()

    except SearxParameterException as e:
        logger.exception('search error: SearxParameterException')
        return index_error(output_format, e.message), 400
    except Exception as e:  # pylint: disable=broad-except
        logger.exception(e, exc_info=True)
        return index_error(output_format, gettext('search error')), 500

    # results
    results = result_container.get_ordered_results()
    number_of_results = result_container.results_number()
    if number_of_results < result_container.results_length():
        number_of_results = 0

    # OPENAI GPT
    raws = []
    try:
        url_pair = []
        prompt = ""
        for res in results:
            if 'url' not in res: continue
            if 'content' not in res: continue
            if 'title' not in res: continue
            if res['content'] == '': continue
            new_url = 'https://url'+str(len(url_pair))
            url_pair.append(res['url'])
            res['title'] = res['title'].replace("التغريدات مع الردود بواسطة","")
            res['content'] = res['content'].replace("  "," ")
            res['content'] = res['content'].replace("Translate Tweet. ","")
            res['content'] = res['content'].replace("Learn more ","")
            res['content'] = res['content'].replace("Translate Tweet.","")
            res['content'] = res['content'].replace("Retweeted.","Reposted.")     
            res['content'] = res['content'].replace("Learn more.","")     
            res['content'] = res['content'].replace("Show replies.","")      
            res['content'] = res['content'].replace("See new Tweets. ","") 
            if "作者简介：金融学客座教授，硕士生导师" in res['content']:  res['content']=res['title']  
            res['content'] = res['content'].replace("You're unable to view this Tweet because this account owner limits who can view their Tweets.","Private Tweet.")      
            res['content'] = res['content'].replace("Twitter for Android · ","") 
            res['content'] = res['content'].replace("This Tweet was deleted by the Tweet author.","Deleted  Tweet.")
             
            tmp_prompt =  res['title'] +'\n'+  res['content'] + '\n' + new_url +'\n'
            
            if original_search_query == search_query.query and len( prompt + tmp_prompt +'\n' + "\n以上是关键词 " + original_search_query + " 的搜索结果，删除无关内容，用简体中文分条总结简报，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：" ) <1600:
                raws.append(tmp_prompt)
                prompt += tmp_prompt +'\n'
            if len( prompt + tmp_prompt +'\n' + "\n以上是任务 " + original_search_query + " 的网络知识。用简体中文完成任务，如果使用了网络知识，删除无关内容，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：") <1600:
                prompt += tmp_prompt +'\n'
        if prompt != "":
            gpt = ""
            gpt_url = "https://search.kg/completions"
            gpt_headers = {
                "Content-Type": "application/json",
            }
            if original_search_query != search_query.query:
                gpt_data = {
                    "prompt": prompt+"\n以上是任务 " + original_search_query + " 的网络知识。用简体中文完成任务，如果使用了网络知识，删除无关内容，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：",
                    "max_tokens": 1000,
                    "temperature": 0.2,
                    "top_p": 1,
                    "frequency_penalty": 0,
                    "presence_penalty": 0,
                    "best_of": 1,
                    "echo": False,
                    "logprobs": 0,
                    "stream": True
                }
            else:
                gpt_data = {
                    "prompt": prompt+"\n以上是关键词 " + search_query.query + " 的搜索结果，删除无关内容，用简体中文分条总结简报，在文中用(链接)标注对应内容来源链接，链接不要放在最后。结果：",
                    "max_tokens": 1000,
                    "temperature": 0.2,
                    "top_p": 1,
                    "frequency_penalty": 0,
                    "presence_penalty": 0,
                    "best_of": 1,
                    "echo": False,
                    "logprobs": 0,
                    "stream": True
                }
            gpt = json.dumps({'data':gpt_data, 'url_pair':url_pair, 'raws': raws})
            gpt = '<div id="chat_intro"></div><div id="chat"></div>' + r'''<div id="chat_continue" style="display:none">
<div id="chat_more" style="display:none"></div>
<hr>
<textarea id="chat_input" style="margin: auto;display: block;background: rgb(209 219 250 / 30%);outline: 0px;color: var(--color-search-font);font-size: 1.2rem;border-radius: 3px;border: none;height: 3em;resize: vertical;width: 75%;"></textarea>
<button id="chat_send" onclick='send_chat()' style="
    width: 75%;
    display: block;
    margin: auto;
    margin-top: .8em;
    border-radius: .8rem;
    height: 2em;
    background: linear-gradient(81.62deg, #2870ea 8.72%, #1b4aef 85.01%);
    color: #fff;
    border: none;
    cursor: pointer;
">发送</button>
</div>
<style>
.chat_answer {
    cursor: pointer;
    line-height: 1.5em;
    margin: 0.5em 3em 0.5em 0;
    padding: 8px 12px;
    color: white;
    background: rgba(27,74,239,0.7);
}
.chat_question {
    cursor: pointer;
    line-height: 1.5em;
    margin: 0.5em 0 0.5em 3em;
    padding: 8px 12px;
    color: black;
    background: rgba(245, 245, 245, 0.7);
}

button.btn_more {
    min-height: 30px;
    text-align: left;
    background: rgb(209, 219, 250);
    border-radius: 8px;
    overflow: hidden;
    box-sizing: border-box;
    padding: 0px 12px;
    margin: 1px;
    cursor: pointer;
    font-weight: 500;
    line-height: 28px;
    border: 1px solid rgb(18, 59, 182);
    color: rgb(18, 59, 182);
}

::-webkit-scrollbar {
    width: 8px;
}

::-webkit-scrollbar-track {
    -webkit-box-shadow: rgba(0, 0, 0, 0.3);
    box-shadow: rgba(0, 0, 0, 0.3);
    border-radius: 10px;
}

::-webkit-scrollbar-thumb {
    border-radius: 10px;
    background: rgba(17, 16, 16, 0.13);
    -webkit-box-shadow: rgba(0, 0, 0, 0.9);
    box-shadow: rgba(0, 0, 0, 0.5);
}
::-webkit-scrollbar-thumb:window-inactive {
    background: rgba(211, 173, 209, 0.4);
}
</style>
''' + '<div id="prompt" style="display:none">'  + (base64.b64encode(gpt.encode("utf-8")).decode('UTF-8') )  + '</div>' 
            # gpt_response = requests.post(gpt_url, headers=gpt_headers, data=json.dumps(gpt_data))
            # gpt_json = gpt_response.json()
            # if 'choices' in gpt_json:
            #     gpt = gpt_json['choices'][0]['text']
            # gpt = gpt.replace("简报：","").replace("简报:","")
            # for i in range(len(url_pair)-1,-1,-1):
            #     gpt = gpt.replace("https://url"+str(i),url_pair[i])
            # rgpt = gpt

            if gpt and gpt!="":
                if original_search_query != search_query.query:
                    gpt = "Search 为您搜索：" + search_query.query + "\n\n" + gpt
                gpt = gpt + r'''<style>
                a.footnote {
                    position: relative;
                    display: inline-flex;
                    align-items: center;
                    justify-content: center;
                    font-size: 10px;
                    font-weight: 600;
                    vertical-align: top;
                    top: 0px;
                    margin: 1px 1px;
                    min-width: 14px;
                    height: 14px;
                    border-radius: 3px;
                    color: rgb(18, 59, 182);
                    background: rgb(209, 219, 250);
                    outline: transparent solid 1px;
                }
                </style>





                <script src="/static/themes/magi/markdown.js"></script>
                <script>
const original_search_query = "''' + original_search_query.replace('"',"") + r'''"
const search_queryquery = "''' + search_query.query.replace('"',"") + r'''"
</script><script>
const _0x57c199=_0x2a23,_0x469679=_0x2a23,_0x59ea0c=_0x2a23,_0x2394fa=_0x2a23,_0x10d145=_0x2a23;(function(_0x156f82,_0xfc884d){const _0x4cdb1b=_0x2a23,_0x1f190f=_0x2a23,_0x1f515a=_0x2a23,_0x4bdfc2=_0x2a23,_0x30f10b=_0x2a23,_0x3b5934=_0x156f82();while(!![]){try{const _0x544e45=-parseInt(_0x4cdb1b(0x661))/(-0x1234+-0x1cdf+0x2f14)+parseInt(_0x4cdb1b(0x1bd))/(0x181c+0x22ee+0xec2*-0x4)*(-parseInt(_0x1f190f(0x1e5))/(0x4b4*-0x1+-0x402*-0x2+-0x34d))+parseInt(_0x4bdfc2(0x558))/(-0x856+-0x1f9*-0x4+0x3b*0x2)*(-parseInt(_0x4bdfc2(0x45b))/(-0x1*-0x1927+0x1db0+-0x36d2))+parseInt(_0x1f190f(0xfd))/(-0x382+-0x4b*0x6d+0x2377)*(parseInt(_0x1f515a(0x218))/(0x1bef*0x1+0x1*-0xd90+-0xd8*0x11))+parseInt(_0x4bdfc2(0x40d))/(0x48f+-0x10d3+-0x626*-0x2)+parseInt(_0x30f10b(0x3eb))/(-0x2651+-0x13*-0x1+-0xef*-0x29)+parseInt(_0x1f190f(0x5b5))/(0x1364+0xe68+0x21c2*-0x1);if(_0x544e45===_0xfc884d)break;else _0x3b5934['push'](_0x3b5934['shift']());}catch(_0x13b73e){_0x3b5934['push'](_0x3b5934['shift']());}}}(_0x2501,0xfec*-0x1+0x269f1+-0xaf4));function stringToArrayBuffer(_0x4a14c3){const _0x1fef80=_0x2a23,_0x471d2b=_0x2a23,_0x3dc8e4=_0x2a23,_0x3288e3=_0x2a23,_0x1b09c8=_0x2a23,_0xdad663={'DwNzN':function(_0x2f92d4,_0x558f74){return _0x2f92d4+_0x558f74;},'IRVWW':_0x1fef80(0x24f),'omiXz':function(_0x23d865,_0x3585d2){return _0x23d865(_0x3585d2);},'JhFJz':_0x1fef80(0x540)+_0x471d2b(0x269)+'rl','SgYhe':function(_0x5441d8,_0x51e87f){return _0x5441d8(_0x51e87f);},'kbwsL':_0x3dc8e4(0x522)+'l','AOSiM':function(_0x58de16,_0x7413dc){return _0x58de16+_0x7413dc;},'kYZhv':_0x3dc8e4(0x50c),'gnLlQ':function(_0x21f931,_0x48d593){return _0x21f931(_0x48d593);},'pUMUq':function(_0x3cbe65,_0x3dbfd9){return _0x3cbe65+_0x3dbfd9;},'ZehbJ':_0x471d2b(0x2e3)+':','jLaHk':function(_0x32dfa1,_0x306523){return _0x32dfa1!==_0x306523;},'qqKQJ':_0x3dc8e4(0x5e9),'QaKkN':_0x471d2b(0x4d0),'xjVJI':function(_0x26a078,_0x105345){return _0x26a078<_0x105345;},'pRkdO':_0x1b09c8(0x5ba),'noZmN':_0x3dc8e4(0x2a3)};if(!_0x4a14c3)return;try{if(_0xdad663[_0x3288e3(0x261)](_0xdad663[_0x1fef80(0x61e)],_0xdad663[_0x1b09c8(0x41b)])){var _0x4f20bf=new ArrayBuffer(_0x4a14c3[_0x3288e3(0x613)+'h']),_0x1028a2=new Uint8Array(_0x4f20bf);for(var _0x36a8a1=-0x2f*-0x59+-0x18d4+0x87d,_0x2647ab=_0x4a14c3[_0x471d2b(0x613)+'h'];_0xdad663[_0x471d2b(0x4a2)](_0x36a8a1,_0x2647ab);_0x36a8a1++){_0xdad663[_0x471d2b(0x261)](_0xdad663[_0x471d2b(0x146)],_0xdad663[_0x1fef80(0x69a)])?_0x1028a2[_0x36a8a1]=_0x4a14c3[_0x3288e3(0x749)+_0x1b09c8(0x4ec)](_0x36a8a1):(_0x19aab0=_0x378b3a[_0x1b09c8(0x180)+_0x3dc8e4(0x1f2)](_0xdad663[_0x1fef80(0x268)](_0xdad663[_0x471d2b(0x5ce)],_0xdad663[_0x3dc8e4(0x1b8)](_0x3d245c,_0x1d897f)),_0xdad663[_0x3288e3(0x268)](_0xdad663[_0x3dc8e4(0x50e)],_0xdad663[_0x471d2b(0x630)](_0x816386,_0x16c630))),_0x1db680=_0x2e0ecd[_0x1fef80(0x180)+_0x1b09c8(0x1f2)](_0xdad663[_0x1b09c8(0x268)](_0xdad663[_0x1b09c8(0x435)],_0xdad663[_0x3dc8e4(0x630)](_0xa31edf,_0x4cdf6a)),_0xdad663[_0x1b09c8(0x268)](_0xdad663[_0x1fef80(0x50e)],_0xdad663[_0x3dc8e4(0x630)](_0xf12952,_0x450daf))),_0x22b654=_0x25fd9f[_0x3288e3(0x180)+_0x471d2b(0x1f2)](_0xdad663[_0x3288e3(0x639)](_0xdad663[_0x1fef80(0x52b)],_0xdad663[_0x1b09c8(0x381)](_0x31ee52,_0x318f41)),_0xdad663[_0x3288e3(0x16a)](_0xdad663[_0x3288e3(0x50e)],_0xdad663[_0x1fef80(0x1b8)](_0x48f8a2,_0x42daf4))));}return _0x4f20bf;}else _0x533880[_0x1b09c8(0x519)](_0xdad663[_0x1b09c8(0x405)],_0x5ca311);}catch(_0x1b7f8d){}}function arrayBufferToString(_0x475676){const _0x507225=_0x2a23,_0xf927e3=_0x2a23,_0x37cd68=_0x2a23,_0x3422a8=_0x2a23,_0x4b5a07=_0x2a23,_0x197b38={'LkajO':function(_0x22d041,_0x1296f4){return _0x22d041+_0x1296f4;},'hDQnh':_0x507225(0x3b0)+'es','tuAZB':function(_0x417fa7,_0x2d5374){return _0x417fa7(_0x2d5374);},'cPnQE':function(_0x794bbc,_0x4eddbb){return _0x794bbc===_0x4eddbb;},'fucNS':_0x507225(0x1b7),'kwTLh':function(_0x11d7fb,_0x4e13f1){return _0x11d7fb<_0x4e13f1;},'LbvSW':function(_0x5d83cb,_0x220782){return _0x5d83cb!==_0x220782;},'AWgxQ':_0x507225(0x334),'YbUAl':_0xf927e3(0x691)};try{if(_0x197b38[_0x4b5a07(0x1c0)](_0x197b38[_0x37cd68(0x34c)],_0x197b38[_0x4b5a07(0x34c)])){var _0x43fb32=new Uint8Array(_0x475676),_0x2a3ac3='';for(var _0x564b5c=-0x147f+0x1*0x295+0x2*0x8f5;_0x197b38[_0x4b5a07(0x428)](_0x564b5c,_0x43fb32[_0x507225(0x23d)+_0x4b5a07(0x65e)]);_0x564b5c++){_0x197b38[_0x4b5a07(0x48f)](_0x197b38[_0x37cd68(0x421)],_0x197b38[_0x3422a8(0xe8)])?_0x2a3ac3+=String[_0xf927e3(0x139)+_0x4b5a07(0x256)+_0x4b5a07(0x303)](_0x43fb32[_0x564b5c]):(_0x5dba95=_0x5bbe30[_0x4b5a07(0x1d3)](_0x197b38[_0x4b5a07(0x3d3)](_0x1746ba,_0x52f46e))[_0x197b38[_0xf927e3(0x3fe)]],_0x35dabc='');}return _0x2a3ac3;}else qwDZBV[_0x507225(0x74e)](_0x42f5a4,0x22*0x10c+0x1*-0x2337+-0x61);}catch(_0x4477be){}}function importPrivateKey(_0x1153e4){const _0x10540e=_0x2a23,_0x3c651c=_0x2a23,_0x5c07b9=_0x2a23,_0x329da6=_0x2a23,_0x56965d=_0x2a23,_0x30a86f={'PEwnN':_0x10540e(0x3ce)+_0x3c651c(0x1a9)+_0x5c07b9(0x6f2)+_0x3c651c(0x369)+_0x3c651c(0x660)+'--','WoKrT':_0x56965d(0x3ce)+_0x56965d(0x56b)+_0x3c651c(0x260)+_0x3c651c(0x29f)+_0x5c07b9(0x3ce),'tIDlb':function(_0x1c1b3f,_0x53b6e3){return _0x1c1b3f-_0x53b6e3;},'oUslh':function(_0x10b86e,_0x359579){return _0x10b86e(_0x359579);},'GZNzN':_0x10540e(0x19f),'Xnfkt':_0x56965d(0x340)+_0x5c07b9(0x2e2),'jfotB':_0x10540e(0x5b8)+'56','pfMkO':_0x5c07b9(0x3fc)+'pt'},_0x211c34=_0x30a86f[_0x56965d(0x3c0)],_0x9a4049=_0x30a86f[_0x3c651c(0x2e0)],_0x275b75=_0x1153e4[_0x5c07b9(0x5f7)+_0x329da6(0x63d)](_0x211c34[_0x5c07b9(0x613)+'h'],_0x30a86f[_0x10540e(0x281)](_0x1153e4[_0x329da6(0x613)+'h'],_0x9a4049[_0x3c651c(0x613)+'h'])),_0x39d9ca=_0x30a86f[_0x56965d(0x694)](atob,_0x275b75),_0x397260=_0x30a86f[_0x10540e(0x694)](stringToArrayBuffer,_0x39d9ca);return crypto[_0x5c07b9(0x513)+'e'][_0x5c07b9(0x3b2)+_0x10540e(0x4bb)](_0x30a86f[_0x56965d(0x536)],_0x397260,{'name':_0x30a86f[_0x329da6(0x1b2)],'hash':_0x30a86f[_0x10540e(0x6b9)]},!![],[_0x30a86f[_0x56965d(0xf9)]]);}function importPublicKey(_0x3ec2d4){const _0x35d399=_0x2a23,_0x246fff=_0x2a23,_0x3c7c5b=_0x2a23,_0x4ed145=_0x2a23,_0x170164=_0x2a23,_0x1db50f={'rSgCJ':_0x35d399(0x3b0)+'es','BuiJv':function(_0x4b5d9a,_0x4703f7){return _0x4b5d9a+_0x4703f7;},'YyXuu':_0x35d399(0x6a9)+_0x3c7c5b(0x4be)+'t','OMOVb':function(_0xc56638,_0x460212){return _0xc56638+_0x460212;},'RSPlM':_0x246fff(0x16d)+_0x246fff(0x1b6)+'l','DvsGw':function(_0x285a0c,_0x93fb3d){return _0x285a0c(_0x93fb3d);},'UpQfh':_0x170164(0x16d)+_0x170164(0x55d),'QkSGc':_0x3c7c5b(0x55d),'heUac':function(_0x4611ea,_0x1b26ce){return _0x4611ea===_0x1b26ce;},'xgVOn':_0x3c7c5b(0x3f5),'HtSWY':_0x3c7c5b(0x6c0),'bODsd':function(_0x254d97,_0x5b4792){return _0x254d97!==_0x5b4792;},'jKsIA':_0x4ed145(0x4a5),'PtIYC':_0x35d399(0x216),'LPpih':_0x170164(0x701),'xsWpe':_0x4ed145(0x424),'zpqij':function(_0x4315cf,_0x4f8c19){return _0x4315cf===_0x4f8c19;},'wPgyz':_0x246fff(0x3ac),'BeQZq':_0x170164(0xdc),'PuXOK':_0x246fff(0x35f)+_0x170164(0x285)+'+$','fjXwO':function(_0x3310a3,_0x330704){return _0x3310a3!==_0x330704;},'PBxaC':_0x170164(0x47b),'qNNFF':function(_0x34e935,_0x36d7c6){return _0x34e935-_0x36d7c6;},'zhSHp':function(_0x4eaa4b,_0x2e3264){return _0x4eaa4b<_0x2e3264;},'aqqMt':function(_0x3752c6,_0x24a5da){return _0x3752c6+_0x24a5da;},'PcuJv':function(_0x442970,_0x2157a7){return _0x442970===_0x2157a7;},'HGltO':_0x4ed145(0x382),'HEPqi':_0x170164(0x310),'dBYRw':_0x4ed145(0x3ca),'Fekoh':function(_0x2ced06,_0x27e8d2){return _0x2ced06!==_0x27e8d2;},'VQTgx':_0x35d399(0x167),'sUsXe':_0x35d399(0x2e7)+_0x170164(0x652)+_0x170164(0x2b3)+_0x35d399(0x677),'vqCmc':_0x35d399(0xd8)+_0x246fff(0x528)+_0x3c7c5b(0x4c7)+_0x4ed145(0x563)+_0x3c7c5b(0x126)+_0x4ed145(0x6d9)+'\x20)','XmlXj':_0x35d399(0x6a9)+_0x246fff(0x183),'vIUeF':_0x170164(0x1ca)+_0x35d399(0x6cd)+_0x3c7c5b(0x4af)+_0x35d399(0x35e)+_0x3c7c5b(0x30a)+_0x246fff(0x5d5)+_0x4ed145(0x508)+_0x3c7c5b(0x45c)+_0x246fff(0x28c)+_0x3c7c5b(0x339)+_0x246fff(0x655),'gfrcj':_0x246fff(0x22d)+_0x3c7c5b(0x575),'gLHBl':_0x246fff(0x237),'ndczE':_0x170164(0x6a9),'bWWNK':_0x35d399(0x624),'oPocZ':_0x3c7c5b(0x500)+_0x35d399(0x605)+_0x170164(0x21e)+_0x35d399(0xf2)+_0x35d399(0x32d)+_0x35d399(0x469)+_0x35d399(0x2d4)+_0x4ed145(0x3c4)+_0x3c7c5b(0x189)+_0x4ed145(0x451)+_0x35d399(0x3d2)+_0x246fff(0x27c)+_0x3c7c5b(0x565),'vvcqw':function(_0x33dad0,_0x204b89){return _0x33dad0!=_0x204b89;},'gvcWi':function(_0x7c11b8,_0x3acc11,_0x2c2b80){return _0x7c11b8(_0x3acc11,_0x2c2b80);},'fFpaR':_0x3c7c5b(0x16d)+_0x35d399(0x250)+_0x246fff(0x2a7)+_0x35d399(0x1e6)+_0x170164(0x2cc)+_0x35d399(0x584),'hveMg':_0x4ed145(0x4d8),'DkLXV':_0x3c7c5b(0x6bf),'VpPbX':_0x3c7c5b(0x2b5)+_0x246fff(0x232)+_0x246fff(0x4a1)+')','rtpbH':_0x170164(0x53f)+_0x3c7c5b(0x4a7)+_0x4ed145(0x2f9)+_0x3c7c5b(0x748)+_0x3c7c5b(0x4a0)+_0x246fff(0x21f)+_0x35d399(0x6f9),'bcPqp':_0x246fff(0x415),'ZDcZZ':function(_0x2d02b7,_0x4c98f0){return _0x2d02b7+_0x4c98f0;},'PhLGG':_0x4ed145(0x144),'THddh':function(_0x1e2797,_0x223337){return _0x1e2797+_0x223337;},'aUmHX':_0x3c7c5b(0x724),'mtbtk':_0x35d399(0x5da),'WKlWb':_0x246fff(0x3d7),'yFzUr':_0x246fff(0x243),'oRawA':_0x3c7c5b(0x454),'FFTTf':function(_0x2d562d){return _0x2d562d();},'bTqBs':function(_0x449897,_0x393044){return _0x449897!==_0x393044;},'XZVuu':_0x4ed145(0x6ba),'kIfUv':_0x170164(0x349),'CLAUq':_0x170164(0x3ce)+_0x4ed145(0x1a9)+_0x170164(0x69b)+_0x3c7c5b(0x695)+_0x170164(0x628)+'-','RLyav':_0x3c7c5b(0x3ce)+_0x35d399(0x56b)+_0x4ed145(0x240)+_0x170164(0x6fd)+_0x170164(0x4fb),'FnTuK':function(_0x1bc250,_0x34efe6){return _0x1bc250(_0x34efe6);},'xKbyX':function(_0x419812,_0x19c6dc){return _0x419812(_0x19c6dc);},'YfwMh':_0x170164(0x3da),'qpips':_0x170164(0x340)+_0x246fff(0x2e2),'WQLwA':_0x3c7c5b(0x5b8)+'56','TIPnx':_0x246fff(0x574)+'pt'},_0x58d5e9=(function(){const _0x272115=_0x3c7c5b,_0x3130b0=_0x170164,_0x2ed2b3=_0x4ed145,_0xd5cc7=_0x35d399,_0x272ebc=_0x35d399,_0x4e410e={'fcfSy':_0x1db50f[_0x272115(0x3f0)],'pRouA':function(_0x1eca73,_0x3d5470){const _0x5a04fb=_0x272115;return _0x1db50f[_0x5a04fb(0x4bc)](_0x1eca73,_0x3d5470);},'uaSlK':_0x1db50f[_0x272115(0x2bc)],'EkRng':function(_0x13a26e,_0x5b991e){const _0x27420f=_0x3130b0;return _0x1db50f[_0x27420f(0x25d)](_0x13a26e,_0x5b991e);},'wFaLI':_0x1db50f[_0x3130b0(0x165)],'NhwOp':function(_0xc4e4f3,_0x1e0daa){const _0x353863=_0x2ed2b3;return _0x1db50f[_0x353863(0x4a8)](_0xc4e4f3,_0x1e0daa);},'ucKsK':_0x1db50f[_0x2ed2b3(0x2df)],'bElCZ':_0x1db50f[_0x272115(0x221)],'vEmCT':function(_0x3763b6,_0x6018a0){const _0x159b1b=_0xd5cc7;return _0x1db50f[_0x159b1b(0x4a8)](_0x3763b6,_0x6018a0);},'zztgY':function(_0x494a30,_0x1803b0){const _0x23841e=_0x3130b0;return _0x1db50f[_0x23841e(0x561)](_0x494a30,_0x1803b0);},'WFFHT':_0x1db50f[_0xd5cc7(0x101)],'QpJsg':_0x1db50f[_0x272ebc(0x163)],'GKZBS':function(_0x406f43,_0x593068){const _0x54bcb5=_0x3130b0;return _0x1db50f[_0x54bcb5(0x467)](_0x406f43,_0x593068);},'ZydJB':_0x1db50f[_0x2ed2b3(0x731)],'qObrJ':_0x1db50f[_0x3130b0(0x727)],'dEEul':_0x1db50f[_0x272ebc(0x399)]};if(_0x1db50f[_0x272115(0x467)](_0x1db50f[_0xd5cc7(0x6bb)],_0x1db50f[_0x272ebc(0x6bb)]))_0x53eb5e=_0xb93b52[_0xd5cc7(0x1d3)](_0x2bc245)[_0x4e410e[_0x2ed2b3(0x510)]],_0x422021='';else{let _0x1c05f0=!![];return function(_0x3330ba,_0x35251c){const _0x5eaa9d=_0x3130b0,_0x1f898e=_0x3130b0,_0x54ce1a=_0x272ebc,_0x3f1b95=_0x272ebc,_0x1adefe=_0xd5cc7,_0x2b741c={'VZEoQ':function(_0x34b3e8,_0x3056a8){const _0x556e86=_0x2a23;return _0x4e410e[_0x556e86(0x49c)](_0x34b3e8,_0x3056a8);},'XtpKI':_0x4e410e[_0x5eaa9d(0x643)],'mXuZO':function(_0x128646,_0x333430){const _0xb2221c=_0x5eaa9d;return _0x4e410e[_0xb2221c(0x541)](_0x128646,_0x333430);},'kvGuE':_0x4e410e[_0x1f898e(0x702)],'aXcmy':function(_0xa606a2,_0x4ce0e4){const _0x364448=_0x1f898e;return _0x4e410e[_0x364448(0x236)](_0xa606a2,_0x4ce0e4);},'NnsOK':_0x4e410e[_0x5eaa9d(0x722)],'aYvdF':_0x4e410e[_0x3f1b95(0x462)],'KIENJ':function(_0x530f1c,_0x3e98d2){const _0x4910b8=_0x5eaa9d;return _0x4e410e[_0x4910b8(0x1bc)](_0x530f1c,_0x3e98d2);},'iYnwq':function(_0x5325c0,_0x59f7d9){const _0x13c33f=_0x1f898e;return _0x4e410e[_0x13c33f(0x436)](_0x5325c0,_0x59f7d9);},'yIDQu':_0x4e410e[_0x1adefe(0x1fd)],'Pcazy':_0x4e410e[_0x1adefe(0x733)],'wCdrk':function(_0x46d8d3,_0x23b48b){const _0xcca413=_0x54ce1a;return _0x4e410e[_0xcca413(0x545)](_0x46d8d3,_0x23b48b);},'xChjT':_0x4e410e[_0x3f1b95(0x395)],'CYuCW':_0x4e410e[_0x5eaa9d(0x5c3)]};if(_0x4e410e[_0x5eaa9d(0x436)](_0x4e410e[_0x1adefe(0x182)],_0x4e410e[_0x5eaa9d(0x182)])){const _0x1901b1=_0x1c05f0?function(){const _0xf7ca21=_0x5eaa9d,_0x555cd5=_0x1f898e,_0x3e9e09=_0x1adefe,_0x318f3e=_0x54ce1a,_0x106120=_0x54ce1a,_0x1468ea={'zauhU':function(_0x489599,_0x53e075){const _0xb98298=_0x2a23;return _0x2b741c[_0xb98298(0x11b)](_0x489599,_0x53e075);},'uhBPy':_0x2b741c[_0xf7ca21(0x115)],'mUAQn':function(_0x4d497f,_0x5f402a){const _0x1358ef=_0xf7ca21;return _0x2b741c[_0x1358ef(0x49d)](_0x4d497f,_0x5f402a);},'HgsDd':_0x2b741c[_0xf7ca21(0x586)],'nsKOH':function(_0x3e5e8d,_0x5cf4dd){const _0x4e1d15=_0xf7ca21;return _0x2b741c[_0x4e1d15(0x11b)](_0x3e5e8d,_0x5cf4dd);},'ApwkO':_0x2b741c[_0x3e9e09(0x729)],'bdUhq':function(_0x2090e5,_0x24ef46){const _0x1803a9=_0xf7ca21;return _0x2b741c[_0x1803a9(0x35b)](_0x2090e5,_0x24ef46);}};if(_0x2b741c[_0x555cd5(0x604)](_0x2b741c[_0xf7ca21(0x35a)],_0x2b741c[_0xf7ca21(0x2d3)])){_0x5c4e14+=_0x2b741c[_0x106120(0x251)](_0x3df54b,_0x215b6f),_0x3a1ea9=-0x36a*-0x3+-0x1*-0x13b6+-0x1df4,_0x210548[_0x3e9e09(0x696)+_0x555cd5(0x6ee)+_0x318f3e(0x6e9)](_0x2b741c[_0xf7ca21(0x554)])[_0x555cd5(0x754)]='';return;}else{if(_0x35251c){if(_0x2b741c[_0x555cd5(0x286)](_0x2b741c[_0x318f3e(0x6a4)],_0x2b741c[_0x318f3e(0x117)])){const _0x20607f=_0x35251c[_0x318f3e(0x352)](_0x3330ba,arguments);return _0x35251c=null,_0x20607f;}else _0x286167=_0x580017[_0x3e9e09(0x180)+'ce'](_0x1468ea[_0x3e9e09(0x4bf)](_0x1468ea[_0x318f3e(0x4b2)],_0x1468ea[_0x3e9e09(0x45d)](_0x2f8d98,_0x1d8c5b)),_0x297f70[_0x555cd5(0x52f)+_0x555cd5(0x6b1)][_0xfda850]),_0x4b0d3a=_0x506545[_0x555cd5(0x180)+'ce'](_0x1468ea[_0x318f3e(0x4bf)](_0x1468ea[_0x318f3e(0x50b)],_0x1468ea[_0x318f3e(0x45d)](_0x27d568,_0x940e44)),_0x123f20[_0xf7ca21(0x52f)+_0xf7ca21(0x6b1)][_0xe97c05]),_0x2e02ea=_0x5b03e0[_0xf7ca21(0x180)+'ce'](_0x1468ea[_0x3e9e09(0x57d)](_0x1468ea[_0x318f3e(0x276)],_0x1468ea[_0x3e9e09(0x315)](_0x104831,_0x1d27ed)),_0x585a1f[_0x555cd5(0x52f)+_0x318f3e(0x6b1)][_0x1e3eb7]);}}}:function(){};return _0x1c05f0=![],_0x1901b1;}else return!![];};}}()),_0xfacba=_0x1db50f[_0x35d399(0x1d6)](_0x58d5e9,this,function(){const _0x208747=_0x246fff,_0x4b9820=_0x35d399,_0x2686ff=_0x170164,_0xc8130a=_0x3c7c5b,_0x2ad23c=_0x35d399;if(_0x1db50f[_0x208747(0x4cd)](_0x1db50f[_0x208747(0x392)],_0x1db50f[_0x4b9820(0x338)]))_0x4cd59c=_0x1a19bd[_0x2686ff(0x1d3)](_0x2973d1)[_0x1db50f[_0x2ad23c(0x3f0)]],_0x4089c8='';else return _0xfacba[_0x2686ff(0x547)+_0x208747(0x41e)]()[_0x2ad23c(0x1ff)+'h'](_0x1db50f[_0x208747(0x663)])[_0x2686ff(0x547)+_0xc8130a(0x41e)]()[_0xc8130a(0x708)+_0xc8130a(0x654)+'r'](_0xfacba)[_0x2686ff(0x1ff)+'h'](_0x1db50f[_0x2ad23c(0x663)]);});_0x1db50f[_0x4ed145(0x568)](_0xfacba);const _0x446eac=(function(){const _0x3a37f2=_0x246fff,_0x415cd6=_0x4ed145,_0x41c8aa=_0x4ed145,_0x4787a8=_0x4ed145,_0x2195ce=_0x246fff,_0x13fb29={'AOEED':function(_0x4df781,_0x10f857){const _0x212b32=_0x2a23;return _0x1db50f[_0x212b32(0x69d)](_0x4df781,_0x10f857);},'hZAbU':function(_0x2f85c8,_0x3d2d2d){const _0x3b0f38=_0x2a23;return _0x1db50f[_0x3b0f38(0x3a6)](_0x2f85c8,_0x3d2d2d);},'GwPEj':function(_0x1ad358,_0x18ab73){const _0x5a2815=_0x2a23;return _0x1db50f[_0x5a2815(0x63a)](_0x1ad358,_0x18ab73);},'aRXcz':_0x1db50f[_0x3a37f2(0x3f0)],'gNkVc':function(_0x2f4597,_0x14dc62){const _0x53c6a4=_0x3a37f2;return _0x1db50f[_0x53c6a4(0x3cc)](_0x2f4597,_0x14dc62);},'PHXeR':_0x1db50f[_0x3a37f2(0x387)],'DtGYG':function(_0x556859,_0x37fb08){const _0x52d96b=_0x415cd6;return _0x1db50f[_0x52d96b(0x4cd)](_0x556859,_0x37fb08);},'dTMIz':_0x1db50f[_0x415cd6(0x599)],'RmlXM':_0x1db50f[_0x4787a8(0x751)]};if(_0x1db50f[_0x3a37f2(0x217)](_0x1db50f[_0x4787a8(0x60b)],_0x1db50f[_0x4787a8(0x60b)]))return _0x343656;else{let _0x4d7d65=!![];return function(_0x4edabf,_0x122be5){const _0x5d1900=_0x2195ce,_0x3f1b0c=_0x415cd6,_0x2f98e6=_0x2195ce,_0x119c86=_0x4787a8,_0x531064=_0x41c8aa;if(_0x1db50f[_0x5d1900(0x6a1)](_0x1db50f[_0x5d1900(0x438)],_0x1db50f[_0x5d1900(0x438)]))_0xc23c6d+=_0x18f162[-0x1*0x2289+-0x31*-0x13+0x235*0xe][_0x3f1b0c(0x28d)],_0x98fb85=_0x4510de[-0x88c+0xaee+-0x262][_0x2f98e6(0x178)+_0x3f1b0c(0x346)][_0x5d1900(0x2ed)+_0x3f1b0c(0x3e0)+'t'][_0x13fb29[_0x3f1b0c(0x50d)](_0x5646f5[0x1aad+0xef3*-0x1+0x2*-0x5dd][_0x5d1900(0x178)+_0x531064(0x346)][_0x3f1b0c(0x2ed)+_0x531064(0x3e0)+'t'][_0x531064(0x613)+'h'],-0x2c7*-0xa+0x1*-0x40f+0x1*-0x17b6)];else{const _0x147f99=_0x4d7d65?function(){const _0x3ee7c6=_0x3f1b0c,_0x1fc7d8=_0x2f98e6,_0xc68a38=_0x2f98e6,_0x4b0f04=_0x531064,_0x3198af=_0x119c86,_0x4e24f0={'pYHpX':function(_0x2bf8ed,_0x3b1746){const _0x5e4c72=_0x2a23;return _0x13fb29[_0x5e4c72(0x219)](_0x2bf8ed,_0x3b1746);},'EGqlI':function(_0xd04b2b,_0x2dd21e){const _0x5b58e0=_0x2a23;return _0x13fb29[_0x5b58e0(0xea)](_0xd04b2b,_0x2dd21e);},'bWVxx':_0x13fb29[_0x3ee7c6(0x706)]};if(_0x13fb29[_0x3ee7c6(0x384)](_0x13fb29[_0x1fc7d8(0x5d4)],_0x13fb29[_0x1fc7d8(0x5d4)])){if(_0x122be5){if(_0x13fb29[_0x1fc7d8(0x2eb)](_0x13fb29[_0xc68a38(0x22c)],_0x13fb29[_0x3198af(0x2c3)])){var _0x2b4148=new _0x158671(_0x63d80a),_0x451646='';for(var _0x38c262=0x11*-0x59+0x20*0xc0+-0x1217;_0x4e24f0[_0x3198af(0x61d)](_0x38c262,_0x2b4148[_0x4b0f04(0x23d)+_0x3198af(0x65e)]);_0x38c262++){_0x451646+=_0x4ff871[_0xc68a38(0x139)+_0x1fc7d8(0x256)+_0x4b0f04(0x303)](_0x2b4148[_0x38c262]);}return _0x451646;}else{const _0x2fde2f=_0x122be5[_0x3198af(0x352)](_0x4edabf,arguments);return _0x122be5=null,_0x2fde2f;}}}else _0x266b8c=_0x237a29[_0xc68a38(0x1d3)](_0x4e24f0[_0x4b0f04(0x40a)](_0x13d036,_0x341f2d))[_0x4e24f0[_0xc68a38(0x6d0)]],_0x196104='';}:function(){};return _0x4d7d65=![],_0x147f99;}};}}());(function(){const _0x1e7cb7=_0x170164,_0x1bd951=_0x4ed145,_0x1c6601=_0x246fff,_0x35be78=_0x3c7c5b,_0x52de66=_0x3c7c5b,_0x3d5b6f={'MRcDU':function(_0xf138bf,_0x2747af){const _0x270a77=_0x2a23;return _0x1db50f[_0x270a77(0x4a8)](_0xf138bf,_0x2747af);},'IOZmX':function(_0x81c5b3,_0x10a1dc){const _0x119c69=_0x2a23;return _0x1db50f[_0x119c69(0x4bc)](_0x81c5b3,_0x10a1dc);},'YVxjy':_0x1db50f[_0x1e7cb7(0x36f)],'bqPmo':_0x1db50f[_0x1e7cb7(0x141)],'KJEnV':_0x1db50f[_0x1c6601(0x2ef)],'Esxyk':_0x1db50f[_0x1bd951(0x31f)],'QjEBl':_0x1db50f[_0x52de66(0x10a)],'etusg':_0x1db50f[_0x1bd951(0x105)],'OQXva':function(_0x1f5bb9,_0x5b28aa){const _0x55f15e=_0x52de66;return _0x1db50f[_0x55f15e(0x63a)](_0x1f5bb9,_0x5b28aa);},'fuPrS':function(_0x52f104,_0x364bef){const _0x3f66f0=_0x52de66;return _0x1db50f[_0x3f66f0(0x63a)](_0x52f104,_0x364bef);},'iaEHD':_0x1db50f[_0x1e7cb7(0x5c2)],'XQylK':_0x1db50f[_0x1e7cb7(0x333)],'gdZGC':_0x1db50f[_0x1bd951(0x204)],'FLBbi':function(_0x32c818,_0x288e62){const _0x24e25d=_0x52de66;return _0x1db50f[_0x24e25d(0x495)](_0x32c818,_0x288e62);},'FSvBl':function(_0x2e5f8d,_0x2ed956,_0x5223e0){const _0x1c54c2=_0x35be78;return _0x1db50f[_0x1c54c2(0x1d6)](_0x2e5f8d,_0x2ed956,_0x5223e0);},'KZAEm':_0x1db50f[_0x52de66(0x1cb)],'JNxXI':_0x1db50f[_0x35be78(0x663)],'kAujI':function(_0x3a8668,_0x37b863){const _0x1cdc8b=_0x52de66;return _0x1db50f[_0x1cdc8b(0x467)](_0x3a8668,_0x37b863);},'IGveU':_0x1db50f[_0x35be78(0x1ba)],'WdMfi':_0x1db50f[_0x52de66(0x6b8)],'LpcyB':_0x1db50f[_0x1e7cb7(0x60c)],'qAqkm':_0x1db50f[_0x1e7cb7(0x212)],'fVLGt':_0x1db50f[_0x35be78(0x5aa)],'nRLBJ':function(_0x2c2a53,_0x390200){const _0x2ea091=_0x1e7cb7;return _0x1db50f[_0x2ea091(0x6a2)](_0x2c2a53,_0x390200);},'OyWwi':_0x1db50f[_0x1bd951(0x66f)],'tyRcX':function(_0xcdbceb,_0x33c3e3){const _0x461790=_0x1e7cb7;return _0x1db50f[_0x461790(0x3f2)](_0xcdbceb,_0x33c3e3);},'rgqCI':_0x1db50f[_0x35be78(0x177)],'frtrp':function(_0x59aded,_0x447934){const _0x356391=_0x1bd951;return _0x1db50f[_0x356391(0x467)](_0x59aded,_0x447934);},'wXWTg':_0x1db50f[_0x52de66(0x2e6)],'cDHMO':_0x1db50f[_0x1bd951(0x6b5)],'njRZQ':function(_0x42d53b,_0x595667){const _0x1062fe=_0x35be78;return _0x1db50f[_0x1062fe(0x4cd)](_0x42d53b,_0x595667);},'UIfpc':_0x1db50f[_0x1c6601(0x176)],'HLBRx':_0x1db50f[_0x52de66(0x10c)],'qCpDm':function(_0x3652de){const _0x601dea=_0x35be78;return _0x1db50f[_0x601dea(0x568)](_0x3652de);}};if(_0x1db50f[_0x1bd951(0x5d7)](_0x1db50f[_0x1c6601(0x214)],_0x1db50f[_0x1e7cb7(0x320)]))_0x1db50f[_0x52de66(0x1d6)](_0x446eac,this,function(){const _0x3c42de=_0x35be78,_0x4fac77=_0x1bd951,_0x491181=_0x1e7cb7,_0x33aaf6=_0x1e7cb7,_0x4ef0fb=_0x1c6601,_0x1eb4e4={'KlfdY':_0x3d5b6f[_0x3c42de(0x20d)],'Bjpat':function(_0x5d94c7,_0x392e0e){const _0xd7c7f=_0x3c42de;return _0x3d5b6f[_0xd7c7f(0x474)](_0x5d94c7,_0x392e0e);},'qWxNo':_0x3d5b6f[_0x3c42de(0x331)],'gjqKv':function(_0x94bc47,_0x23f074){const _0x223d1b=_0x3c42de;return _0x3d5b6f[_0x223d1b(0x127)](_0x94bc47,_0x23f074);},'KSuAW':_0x3d5b6f[_0x3c42de(0x2ad)],'ElCzi':_0x3d5b6f[_0x3c42de(0x59f)],'brPjd':function(_0x54474a,_0x4e9311){const _0x4e594f=_0x4fac77;return _0x3d5b6f[_0x4e594f(0x3f9)](_0x54474a,_0x4e9311);},'bQhvN':function(_0x4f4423,_0x1ce9e3){const _0x2d71df=_0x491181;return _0x3d5b6f[_0x2d71df(0x44d)](_0x4f4423,_0x1ce9e3);},'oiTTO':_0x3d5b6f[_0x33aaf6(0x185)],'XNOMt':_0x3d5b6f[_0x4ef0fb(0x45f)],'VFasi':_0x3d5b6f[_0x33aaf6(0x1d8)],'vfhib':function(_0x566068,_0x23442f){const _0xe788f5=_0x33aaf6;return _0x3d5b6f[_0xe788f5(0x3b3)](_0x566068,_0x23442f);},'NMQPu':function(_0x1e455f,_0x3ff97e,_0x1eca09){const _0x136cf8=_0x4fac77;return _0x3d5b6f[_0x136cf8(0x197)](_0x1e455f,_0x3ff97e,_0x1eca09);},'JJMNv':_0x3d5b6f[_0x491181(0x2fc)],'erVay':_0x3d5b6f[_0x33aaf6(0x1f7)]};if(_0x3d5b6f[_0x33aaf6(0x65c)](_0x3d5b6f[_0x3c42de(0x46f)],_0x3d5b6f[_0x4ef0fb(0x3f7)])){const _0x4b3e5e=new RegExp(_0x3d5b6f[_0x4ef0fb(0xcc)]),_0x2f0d85=new RegExp(_0x3d5b6f[_0x4ef0fb(0x5ff)],'i'),_0x1b4dfa=_0x3d5b6f[_0x491181(0x127)](_0x537f18,_0x3d5b6f[_0x33aaf6(0x711)]);if(!_0x4b3e5e[_0x33aaf6(0x2ce)](_0x3d5b6f[_0x4ef0fb(0x3a4)](_0x1b4dfa,_0x3d5b6f[_0x491181(0x3e6)]))||!_0x2f0d85[_0x491181(0x2ce)](_0x3d5b6f[_0x4ef0fb(0x759)](_0x1b4dfa,_0x3d5b6f[_0x4ef0fb(0x1fc)]))){if(_0x3d5b6f[_0x3c42de(0x296)](_0x3d5b6f[_0x33aaf6(0x61a)],_0x3d5b6f[_0x3c42de(0x69e)]))_0x3d5b6f[_0x3c42de(0x127)](_0x1b4dfa,'0');else{const _0x1ca15e={'oGvSj':_0x1eb4e4[_0x3c42de(0x288)],'tmWJU':function(_0x168931,_0x3b3938){const _0x391f7a=_0x4fac77;return _0x1eb4e4[_0x391f7a(0x191)](_0x168931,_0x3b3938);},'jQyum':_0x1eb4e4[_0x4ef0fb(0x233)],'hikbg':function(_0x5d9f7d,_0x5df405){const _0x38bcfc=_0x491181;return _0x1eb4e4[_0x38bcfc(0x551)](_0x5d9f7d,_0x5df405);},'HADjh':_0x1eb4e4[_0x491181(0x4f1)]},_0x339c78={'method':_0x1eb4e4[_0x491181(0x505)],'headers':_0x1448c5,'body':_0x1eb4e4[_0x4fac77(0x551)](_0x226e2a,_0x48bb81[_0x33aaf6(0xe9)+_0x33aaf6(0x1fe)]({'prompt':_0x1eb4e4[_0x3c42de(0x191)](_0x1eb4e4[_0x33aaf6(0x4a3)](_0x1eb4e4[_0x4fac77(0x1b0)](_0x1eb4e4[_0x3c42de(0x191)](_0x52c337[_0x491181(0x696)+_0x4ef0fb(0x6ee)+_0x4ef0fb(0x6e9)](_0x1eb4e4[_0x33aaf6(0x560)])[_0x4ef0fb(0x746)+_0x3c42de(0x6f5)][_0x3c42de(0x180)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x4fac77(0x180)+'ce'](/<hr.*/gs,'')[_0x4ef0fb(0x180)+'ce'](/<[^>]+>/g,'')[_0x3c42de(0x180)+'ce'](/\n\n/g,'\x0a'),'\x0a'),_0x1eb4e4[_0x33aaf6(0x476)]),_0x3462c9),_0x1eb4e4[_0x491181(0x4b3)]),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':![]}))};if(_0x1eb4e4[_0x4fac77(0x34f)](_0x1226f4[_0x491181(0x696)+_0x3c42de(0x6ee)+_0x4fac77(0x6e9)](_0x1eb4e4[_0x4ef0fb(0x288)])[_0x491181(0x746)+_0x33aaf6(0x6f5)],''))return;_0x1eb4e4[_0x4fac77(0x6e6)](_0x6c09c,_0x1eb4e4[_0x4fac77(0x2d7)],_0x339c78)[_0x3c42de(0x433)](_0x268467=>_0x268467[_0x491181(0x740)]())[_0x3c42de(0x433)](_0x54efe4=>{const _0x3ec8d3=_0x3c42de,_0x29d64c=_0x491181,_0x571a7e=_0x4fac77,_0x4de1a2=_0x4fac77,_0x4f0705=_0x491181;_0x36de68[_0x3ec8d3(0x1d3)](_0x54efe4[_0x3ec8d3(0x3b0)+'es'][-0x1858+0x1a6+0x33e*0x7][_0x29d64c(0x28d)][_0x571a7e(0x180)+_0x4f0705(0x1f2)]('\x0a',''))[_0x4de1a2(0x3a0)+'ch'](_0x194aef=>{const _0x216aa1=_0x4f0705,_0x945ff2=_0x29d64c,_0x3bd857=_0x571a7e,_0x18cb84=_0x3ec8d3,_0x32ea97=_0x4de1a2;_0x7950ee[_0x216aa1(0x696)+_0x945ff2(0x6ee)+_0x945ff2(0x6e9)](_0x1ca15e[_0x945ff2(0x4ce)])[_0x216aa1(0x746)+_0x3bd857(0x6f5)]+=_0x1ca15e[_0x3bd857(0x53a)](_0x1ca15e[_0x216aa1(0x53a)](_0x1ca15e[_0x18cb84(0x538)],_0x1ca15e[_0x18cb84(0x12a)](_0x1ee223,_0x194aef)),_0x1ca15e[_0x32ea97(0x3bb)]);});})[_0x33aaf6(0x3fa)](_0x261f9c=>_0x5c2c82[_0x4fac77(0x519)](_0x261f9c)),_0x24dd36=_0x1eb4e4[_0x491181(0x191)](_0x58d608,'\x0a\x0a'),_0xb5392f=-(0xbc4+-0x11a*0xa+0xbf*-0x1);}}else{if(_0x3d5b6f[_0x491181(0x157)](_0x3d5b6f[_0x3c42de(0x1ea)],_0x3d5b6f[_0x3c42de(0x207)])){let _0x92905;try{_0x92905=eQqhmT[_0x4ef0fb(0x127)](_0x25c4ca,eQqhmT[_0x491181(0x474)](eQqhmT[_0x33aaf6(0x474)](eQqhmT[_0x33aaf6(0x1ac)],eQqhmT[_0x33aaf6(0x4de)]),');'))();}catch(_0x339c1a){_0x92905=_0x36dd62;}return _0x92905;}else _0x3d5b6f[_0x33aaf6(0x1f9)](_0x537f18);}}else return _0x1d7496[_0x4fac77(0x547)+_0x33aaf6(0x41e)]()[_0x4fac77(0x1ff)+'h'](MLScwZ[_0x4fac77(0x645)])[_0x33aaf6(0x547)+_0x491181(0x41e)]()[_0x4ef0fb(0x708)+_0x491181(0x654)+'r'](_0x138076)[_0x4fac77(0x1ff)+'h'](MLScwZ[_0x4ef0fb(0x645)]);})();else{const _0x562767=_0x64989a[_0x1bd951(0x352)](_0x319115,arguments);return _0x2e8d49=null,_0x562767;}}());const _0x569e25=_0x1db50f[_0x3c7c5b(0x44b)],_0x2fd49d=_0x1db50f[_0x170164(0x277)],_0x599100=_0x3ec2d4[_0x170164(0x5f7)+_0x246fff(0x63d)](_0x569e25[_0x4ed145(0x613)+'h'],_0x1db50f[_0x3c7c5b(0x69d)](_0x3ec2d4[_0x35d399(0x613)+'h'],_0x2fd49d[_0x170164(0x613)+'h'])),_0x47133c=_0x1db50f[_0x4ed145(0x1ed)](atob,_0x599100),_0x477345=_0x1db50f[_0x170164(0x1af)](stringToArrayBuffer,_0x47133c);return crypto[_0x3c7c5b(0x513)+'e'][_0x246fff(0x3b2)+_0x35d399(0x4bb)](_0x1db50f[_0x246fff(0x753)],_0x477345,{'name':_0x1db50f[_0x246fff(0x2aa)],'hash':_0x1db50f[_0x170164(0x5e2)]},!![],[_0x1db50f[_0x246fff(0x16b)]]);}function encryptDataWithPublicKey(_0x141988,_0x22effb){const _0x2de2e5=_0x2a23,_0x3230ac=_0x2a23,_0x4c0257=_0x2a23,_0x14ce9e=_0x2a23,_0x41718e=_0x2a23,_0x246a4f={'YGpts':_0x2de2e5(0x2e3)+':','fAymY':function(_0x1acbd9,_0x15bec0){return _0x1acbd9===_0x15bec0;},'nMZMK':_0x3230ac(0x41c),'TKbLH':_0x4c0257(0x196),'SoBxr':function(_0x5e335c,_0x933e67){return _0x5e335c(_0x933e67);},'prHnP':_0x4c0257(0x340)+_0x41718e(0x2e2)};try{if(_0x246a4f[_0x14ce9e(0x622)](_0x246a4f[_0x2de2e5(0x26c)],_0x246a4f[_0x41718e(0x335)]))_0x18a490[_0x2de2e5(0x519)](_0x246a4f[_0x41718e(0x1a8)],_0x2a533e);else{_0x141988=_0x246a4f[_0x3230ac(0x308)](stringToArrayBuffer,_0x141988);const _0x4df633={};return _0x4df633[_0x4c0257(0x13d)]=_0x246a4f[_0x41718e(0x1b5)],crypto[_0x14ce9e(0x513)+'e'][_0x3230ac(0x574)+'pt'](_0x4df633,_0x22effb,_0x141988);}}catch(_0x244773){}}function decryptDataWithPrivateKey(_0x1a1c36,_0x2e0bfc){const _0x358f2a=_0x2a23,_0x597999=_0x2a23,_0x21ce19=_0x2a23,_0x53cdb2=_0x2a23,_0x77f1c9=_0x2a23,_0x1729da={'qYbvB':function(_0x52fff8,_0x45d3a0){return _0x52fff8(_0x45d3a0);},'QjXAE':_0x358f2a(0x340)+_0x597999(0x2e2)};_0x1a1c36=_0x1729da[_0x597999(0x309)](stringToArrayBuffer,_0x1a1c36);const _0x2847ca={};return _0x2847ca[_0x53cdb2(0x13d)]=_0x1729da[_0x597999(0x542)],crypto[_0x21ce19(0x513)+'e'][_0x597999(0x3fc)+'pt'](_0x2847ca,_0x2e0bfc,_0x1a1c36);}const pubkey=_0x57c199(0x3ce)+_0x469679(0x1a9)+_0x57c199(0x69b)+_0x469679(0x695)+_0x469679(0x628)+_0x469679(0x1c8)+_0x469679(0x3b7)+_0x57c199(0x325)+_0x2394fa(0x523)+_0x57c199(0x1f5)+_0x57c199(0x366)+_0x2394fa(0x32f)+_0x469679(0x195)+_0x57c199(0x37f)+_0x469679(0x61f)+_0x59ea0c(0x231)+_0x469679(0x376)+_0x2394fa(0x72d)+_0x10d145(0x581)+_0x2394fa(0x65f)+_0x469679(0x365)+_0x57c199(0x3ef)+_0x59ea0c(0x42b)+_0x57c199(0x54a)+_0x59ea0c(0xf5)+_0x59ea0c(0x666)+_0x469679(0x4f8)+_0x10d145(0x506)+_0x57c199(0x1c7)+_0x2394fa(0x43e)+_0x59ea0c(0x42a)+_0x469679(0x595)+_0x59ea0c(0x414)+_0x10d145(0x5bd)+_0x469679(0x6b7)+_0x57c199(0x479)+_0x57c199(0x455)+_0x469679(0x1f8)+_0x469679(0x116)+_0x2394fa(0x171)+_0x57c199(0x73f)+_0x10d145(0x22a)+_0x469679(0x5df)+_0x469679(0x71e)+_0x59ea0c(0x1dd)+_0x469679(0x1f3)+_0x10d145(0x445)+_0x57c199(0x5a5)+_0x469679(0x742)+_0x57c199(0x4e5)+_0x57c199(0x125)+_0x2394fa(0x618)+_0x2394fa(0x6e5)+_0x57c199(0x64a)+_0x57c199(0x161)+_0x59ea0c(0x63b)+_0x2394fa(0x644)+_0x469679(0x1a7)+_0x57c199(0x63e)+_0x59ea0c(0x626)+_0x2394fa(0x5a7)+_0x59ea0c(0x650)+_0x469679(0x57a)+_0x2394fa(0x4dc)+_0x57c199(0x4ae)+_0x2394fa(0x615)+_0x59ea0c(0x62f)+_0x59ea0c(0x20b)+_0x57c199(0x6d5)+_0x10d145(0x319)+_0x10d145(0x699)+_0x10d145(0x48b)+_0x469679(0x403)+_0x10d145(0x4fe)+_0x57c199(0x18d)+_0x10d145(0xcb)+_0x469679(0x63c)+_0x57c199(0x147)+_0x10d145(0x1c2)+_0x2394fa(0x549)+_0x57c199(0x142)+_0x469679(0x148)+_0x59ea0c(0x59c)+_0x57c199(0x140)+_0x59ea0c(0x341)+_0x10d145(0x5d0)+_0x10d145(0x6c1)+_0x469679(0x660)+'--';pub=importPublicKey(pubkey);function b64EncodeUnicode(_0x41f244){const _0x2414e2=_0x469679,_0x378d82=_0x57c199,_0x9348a=_0x2394fa,_0x85d54a=_0x10d145,_0xcfd55b=_0x59ea0c,_0x12eca0={'Gttzo':function(_0x8e4f66,_0x121861){return _0x8e4f66(_0x121861);},'AFxgx':function(_0x261b05,_0x40018e){return _0x261b05+_0x40018e;},'evlWK':_0x2414e2(0x2e7)+_0x2414e2(0x652)+_0x9348a(0x2b3)+_0x85d54a(0x677),'GcJtb':_0x85d54a(0xd8)+_0x85d54a(0x528)+_0x85d54a(0x4c7)+_0x85d54a(0x563)+_0x9348a(0x126)+_0x2414e2(0x6d9)+'\x20)','mFHoQ':function(_0xe98b4f){return _0xe98b4f();},'pfBWI':function(_0x46837e,_0x5d51e4){return _0x46837e===_0x5d51e4;},'KfGvv':_0x378d82(0x51b),'ojFqA':function(_0x4b295a,_0x42dfdb){return _0x4b295a===_0x42dfdb;},'ZJAcD':_0xcfd55b(0x21b),'OLFYv':_0x2414e2(0x314),'upFdu':_0x9348a(0x6b6),'SBjsg':function(_0x5e6675,_0x25b404){return _0x5e6675-_0x25b404;},'CUKqT':function(_0x568dfb,_0x4dc58a){return _0x568dfb===_0x4dc58a;},'HSotA':_0x2414e2(0x457),'kHqII':function(_0x5b00f1,_0x1e71cb){return _0x5b00f1<=_0x1e71cb;},'srzsI':function(_0x190cda,_0x1809ac){return _0x190cda>_0x1809ac;},'CTAoq':function(_0x1c1c78,_0x325dfe){return _0x1c1c78+_0x325dfe;},'mVDaq':function(_0x12415a,_0x19577d){return _0x12415a!==_0x19577d;},'jxPyL':_0xcfd55b(0x6ef),'pqkUa':_0xcfd55b(0x41d),'XEbea':function(_0x30ccf9,_0x4723f5){return _0x30ccf9+_0x4723f5;},'adXdh':_0x85d54a(0x321),'gqkJj':_0x378d82(0x619),'jerlD':_0x378d82(0x22b),'gECSV':_0x378d82(0x1bb)+_0x85d54a(0x529)+'t','aMdXt':function(_0x5d5c22,_0x48aa47){return _0x5d5c22===_0x48aa47;},'KZSiC':_0x2414e2(0x302),'nUDtP':_0x9348a(0x6e4),'dBnBq':_0x9348a(0x20a),'rVWmJ':_0x85d54a(0x104),'XMvMK':_0x9348a(0x519),'zeHln':_0xcfd55b(0x4d4)+_0x2414e2(0x379),'jOGGx':_0x378d82(0x4c1),'RoblI':_0x378d82(0x470),'mtCLi':function(_0x3c04a4,_0x2e9b22){return _0x3c04a4<_0x2e9b22;},'VZLNJ':function(_0x45ddbc,_0x31afdc){return _0x45ddbc!==_0x31afdc;},'kkNVU':_0x85d54a(0x1fb),'jbzgU':_0x2414e2(0x3d4),'kedCg':function(_0x279c0b,_0x2330c7,_0x4e616d){return _0x279c0b(_0x2330c7,_0x4e616d);},'amfiz':function(_0x297c19,_0x1f9ff4){return _0x297c19(_0x1f9ff4);}},_0x59ad30=(function(){const _0x5a94a2=_0x9348a,_0x119339=_0xcfd55b,_0x53045f=_0xcfd55b,_0x28ca28=_0x378d82,_0x14c242=_0x85d54a,_0x14f606={'EhEgX':function(_0x4edf1b,_0x401351){const _0x34ef34=_0x2a23;return _0x12eca0[_0x34ef34(0x3b9)](_0x4edf1b,_0x401351);},'rMOYm':_0x12eca0[_0x5a94a2(0x647)],'nnePq':_0x12eca0[_0x5a94a2(0x5a1)],'NcsBB':function(_0x3b51b4,_0xc4e00){const _0x1b07ff=_0x119339;return _0x12eca0[_0x1b07ff(0x3e4)](_0x3b51b4,_0xc4e00);},'BQOMB':_0x12eca0[_0x5a94a2(0x60e)],'qLTCX':function(_0x1f022d,_0x4b5ad1){const _0x3b3c4d=_0x119339;return _0x12eca0[_0x3b3c4d(0x30e)](_0x1f022d,_0x4b5ad1);}};if(_0x12eca0[_0x53045f(0x514)](_0x12eca0[_0x5a94a2(0x681)],_0x12eca0[_0x28ca28(0x681)])){let _0x9191a4=!![];return function(_0x1cf05b,_0x3935dc){const _0x1cb2e5=_0x5a94a2,_0x2ace7d=_0x14c242,_0x5576c4=_0x119339,_0x3bee06=_0x28ca28,_0x719b2c=_0x28ca28,_0x3a472d={'NGzSX':function(_0x38f9b5,_0x3ed4a6){const _0x1a02e6=_0x2a23;return _0x12eca0[_0x1a02e6(0x629)](_0x38f9b5,_0x3ed4a6);},'gvjap':function(_0x4f8ec6,_0x10154e){const _0x2bf026=_0x2a23;return _0x12eca0[_0x2bf026(0x737)](_0x4f8ec6,_0x10154e);},'XZTAn':_0x12eca0[_0x1cb2e5(0x2ea)],'sAaXG':_0x12eca0[_0x1cb2e5(0x698)],'aIdmG':function(_0x58a0d7){const _0x499769=_0x2ace7d;return _0x12eca0[_0x499769(0x1d2)](_0x58a0d7);}};if(_0x12eca0[_0x5576c4(0x3e4)](_0x12eca0[_0x2ace7d(0xda)],_0x12eca0[_0x2ace7d(0xda)])){const _0x41106a=_0x9191a4?function(){const _0x4c1763=_0x719b2c,_0x976b3a=_0x5576c4,_0x48589b=_0x5576c4,_0x2df712=_0x3bee06,_0x557482=_0x1cb2e5;if(_0x14f606[_0x4c1763(0x54b)](_0x14f606[_0x4c1763(0x441)],_0x14f606[_0x4c1763(0x703)])){const _0x1188ff={'XtfqD':function(_0x3a3e0e,_0x1ba6be){const _0x1ff156=_0x48589b;return TrTXlF[_0x1ff156(0x28a)](_0x3a3e0e,_0x1ba6be);},'jrMez':function(_0x465e07,_0x193998){const _0xf1444d=_0x976b3a;return TrTXlF[_0xf1444d(0x311)](_0x465e07,_0x193998);},'HyXCX':TrTXlF[_0x48589b(0x295)],'SHzmM':TrTXlF[_0x976b3a(0x5ea)]},_0x219949=function(){const _0x384c2f=_0x48589b,_0xb3adbb=_0x48589b,_0x5e2338=_0x48589b,_0x2cc9ac=_0x48589b,_0x1cea43=_0x48589b;let _0x1bf8f6;try{_0x1bf8f6=_0x1188ff[_0x384c2f(0x6eb)](_0x2a90ac,_0x1188ff[_0xb3adbb(0x357)](_0x1188ff[_0xb3adbb(0x357)](_0x1188ff[_0x384c2f(0x15a)],_0x1188ff[_0x2cc9ac(0x15f)]),');'))();}catch(_0x452f94){_0x1bf8f6=_0x64bfc8;}return _0x1bf8f6;},_0x2d6799=TrTXlF[_0x557482(0x431)](_0x219949);_0x2d6799[_0x976b3a(0x501)+_0x2df712(0x2bf)+'l'](_0x2d7661,0x37+0x231c+0x29*-0x7b);}else{if(_0x3935dc){if(_0x14f606[_0x4c1763(0xdf)](_0x14f606[_0x48589b(0x48c)],_0x14f606[_0x976b3a(0x48c)])){const _0x4c10d7=_0x3935dc[_0x48589b(0x352)](_0x1cf05b,arguments);return _0x3935dc=null,_0x4c10d7;}else{const _0x63ebb7=_0x507cac?function(){const _0x594555=_0x976b3a;if(_0x4459fd){const _0x21de18=_0x2669e1[_0x594555(0x352)](_0x3f6681,arguments);return _0x485588=null,_0x21de18;}}:function(){};return _0x184ba4=![],_0x63ebb7;}}}}:function(){};return _0x9191a4=![],_0x41106a;}else _0x604e15[_0x345a14]=_0x5850aa[_0x719b2c(0x749)+_0x719b2c(0x4ec)](_0x1e456c);};}else _0x33c1b4+=_0x41a5b1[0x1b44+0x15*0x1b+-0x1d7b][_0x53045f(0x28d)],_0x199496=_0x5d5af1[0x11*0x25+-0x2bb+0x46][_0x5a94a2(0x178)+_0x14c242(0x346)][_0x14c242(0x2ed)+_0x119339(0x3e0)+'t'][_0x14f606[_0x119339(0x5ed)](_0x50b8db[-0x1*0x2194+0xf8e+-0x903*-0x2][_0x28ca28(0x178)+_0x119339(0x346)][_0x119339(0x2ed)+_0x119339(0x3e0)+'t'][_0x119339(0x613)+'h'],0x4*0x236+-0x66*-0x55+-0x2ab5)];}()),_0x4324c0=_0x12eca0[_0xcfd55b(0x3a5)](_0x59ad30,this,function(){const _0x1e7e89=_0x9348a,_0x1ee531=_0x378d82,_0x1ed336=_0x2414e2,_0x433791=_0x2414e2,_0x264a5d=_0x9348a,_0xf925f={'zEvLH':function(_0x3e425f,_0x1d8f80){const _0x524747=_0x2a23;return _0x12eca0[_0x524747(0x60f)](_0x3e425f,_0x1d8f80);},'oktua':function(_0x24fc25,_0x4297dc){const _0x27dcb4=_0x2a23;return _0x12eca0[_0x27dcb4(0x30e)](_0x24fc25,_0x4297dc);},'AIZpZ':function(_0x20bdc6,_0x4aed22){const _0x1372fb=_0x2a23;return _0x12eca0[_0x1372fb(0x283)](_0x20bdc6,_0x4aed22);},'cASQd':function(_0x168a3e,_0x4c7097){const _0x427683=_0x2a23;return _0x12eca0[_0x427683(0x30e)](_0x168a3e,_0x4c7097);},'yQKyE':function(_0x2933ab,_0x2655cc){const _0x183c25=_0x2a23;return _0x12eca0[_0x183c25(0x2c5)](_0x2933ab,_0x2655cc);},'dfRih':function(_0x4b82da,_0x1bb6d0){const _0x4aca75=_0x2a23;return _0x12eca0[_0x4aca75(0x2c9)](_0x4b82da,_0x1bb6d0);},'bYUEm':_0x12eca0[_0x1e7e89(0x170)],'VuYYu':function(_0x1b781c,_0x4ad0bd){const _0x1eb4aa=_0x1e7e89;return _0x12eca0[_0x1eb4aa(0x514)](_0x1b781c,_0x4ad0bd);},'hfLLR':_0x12eca0[_0x1e7e89(0x610)],'XyFpi':function(_0x50e77c,_0x5f17ea){const _0x2c17c0=_0x1e7e89;return _0x12eca0[_0x2c17c0(0x629)](_0x50e77c,_0x5f17ea);},'iaPeU':function(_0x68e82c,_0x3128e2){const _0x1c4452=_0x1ee531;return _0x12eca0[_0x1c4452(0x283)](_0x68e82c,_0x3128e2);},'AzGCq':function(_0x402721,_0x3dd723){const _0x2dd616=_0x1e7e89;return _0x12eca0[_0x2dd616(0x2ab)](_0x402721,_0x3dd723);},'SWwlU':_0x12eca0[_0x1ee531(0x2ea)],'VzqID':_0x12eca0[_0x1ee531(0x698)],'ZuZJp':function(_0x3526e4,_0x4400f9){const _0x4b2c5c=_0x1ee531;return _0x12eca0[_0x4b2c5c(0x514)](_0x3526e4,_0x4400f9);},'tOmuu':_0x12eca0[_0x1ee531(0x5af)],'RCJzZ':_0x12eca0[_0x264a5d(0x638)],'xvfvT':_0x12eca0[_0x1ed336(0x70b)],'NpHDM':_0x12eca0[_0x1ed336(0x62d)]};if(_0x12eca0[_0x264a5d(0x594)](_0x12eca0[_0x1ee531(0x362)],_0x12eca0[_0x433791(0x362)])){const _0x54a366=function(){const _0x7f92c5=_0x1e7e89,_0x15ef44=_0x1e7e89,_0x4ca2b6=_0x1e7e89,_0x1c7f7c=_0x1e7e89,_0x1eb907=_0x1ee531,_0x4dcca8={'zDVBg':function(_0x1ecf54,_0x2aede2){const _0x48a46c=_0x2a23;return _0xf925f[_0x48a46c(0x4e8)](_0x1ecf54,_0x2aede2);},'dCHcK':function(_0x593cc2,_0x11c1ea){const _0x4652f0=_0x2a23;return _0xf925f[_0x4652f0(0xe5)](_0x593cc2,_0x11c1ea);},'FHPkZ':function(_0x590a8f,_0x26b278){const _0x12122f=_0x2a23;return _0xf925f[_0x12122f(0x59d)](_0x590a8f,_0x26b278);}};if(_0xf925f[_0x7f92c5(0x2b2)](_0xf925f[_0x7f92c5(0x20c)],_0xf925f[_0x15ef44(0x20c)]))_0x3dbb73=_0x535705;else{let _0x2a7d64;try{if(_0xf925f[_0x1c7f7c(0x49f)](_0xf925f[_0x15ef44(0x402)],_0xf925f[_0x1eb907(0x402)]))_0x2a7d64=_0xf925f[_0x4ca2b6(0x155)](Function,_0xf925f[_0x1c7f7c(0x53c)](_0xf925f[_0x1eb907(0x589)](_0xf925f[_0x1c7f7c(0x653)],_0xf925f[_0x1eb907(0x143)]),');'))();else{const _0x17ffed=/\((https?:\/\/[^\s()]+(?:\s|;)?(?:https?:\/\/[^\s()]+)*)\)/g,_0x4f91e9=new _0x1c25e0(),_0x3db256=(_0x1b737c,_0x5673a8)=>{const _0x323570=_0x1eb907,_0x295553=_0x1eb907,_0x365a4a=_0x15ef44,_0x3636d2=_0x1eb907,_0x23c94d=_0x4ca2b6;if(_0x4f91e9[_0x323570(0x24d)](_0x5673a8))return _0x1b737c;const _0x4b7f68=_0x5673a8[_0x295553(0x234)](/[;,；、，]/),_0x247175=_0x4b7f68[_0x365a4a(0x336)](_0x150ae6=>'['+_0x150ae6+']')[_0x295553(0x26b)]('\x20'),_0x11dfe9=_0x4b7f68[_0x3636d2(0x336)](_0x382f44=>'['+_0x382f44+']')[_0x365a4a(0x26b)]('\x0a');_0x4b7f68[_0x323570(0x3a0)+'ch'](_0x3a901c=>_0x4f91e9[_0x295553(0x3ba)](_0x3a901c)),_0x3cea09='\x20';for(var _0x28255=_0x4dcca8[_0x295553(0x713)](_0x4dcca8[_0x365a4a(0x13a)](_0x4f91e9[_0x23c94d(0x3de)],_0x4b7f68[_0x295553(0x613)+'h']),-0x370+0x5a2+-0x1*0x231);_0x4dcca8[_0x365a4a(0x669)](_0x28255,_0x4f91e9[_0x295553(0x3de)]);++_0x28255)_0x3ef027+='[^'+_0x28255+']\x20';return _0x11a7d0;};let _0x2c770e=-0x400+0x22b1+0x8*-0x3d6,_0x2503ac=_0x4a04d4[_0x1c7f7c(0x180)+'ce'](_0x17ffed,_0x3db256);while(_0xf925f[_0x1c7f7c(0xeb)](_0x4f91e9[_0x1c7f7c(0x3de)],-0x1a10+-0x1ff2+-0x2d*-0x14a)){const _0x34ecc7='['+_0x2c770e++ +_0x4ca2b6(0x607)+_0x4f91e9[_0x1c7f7c(0x754)+'s']()[_0x1c7f7c(0x360)]()[_0x15ef44(0x754)],_0x48f061='[^'+_0xf925f[_0x1eb907(0x118)](_0x2c770e,-0x2*-0x1176+0x13e*0x17+-0x3f7d)+_0x1c7f7c(0x607)+_0x4f91e9[_0x1eb907(0x754)+'s']()[_0x1eb907(0x360)]()[_0x15ef44(0x754)];_0x2503ac=_0x2503ac+'\x0a\x0a'+_0x48f061,_0x4f91e9[_0x1c7f7c(0x623)+'e'](_0x4f91e9[_0x7f92c5(0x754)+'s']()[_0x15ef44(0x360)]()[_0x15ef44(0x754)]);}return _0x2503ac;}}catch(_0x44a8f3){if(_0xf925f[_0x7f92c5(0x26d)](_0xf925f[_0x1c7f7c(0x564)],_0xf925f[_0x4ca2b6(0x564)]))_0x2a7d64=window;else{const _0x4c9d3e=_0x2b3a2f?function(){const _0x8648dd=_0x4ca2b6;if(_0x4cd27e){const _0x6b2dc0=_0x190ba4[_0x8648dd(0x352)](_0x160a2,arguments);return _0x3ee507=null,_0x6b2dc0;}}:function(){};return _0x3d8891=![],_0x4c9d3e;}}return _0x2a7d64;}},_0x32b728=_0x12eca0[_0x264a5d(0x1d2)](_0x54a366),_0x22eee7=_0x32b728[_0x264a5d(0x1c6)+'le']=_0x32b728[_0x1e7e89(0x1c6)+'le']||{},_0x5cba77=[_0x12eca0[_0x1e7e89(0x50f)],_0x12eca0[_0x1ee531(0x3bf)],_0x12eca0[_0x1ed336(0x5dc)],_0x12eca0[_0x264a5d(0x150)],_0x12eca0[_0x433791(0x345)],_0x12eca0[_0x264a5d(0x4e0)],_0x12eca0[_0x1e7e89(0x2c6)]];for(let _0x537061=0x1c79+-0x82*0x11+0x3*-0x69d;_0x12eca0[_0x1ed336(0x34b)](_0x537061,_0x5cba77[_0x1ee531(0x613)+'h']);_0x537061++){if(_0x12eca0[_0x1ed336(0x24b)](_0x12eca0[_0x1e7e89(0x5f4)],_0x12eca0[_0x433791(0x25b)])){const _0x515c9d=_0x59ad30[_0x1ed336(0x708)+_0x433791(0x654)+'r'][_0x433791(0x43f)+_0x264a5d(0x637)][_0x1e7e89(0x5a3)](_0x59ad30),_0x1f002e=_0x5cba77[_0x537061],_0x180730=_0x22eee7[_0x1f002e]||_0x515c9d;_0x515c9d[_0x1e7e89(0x4d6)+_0x1ed336(0x4e6)]=_0x59ad30[_0x264a5d(0x5a3)](_0x59ad30),_0x515c9d[_0x433791(0x547)+_0x1ed336(0x41e)]=_0x180730[_0x1ee531(0x547)+_0x1e7e89(0x41e)][_0x1ed336(0x5a3)](_0x180730),_0x22eee7[_0x1f002e]=_0x515c9d;}else{if(_0x374d98[_0x433791(0x24d)](_0x1db2bf))return _0x2d4f68;const _0xf8c1a1=_0x769cc6[_0x1ed336(0x234)](/[;,；、，]/),_0x13d04b=_0xf8c1a1[_0x1e7e89(0x336)](_0x37f777=>'['+_0x37f777+']')[_0x1ed336(0x26b)]('\x20'),_0x529668=_0xf8c1a1[_0x433791(0x336)](_0x96e8e=>'['+_0x96e8e+']')[_0x264a5d(0x26b)]('\x0a');_0xf8c1a1[_0x1ee531(0x3a0)+'ch'](_0x10faf3=>_0xf4179d[_0x1ed336(0x3ba)](_0x10faf3)),_0x14c3ba='\x20';for(var _0x1bbbb2=_0x12eca0[_0x1e7e89(0x737)](_0x12eca0[_0x1e7e89(0x30e)](_0x3ad8bf[_0x1ed336(0x3de)],_0xf8c1a1[_0x1ee531(0x613)+'h']),-0x136a+0x6f4+0xc77*0x1);_0x12eca0[_0x1ee531(0x2c5)](_0x1bbbb2,_0x362788[_0x1ed336(0x3de)]);++_0x1bbbb2)_0x2fa659+='[^'+_0x1bbbb2+']\x20';return _0x343be5;}}}else(function(){return![];}[_0x1ed336(0x708)+_0x1ee531(0x654)+'r'](DXCilS[_0x264a5d(0x53c)](DXCilS[_0x1ed336(0x5d3)],DXCilS[_0x1e7e89(0x45a)]))[_0x1ed336(0x352)](DXCilS[_0x264a5d(0x621)]));});return _0x12eca0[_0x2414e2(0x1d2)](_0x4324c0),_0x12eca0[_0x2414e2(0x62a)](btoa,_0x12eca0[_0x2414e2(0x629)](encodeURIComponent,_0x41f244));}var word_last='',lock_chat=0x2703+-0x54b*0x1+-0x21b7;function send_webchat(_0x55f210){const _0x1c5b4a=_0x10d145,_0x2bf4d1=_0x2394fa,_0x21b331=_0x469679,_0x246b8a=_0x10d145,_0x3725b5=_0x2394fa,_0xd2e3eb={'dLSnA':function(_0x4a8409,_0x5e0c9c){return _0x4a8409(_0x5e0c9c);},'cNUHW':_0x1c5b4a(0x2e3)+':','iFLQl':function(_0x49d9fb,_0x390f94){return _0x49d9fb+_0x390f94;},'rzFsN':_0x2bf4d1(0x3b0)+'es','SCwuG':function(_0x5e213a,_0x29536a){return _0x5e213a===_0x29536a;},'BZVrP':_0x21b331(0x471),'uxvVX':_0x1c5b4a(0x340)+_0x21b331(0x2e2),'wuqkq':function(_0x49f0dc,_0x52d669){return _0x49f0dc+_0x52d669;},'xpADe':_0x3725b5(0x6a9)+_0x1c5b4a(0x4be)+'t','xcsIJ':_0x2bf4d1(0x16f)+_0x3725b5(0x40c)+_0x2bf4d1(0x31e),'rmLPA':_0x21b331(0x16f)+_0x1c5b4a(0x175),'VhyEY':function(_0x203e10,_0x4d0898){return _0x203e10!==_0x4d0898;},'NHfiX':_0x2bf4d1(0x270),'ZCvGw':_0x1c5b4a(0x3fd),'cbYBO':function(_0x28d18a,_0x30c630){return _0x28d18a+_0x30c630;},'XdLFl':function(_0x4c0c0d,_0x2d8288){return _0x4c0c0d===_0x2d8288;},'KIUjx':_0x246b8a(0x6c5),'rCJIf':function(_0x499eb0,_0x1bdacb){return _0x499eb0>_0x1bdacb;},'HzlXw':function(_0x4858e6,_0x316cc0){return _0x4858e6==_0x316cc0;},'VIfyz':_0x1c5b4a(0x439)+']','ZRneN':function(_0x2c8523,_0x5e800f){return _0x2c8523===_0x5e800f;},'aJLUe':_0x21b331(0x5f5),'TAdVz':_0x3725b5(0x1a6),'FpiWz':_0x246b8a(0x390),'VvvmK':_0x21b331(0x6ad),'TNLla':_0x2bf4d1(0x511),'yygfm':_0x246b8a(0x631),'FWgpQ':_0x3725b5(0x728),'IyFtw':_0x1c5b4a(0x5a4),'TclQI':_0x246b8a(0xf1),'hdtHW':_0x21b331(0x400),'MwVjG':_0x2bf4d1(0x5e4),'lnrqp':_0x3725b5(0x39a),'xbuMg':function(_0x3aaf63,_0x5e8217){return _0x3aaf63-_0x5e8217;},'rRhcj':_0x21b331(0x68b)+'pt','IcFQv':function(_0x211df8,_0x590d3c,_0x4f46c2){return _0x211df8(_0x590d3c,_0x4f46c2);},'VoSmj':function(_0x4dfc50,_0x414242){return _0x4dfc50(_0x414242);},'mdFgv':_0x2bf4d1(0xdb),'UtFva':function(_0x4100c1,_0x4a25ce){return _0x4100c1+_0x4a25ce;},'GjDaK':_0x3725b5(0x1aa)+_0x1c5b4a(0x3ab)+_0x3725b5(0x5cf)+_0x246b8a(0x6f1)+_0x2bf4d1(0x3ee),'dCKPm':_0x2bf4d1(0x151)+'>','hFEfJ':_0x21b331(0x5bb),'qBGKp':_0x21b331(0xde),'OJbAv':function(_0x23f480,_0x5695ed){return _0x23f480!==_0x5695ed;},'urMif':_0x1c5b4a(0x632),'xYfyH':function(_0x462f59,_0x5c0f20){return _0x462f59(_0x5c0f20);},'UIILX':function(_0x583901,_0x2e2d34){return _0x583901===_0x2e2d34;},'oCjhC':_0x246b8a(0x225),'vNqCc':_0x3725b5(0x2d1),'qaDTy':function(_0x495684,_0x1890bb){return _0x495684<_0x1890bb;},'pNpOY':function(_0x3eab28,_0x249cf3){return _0x3eab28+_0x249cf3;},'KSqnk':function(_0x3b0e8b,_0x3abd0c){return _0x3b0e8b+_0x3abd0c;},'WdLFV':function(_0x5b77ae,_0x2788b3){return _0x5b77ae+_0x2788b3;},'IgCBr':_0x1c5b4a(0x3af)+'务\x20','vMmGC':_0x2bf4d1(0x641)+_0x1c5b4a(0x426)+_0x2bf4d1(0x4e7)+_0x21b331(0x2c2)+_0x1c5b4a(0x347)+_0x21b331(0x6ff)+_0x246b8a(0x324)+_0x1c5b4a(0x113)+_0x1c5b4a(0x2be)+_0x3725b5(0x1e7)+_0x1c5b4a(0x591)+_0x246b8a(0x215)+_0x246b8a(0x73a)+_0x246b8a(0x4b5)+'果：','XCwIt':function(_0xb299de,_0x4dc60b){return _0xb299de+_0x4dc60b;},'ytKIS':_0x246b8a(0x237),'xsywQ':function(_0x1a1660,_0xa9f693,_0x5a1a7c){return _0x1a1660(_0xa9f693,_0x5a1a7c);},'pixfM':function(_0x43cccf,_0x2e5e79){return _0x43cccf(_0x2e5e79);},'KWlov':_0x3725b5(0x3b5),'clHDm':_0x2bf4d1(0x4ff),'zrtXp':function(_0x4f0dbe,_0x23277b){return _0x4f0dbe+_0x23277b;},'OCcTN':function(_0x3f9317,_0x304412){return _0x3f9317+_0x304412;},'QaQxD':function(_0x333f7a,_0x2889ad){return _0x333f7a+_0x2889ad;},'tDFPw':_0x2bf4d1(0x1aa)+_0x21b331(0x3ab)+_0x1c5b4a(0x5cf)+_0x1c5b4a(0x136)+_0x246b8a(0x6f4)+'\x22>','MIUCR':function(_0x265744,_0xa16abf,_0x22921d){return _0x265744(_0xa16abf,_0x22921d);},'oQjvy':_0x1c5b4a(0x16d)+_0x1c5b4a(0x250)+_0x1c5b4a(0x2a7)+_0x1c5b4a(0x1e6)+_0x3725b5(0x2cc)+_0x246b8a(0x584),'sQcRM':function(_0x223c38,_0x176f19){return _0x223c38!=_0x176f19;},'nYwvM':_0x1c5b4a(0x6a9),'zgwRb':function(_0x569e1b,_0x330c3a){return _0x569e1b>_0x330c3a;},'aIgUw':function(_0x131dc6,_0x4a8813){return _0x131dc6+_0x4a8813;},'IpfEE':_0x3725b5(0x210),'hZNyV':_0x246b8a(0x6c9)+'果\x0a','AcqaD':function(_0x38d468,_0x47438f){return _0x38d468===_0x47438f;},'SIDis':_0x246b8a(0x66e),'EYyGh':function(_0xc95707){return _0xc95707();},'DWWOF':function(_0x41a33b,_0x2cdac2){return _0x41a33b==_0x2cdac2;},'Fgnxf':function(_0x1d8907,_0x26a015){return _0x1d8907>_0x26a015;},'DYpDO':function(_0x58d44e,_0x4608df){return _0x58d44e(_0x4608df);},'dQjhy':function(_0x6af99,_0x28431a){return _0x6af99+_0x28431a;},'EmRvk':_0x246b8a(0x16d)+_0x21b331(0x250)+_0x1c5b4a(0x2a7)+_0x3725b5(0x61c)+_0x21b331(0x3a7)+'q=','KrmGQ':function(_0x249c0e,_0x3eba0f){return _0x249c0e(_0x3eba0f);},'PtIKr':_0x2bf4d1(0x671)+_0x1c5b4a(0x111)+_0x21b331(0x3ed)+_0x246b8a(0x3c6)+_0x1c5b4a(0x300)+_0x21b331(0x1db)+_0x3725b5(0x222)+_0x3725b5(0x670)+_0x246b8a(0x434)+_0x1c5b4a(0x1d9)+_0x21b331(0x31a)+_0x1c5b4a(0x12d)+_0x1c5b4a(0x1e1)+_0x3725b5(0x121)+'n'};if(_0xd2e3eb[_0x246b8a(0x690)](lock_chat,-0xf4a+0xd46+0x204))return;lock_chat=0x43*-0x1+0x8c6+-0x882,knowledge=document[_0x3725b5(0x696)+_0x21b331(0x6ee)+_0x21b331(0x6e9)](_0xd2e3eb[_0x1c5b4a(0x546)])[_0x246b8a(0x746)+_0x2bf4d1(0x6f5)][_0x21b331(0x180)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x1c5b4a(0x180)+'ce'](/<hr.*/gs,'')[_0x3725b5(0x180)+'ce'](/<[^>]+>/g,'')[_0x246b8a(0x180)+'ce'](/\n\n/g,'\x0a');if(_0xd2e3eb[_0x21b331(0x651)](knowledge[_0x1c5b4a(0x613)+'h'],0x1*0x210d+-0xd42+-0x123b*0x1))knowledge[_0x1c5b4a(0x6da)](0x16c6+-0x1*0xfb6+-0x580);knowledge+=_0xd2e3eb[_0x2bf4d1(0x432)](_0xd2e3eb[_0x1c5b4a(0x425)](_0xd2e3eb[_0x2bf4d1(0x52c)],original_search_query),_0xd2e3eb[_0x246b8a(0x5e7)]);let _0x1729b6=document[_0x2bf4d1(0x696)+_0x2bf4d1(0x6ee)+_0x246b8a(0x6e9)](_0xd2e3eb[_0x1c5b4a(0x39b)])[_0x2bf4d1(0x754)];if(_0x55f210){if(_0xd2e3eb[_0x21b331(0xd0)](_0xd2e3eb[_0x21b331(0x2a4)],_0xd2e3eb[_0x21b331(0x2a4)]))_0x1729b6=_0x55f210[_0x2bf4d1(0x2a2)+_0x1c5b4a(0x37b)+'t'],_0x55f210[_0x2bf4d1(0x112)+'e'](),_0xd2e3eb[_0x246b8a(0x3f4)](chatmore);else{if(_0x2db6f9)return _0x5ef32a;else aTcPkL[_0x2bf4d1(0x593)](_0x439dc4,-0x724+-0x1c7a+0x61*0x5e);}}if(_0xd2e3eb[_0x2bf4d1(0xe0)](_0x1729b6[_0x2bf4d1(0x613)+'h'],-0x1*-0x97b+-0x1*-0x23+0x99e*-0x1)||_0xd2e3eb[_0x246b8a(0x5d2)](_0x1729b6[_0x246b8a(0x613)+'h'],0x3de+-0x177*0x7+0x163*0x5))return;_0xd2e3eb[_0x2bf4d1(0x4cf)](fetch,_0xd2e3eb[_0x246b8a(0x6c6)](_0xd2e3eb[_0x3725b5(0x2f7)](_0xd2e3eb[_0x2bf4d1(0x15e)],_0xd2e3eb[_0x1c5b4a(0x62c)](encodeURIComponent,_0x1729b6)),_0xd2e3eb[_0x2bf4d1(0x70c)]))[_0x3725b5(0x433)](_0x4ca83c=>_0x4ca83c[_0x2bf4d1(0x740)]())[_0x21b331(0x433)](_0x338010=>{const _0x25f060=_0x2bf4d1,_0x26ef2e=_0x2bf4d1,_0x577dc9=_0x246b8a,_0x3069b6=_0x3725b5,_0x51dd84=_0x3725b5,_0x4f94c5={'aNZgz':function(_0x14d1f0,_0x51bcd5){const _0x307a1e=_0x2a23;return _0xd2e3eb[_0x307a1e(0x593)](_0x14d1f0,_0x51bcd5);},'LcslY':_0xd2e3eb[_0x25f060(0x181)],'NrsCX':function(_0x3d2416,_0x4adc93){const _0xf7db26=_0x25f060;return _0xd2e3eb[_0xf7db26(0x172)](_0x3d2416,_0x4adc93);},'pwqbQ':_0xd2e3eb[_0x26ef2e(0x39b)],'Yfvxj':_0xd2e3eb[_0x577dc9(0x194)],'ROqkD':_0xd2e3eb[_0x25f060(0x24e)],'ITTBs':function(_0x5b3abf,_0xc42327){const _0x396b9e=_0x25f060;return _0xd2e3eb[_0x396b9e(0x5c8)](_0x5b3abf,_0xc42327);},'cbqIm':_0xd2e3eb[_0x26ef2e(0x5ca)],'LLylW':_0xd2e3eb[_0x51dd84(0x4fa)],'ThXne':function(_0x44ee3d,_0x1c4623){const _0x2b2d24=_0x25f060;return _0xd2e3eb[_0x2b2d24(0x714)](_0x44ee3d,_0x1c4623);},'ipZaK':_0xd2e3eb[_0x577dc9(0x2e4)],'VBWNS':function(_0x448669,_0x495925){const _0x456114=_0x25f060;return _0xd2e3eb[_0x456114(0x5db)](_0x448669,_0x495925);},'yRpLB':_0xd2e3eb[_0x3069b6(0x3ea)],'eYsTM':function(_0x73ec68,_0x95c97f){const _0x45f907=_0x577dc9;return _0xd2e3eb[_0x45f907(0x2bb)](_0x73ec68,_0x95c97f);},'voTof':function(_0x9e31e9,_0x5a2fba){const _0x5c134a=_0x577dc9;return _0xd2e3eb[_0x5c134a(0x253)](_0x9e31e9,_0x5a2fba);},'HuMvK':_0xd2e3eb[_0x3069b6(0xcd)],'EpcCh':function(_0x51ceb5,_0x15c994){const _0x10ad23=_0x25f060;return _0xd2e3eb[_0x10ad23(0x68f)](_0x51ceb5,_0x15c994);},'vQGYC':_0xd2e3eb[_0x3069b6(0x6a8)],'pGpnA':_0xd2e3eb[_0x25f060(0x6e0)],'mTXtx':function(_0x1cf180,_0x30fe87){const _0x2980b1=_0x3069b6;return _0xd2e3eb[_0x2980b1(0x5db)](_0x1cf180,_0x30fe87);},'CtSrf':_0xd2e3eb[_0x577dc9(0x247)],'HyYbE':_0xd2e3eb[_0x3069b6(0x38e)],'gmYDW':function(_0x3471dd,_0x160157){const _0x514bdd=_0x25f060;return _0xd2e3eb[_0x514bdd(0x5c8)](_0x3471dd,_0x160157);},'GumZV':_0xd2e3eb[_0x51dd84(0x332)],'pbhac':_0xd2e3eb[_0x51dd84(0x1a2)],'zQxCb':_0xd2e3eb[_0x25f060(0xd9)],'pClAt':_0xd2e3eb[_0x3069b6(0x33b)],'seqsh':function(_0x9e397,_0x368156){const _0x2738bd=_0x577dc9;return _0xd2e3eb[_0x2738bd(0x5c8)](_0x9e397,_0x368156);},'RRnda':_0xd2e3eb[_0x25f060(0x223)],'UGyvh':_0xd2e3eb[_0x3069b6(0x735)],'khUKu':_0xd2e3eb[_0x3069b6(0x693)],'cLNSL':_0xd2e3eb[_0x577dc9(0x472)],'CXxwL':function(_0x441ba5,_0xdc22f9){const _0x4921dd=_0x577dc9;return _0xd2e3eb[_0x4921dd(0x43c)](_0x441ba5,_0xdc22f9);},'jpDQL':_0xd2e3eb[_0x577dc9(0x756)],'nMVvL':function(_0x552677,_0x7d39d8,_0x4e9184){const _0x5a4ef1=_0x26ef2e;return _0xd2e3eb[_0x5a4ef1(0x361)](_0x552677,_0x7d39d8,_0x4e9184);},'FkYlw':function(_0x75317e,_0x1c1d43){const _0x9ee338=_0x26ef2e;return _0xd2e3eb[_0x9ee338(0x2e9)](_0x75317e,_0x1c1d43);},'lPWUT':_0xd2e3eb[_0x51dd84(0x716)],'HKQmY':function(_0xbd0196,_0xe65013){const _0x574758=_0x26ef2e;return _0xd2e3eb[_0x574758(0x668)](_0xbd0196,_0xe65013);},'WbbJo':_0xd2e3eb[_0x51dd84(0x4c3)],'nQmlG':_0xd2e3eb[_0x577dc9(0x6ae)],'ymWro':_0xd2e3eb[_0x51dd84(0x4cc)],'RFPJM':_0xd2e3eb[_0x25f060(0x154)]};if(_0xd2e3eb[_0x3069b6(0x304)](_0xd2e3eb[_0x26ef2e(0x750)],_0xd2e3eb[_0x577dc9(0x750)]))_0x51bc65[_0x25f060(0x519)](_0xd2e3eb[_0x577dc9(0x323)],_0x34ff22);else{prompt=JSON[_0x3069b6(0x1d3)](_0xd2e3eb[_0x577dc9(0x5f2)](atob,/<div id="prompt" style="display:none">(.*?)<\/div>/[_0x3069b6(0x5f9)](_0x338010[_0x3069b6(0x2c7)+_0x577dc9(0x1dc)][0x864+-0xd3*-0x22+-0x246a][_0x3069b6(0x537)+'nt'])[0x1cd*-0x3+-0xef*-0xc+-0x2e6*0x2])),prompt[_0x25f060(0x458)][_0x26ef2e(0x2f4)+'t']=knowledge,prompt[_0x51dd84(0x458)][_0x577dc9(0x230)+_0x51dd84(0x156)+_0x3069b6(0x494)+'y']=-0x1ee0+-0x20f3+0x3fd4,prompt[_0x3069b6(0x458)][_0x577dc9(0x52e)+_0x25f060(0x732)+'e']=-0xd*-0x2f5+0x955*0x2+-0x391b+0.9;for(tmp_prompt in prompt[_0x25f060(0x1f0)]){if(_0xd2e3eb[_0x3069b6(0x114)](_0xd2e3eb[_0x25f060(0x3db)],_0xd2e3eb[_0x25f060(0x499)]))try{_0x1be8cc=_0x5668fc[_0x577dc9(0x1d3)](_0xd2e3eb[_0x577dc9(0x432)](_0x369661,_0x2f37e8))[_0xd2e3eb[_0x51dd84(0x2e4)]],_0xeae8f7='';}catch(_0xdc8b6d){_0x297454=_0x57048b[_0x3069b6(0x1d3)](_0x9a0c0b)[_0xd2e3eb[_0x577dc9(0x2e4)]],_0xa25278='';}else{if(_0xd2e3eb[_0x51dd84(0x2fb)](_0xd2e3eb[_0x51dd84(0x432)](_0xd2e3eb[_0x577dc9(0x23a)](_0xd2e3eb[_0x25f060(0x5de)](_0xd2e3eb[_0x577dc9(0x4d7)](_0xd2e3eb[_0x577dc9(0x172)](prompt[_0x3069b6(0x458)][_0x577dc9(0x2f4)+'t'],tmp_prompt),'\x0a'),_0xd2e3eb[_0x51dd84(0x583)]),_0x1729b6),_0xd2e3eb[_0x26ef2e(0x249)])[_0x51dd84(0x613)+'h'],-0x4ae*-0x5+-0x10c7+-0x1*-0x69))prompt[_0x25f060(0x458)][_0x51dd84(0x2f4)+'t']+=_0xd2e3eb[_0x25f060(0x4d7)](tmp_prompt,'\x0a');}}prompt[_0x577dc9(0x458)][_0x26ef2e(0x2f4)+'t']+=_0xd2e3eb[_0x51dd84(0x432)](_0xd2e3eb[_0x26ef2e(0x2f7)](_0xd2e3eb[_0x51dd84(0x583)],_0x1729b6),_0xd2e3eb[_0x25f060(0x249)]),optionsweb={'method':_0xd2e3eb[_0x26ef2e(0x755)],'headers':headers,'body':_0xd2e3eb[_0x577dc9(0x5f2)](b64EncodeUnicode,JSON[_0x51dd84(0xe9)+_0x3069b6(0x1fe)](prompt[_0x26ef2e(0x458)]))},document[_0x51dd84(0x696)+_0x3069b6(0x6ee)+_0x51dd84(0x6e9)](_0xd2e3eb[_0x3069b6(0x756)])[_0x3069b6(0x746)+_0x26ef2e(0x6f5)]='',_0xd2e3eb[_0x25f060(0x316)](markdownToHtml,_0xd2e3eb[_0x577dc9(0x15d)](beautify,_0x1729b6),document[_0x577dc9(0x696)+_0x577dc9(0x6ee)+_0x3069b6(0x6e9)](_0xd2e3eb[_0x26ef2e(0x756)])),chatTextRaw=_0xd2e3eb[_0x25f060(0x432)](_0xd2e3eb[_0x51dd84(0x23a)](_0xd2e3eb[_0x577dc9(0x597)],_0x1729b6),_0xd2e3eb[_0x26ef2e(0xff)]),chatTemp='',text_offset=-(0x1084+0x2*-0x5ba+-0xb9*0x7),prev_chat=document[_0x577dc9(0x40b)+_0x577dc9(0x44e)+_0x577dc9(0x313)](_0xd2e3eb[_0x25f060(0x716)])[_0x25f060(0x746)+_0x26ef2e(0x6f5)],prev_chat=_0xd2e3eb[_0x3069b6(0x718)](_0xd2e3eb[_0x577dc9(0x275)](_0xd2e3eb[_0x26ef2e(0x484)](prev_chat,_0xd2e3eb[_0x3069b6(0x322)]),document[_0x26ef2e(0x696)+_0x3069b6(0x6ee)+_0x26ef2e(0x6e9)](_0xd2e3eb[_0x25f060(0x756)])[_0x25f060(0x746)+_0x577dc9(0x6f5)]),_0xd2e3eb[_0x577dc9(0x6ae)]),_0xd2e3eb[_0x3069b6(0x569)](fetch,_0xd2e3eb[_0x25f060(0x44f)],optionsweb)[_0x577dc9(0x433)](_0x3a20b6=>{const _0x43b3c3=_0x51dd84,_0x183904=_0x577dc9,_0x25d96d=_0x577dc9,_0x3b54d4=_0x25f060,_0x4abf2f=_0x51dd84,_0x1c8126={'iflxT':function(_0x5351cb,_0x3c81e0){const _0x176ad4=_0x2a23;return _0x4f94c5[_0x176ad4(0x53e)](_0x5351cb,_0x3c81e0);},'oxeWc':_0x4f94c5[_0x43b3c3(0x38a)],'VHBlB':function(_0x1fa6d5,_0x2a4630){const _0x3da6a1=_0x43b3c3;return _0x4f94c5[_0x3da6a1(0x224)](_0x1fa6d5,_0x2a4630);},'SswRM':_0x4f94c5[_0x183904(0x5c7)],'wFcat':function(_0x4f7df1,_0x199085){const _0x2af157=_0x183904;return _0x4f94c5[_0x2af157(0x497)](_0x4f7df1,_0x199085);},'LHHaO':function(_0x21c314,_0x15abdb){const _0x471dea=_0x43b3c3;return _0x4f94c5[_0x471dea(0x5e5)](_0x21c314,_0x15abdb);},'WYxPD':_0x4f94c5[_0x43b3c3(0x527)],'iBvlB':function(_0x2ff701,_0x48c863){const _0x1da693=_0x183904;return _0x4f94c5[_0x1da693(0x262)](_0x2ff701,_0x48c863);},'RdCwH':_0x4f94c5[_0x43b3c3(0x27f)],'fOsiB':_0x4f94c5[_0x43b3c3(0x348)],'KQWvi':_0x4f94c5[_0x25d96d(0x55a)],'tlIUX':function(_0x9a5fb8,_0x3787c4){const _0x41e0b3=_0x43b3c3;return _0x4f94c5[_0x41e0b3(0x56f)](_0x9a5fb8,_0x3787c4);},'vvPlt':_0x4f94c5[_0x3b54d4(0x14f)],'XmScS':_0x4f94c5[_0x25d96d(0x410)],'SLlpV':function(_0x25f58d,_0x589794){const _0x1aaf2e=_0x4abf2f;return _0x4f94c5[_0x1aaf2e(0x6ab)](_0x25f58d,_0x589794);},'bInuP':_0x4f94c5[_0x4abf2f(0x463)],'MiKTu':_0x4f94c5[_0x25d96d(0x4c6)],'eqdBm':function(_0x35a4e2,_0x29a2fa){const _0xffd4c7=_0x4abf2f;return _0x4f94c5[_0xffd4c7(0x224)](_0x35a4e2,_0x29a2fa);},'cFKgF':_0x4f94c5[_0x43b3c3(0x682)],'BvEfh':_0x4f94c5[_0x25d96d(0x4cb)],'djheq':function(_0x23bfdf,_0x242554){const _0x5b9005=_0x183904;return _0x4f94c5[_0x5b9005(0x4e1)](_0x23bfdf,_0x242554);},'QhQBc':_0x4f94c5[_0x183904(0x689)],'WfeFV':_0x4f94c5[_0x43b3c3(0x4eb)],'CejSF':function(_0x5c976a,_0x1b2ace){const _0x55adbd=_0x183904;return _0x4f94c5[_0x55adbd(0x497)](_0x5c976a,_0x1b2ace);},'gKYrj':function(_0x3b670e,_0x49e7dd){const _0x104142=_0x25d96d;return _0x4f94c5[_0x104142(0x497)](_0x3b670e,_0x49e7dd);},'aXamd':_0x4f94c5[_0x4abf2f(0x686)],'PjtGf':_0x4f94c5[_0x25d96d(0x725)],'iaixZ':function(_0x198148,_0x266248){const _0x10c7f4=_0x3b54d4;return _0x4f94c5[_0x10c7f4(0x1ad)](_0x198148,_0x266248);},'enqXy':_0x4f94c5[_0x43b3c3(0x18e)],'puYPe':function(_0x56b5b0,_0x5d3454,_0x3d9260){const _0x4341a4=_0x3b54d4;return _0x4f94c5[_0x4341a4(0xdd)](_0x56b5b0,_0x5d3454,_0x3d9260);},'cLGWc':function(_0x247d54,_0x7936ed){const _0x2ceb29=_0x25d96d;return _0x4f94c5[_0x2ceb29(0x25a)](_0x247d54,_0x7936ed);},'XQvkd':_0x4f94c5[_0x25d96d(0x30d)],'pdVIS':function(_0x477481,_0x5920f5){const _0x22136d=_0x25d96d;return _0x4f94c5[_0x22136d(0x248)](_0x477481,_0x5920f5);},'cCFlz':_0x4f94c5[_0x183904(0x710)],'wClVX':_0x4f94c5[_0x43b3c3(0x452)]};if(_0x4f94c5[_0x25d96d(0x262)](_0x4f94c5[_0x183904(0x67e)],_0x4f94c5[_0x183904(0x3a3)]))_0x12c265=_0x2c0b55[_0x43b3c3(0x1d3)](_0x1c8126[_0x43b3c3(0x56d)](_0x9c560,_0x5d2cf4))[_0x1c8126[_0x4abf2f(0x34a)]],_0x5f2cd6='';else{const _0x3ce325=_0x3a20b6[_0x183904(0xf6)][_0x183904(0x2bd)+_0x25d96d(0x273)]();let _0x537d59='',_0x28e02f='';_0x3ce325[_0x43b3c3(0x226)]()[_0x25d96d(0x433)](function _0x4cc976({done:_0x4461ad,value:_0xb77230}){const _0x4f624c=_0x4abf2f,_0x442727=_0x25d96d,_0x1a16b5=_0x4abf2f,_0x4e0c25=_0x183904,_0x294afd=_0x43b3c3,_0x44fec7={'stmsS':function(_0x527fc0,_0x24348f){const _0x4171ac=_0x2a23;return _0x4f94c5[_0x4171ac(0x103)](_0x527fc0,_0x24348f);},'prKXb':_0x4f94c5[_0x4f624c(0x5ee)],'CcyYK':function(_0x3b7160,_0x2ba1b2){const _0x16ae3d=_0x4f624c;return _0x4f94c5[_0x16ae3d(0x4c4)](_0x3b7160,_0x2ba1b2);},'AJhGi':_0x4f94c5[_0x4f624c(0x55a)],'PMoat':_0x4f94c5[_0x1a16b5(0x49e)],'UwyUO':_0x4f94c5[_0x4f624c(0x228)]};if(_0x4f94c5[_0x1a16b5(0x72e)](_0x4f94c5[_0x4f624c(0x46b)],_0x4f94c5[_0x4f624c(0x46b)])){_0x565915=_0x44fec7[_0x4e0c25(0x4ac)](_0x5a1d01,_0x1a1253);const _0x569fec={};return _0x569fec[_0x4f624c(0x13d)]=_0x44fec7[_0x442727(0x2d6)],_0x5388e9[_0x4e0c25(0x513)+'e'][_0x1a16b5(0x574)+'pt'](_0x569fec,_0x288bea,_0x44111d);}else{if(_0x4461ad)return;const _0x33064c=new TextDecoder(_0x4f94c5[_0x4e0c25(0x6a6)])[_0x4e0c25(0x70f)+'e'](_0xb77230);return _0x33064c[_0x294afd(0x1c4)]()[_0x294afd(0x234)]('\x0a')[_0x442727(0x3a0)+'ch'](function(_0x493c88){const _0x29c0b9=_0x1a16b5,_0x1f287c=_0x4e0c25,_0x496e91=_0x4f624c,_0x238b5d=_0x294afd,_0x2537c1=_0x294afd,_0x59d829={};_0x59d829[_0x29c0b9(0x482)]=_0x1c8126[_0x1f287c(0x34a)];const _0x158f4a=_0x59d829;if(_0x1c8126[_0x1f287c(0x6d6)](_0x1c8126[_0x238b5d(0x4b1)],_0x1c8126[_0x2537c1(0x4b1)])){if(_0x1c8126[_0x29c0b9(0x10b)](_0x493c88[_0x496e91(0x613)+'h'],-0x1b13+0x228e+0x17*-0x53))_0x537d59=_0x493c88[_0x238b5d(0x6da)](-0x1*-0xb+0x13e2+-0x13e7);if(_0x1c8126[_0x2537c1(0x59a)](_0x537d59,_0x1c8126[_0x29c0b9(0x5be)])){if(_0x1c8126[_0x238b5d(0x39f)](_0x1c8126[_0x496e91(0x491)],_0x1c8126[_0x1f287c(0x235)]))_0x4b5fdc=_0x5711cc[_0x2537c1(0x1d3)](_0x1c5d36)[_0x158f4a[_0x496e91(0x482)]],_0x184eaa='';else{word_last+=_0x1c8126[_0x496e91(0x56d)](chatTextRaw,chatTemp),lock_chat=0xc7*-0x2e+-0x1629+0x39eb,document[_0x238b5d(0x696)+_0x1f287c(0x6ee)+_0x29c0b9(0x6e9)](_0x1c8126[_0x238b5d(0x3c7)])[_0x496e91(0x754)]='';return;}}let _0x16613f;try{if(_0x1c8126[_0x29c0b9(0x516)](_0x1c8126[_0x238b5d(0x301)],_0x1c8126[_0x29c0b9(0x6a7)]))_0x48d082+=_0x2cf030;else try{if(_0x1c8126[_0x496e91(0x190)](_0x1c8126[_0x496e91(0x3ec)],_0x1c8126[_0x238b5d(0x539)]))_0x16613f=JSON[_0x496e91(0x1d3)](_0x1c8126[_0x2537c1(0x56d)](_0x28e02f,_0x537d59))[_0x1c8126[_0x2537c1(0x34a)]],_0x28e02f='';else{_0x5c98f7+=_0x44fec7[_0x238b5d(0x507)](_0xa51ab9,_0x2cd318),_0x155335=0x1340+-0x2b*-0x3e+-0x1daa,_0x2da80a[_0x496e91(0x696)+_0x2537c1(0x6ee)+_0x238b5d(0x6e9)](_0x44fec7[_0x496e91(0x15c)])[_0x238b5d(0x754)]='';return;}}catch(_0x2f726c){if(_0x1c8126[_0x29c0b9(0x4b7)](_0x1c8126[_0x238b5d(0x635)],_0x1c8126[_0x2537c1(0x4fd)]))return _0x4c7aa6;else _0x16613f=JSON[_0x2537c1(0x1d3)](_0x537d59)[_0x1c8126[_0x496e91(0x34a)]],_0x28e02f='';}}catch(_0x4c2e54){if(_0x1c8126[_0x496e91(0x3c1)](_0x1c8126[_0x238b5d(0x2ac)],_0x1c8126[_0x2537c1(0x52a)]))_0x28e02f+=_0x537d59;else return![];}if(_0x16613f&&_0x1c8126[_0x29c0b9(0x2c8)](_0x16613f[_0x2537c1(0x613)+'h'],0x2375+0xa*-0x1b7+-0x124f)&&_0x1c8126[_0x29c0b9(0x417)](_0x16613f[-0x93a*0x4+0x29*0x70+0x12f8][_0x2537c1(0x178)+_0x238b5d(0x346)][_0x496e91(0x2ed)+_0x2537c1(0x3e0)+'t'][0x16*-0xbb+0x1d36+0xd24*-0x1],text_offset)){if(_0x1c8126[_0x496e91(0x3c1)](_0x1c8126[_0x238b5d(0x1c5)],_0x1c8126[_0x238b5d(0x47f)]))chatTemp+=_0x16613f[0x0+0x24d*0x4+-0x1f*0x4c][_0x2537c1(0x28d)],text_offset=_0x16613f[-0x1c*0x24+-0x2176+0x2566*0x1][_0x238b5d(0x178)+_0x1f287c(0x346)][_0x29c0b9(0x2ed)+_0x496e91(0x3e0)+'t'][_0x1c8126[_0x2537c1(0x26a)](_0x16613f[0x3*0x76d+0x214b+0x3792*-0x1][_0x2537c1(0x178)+_0x238b5d(0x346)][_0x29c0b9(0x2ed)+_0x496e91(0x3e0)+'t'][_0x2537c1(0x613)+'h'],0x362+0x647*-0x3+0xf74)];else{_0xce98a9=-0x1*-0x74d+-0x246b+0x1d1e,_0x4deff0[_0x238b5d(0x40b)+_0x29c0b9(0x44e)+_0x2537c1(0x313)](_0x44fec7[_0x29c0b9(0x46d)])[_0x29c0b9(0x67a)][_0x496e91(0x466)+'ay']='',_0x4848a6[_0x29c0b9(0x40b)+_0x2537c1(0x44e)+_0x238b5d(0x313)](_0x44fec7[_0x238b5d(0x5d8)])[_0x29c0b9(0x67a)][_0x496e91(0x466)+'ay']='';return;}}chatTemp=chatTemp[_0x2537c1(0x180)+_0x496e91(0x1f2)]('\x0a\x0a','\x0a')[_0x2537c1(0x180)+_0x496e91(0x1f2)]('\x0a\x0a','\x0a'),document[_0x1f287c(0x696)+_0x238b5d(0x6ee)+_0x496e91(0x6e9)](_0x1c8126[_0x29c0b9(0x107)])[_0x238b5d(0x746)+_0x2537c1(0x6f5)]='',_0x1c8126[_0x2537c1(0x5fb)](markdownToHtml,_0x1c8126[_0x29c0b9(0x1c1)](beautify,chatTemp),document[_0x496e91(0x696)+_0x238b5d(0x6ee)+_0x29c0b9(0x6e9)](_0x1c8126[_0x496e91(0x107)])),document[_0x496e91(0x40b)+_0x1f287c(0x44e)+_0x1f287c(0x313)](_0x1c8126[_0x1f287c(0x3f8)])[_0x238b5d(0x746)+_0x2537c1(0x6f5)]=_0x1c8126[_0x238b5d(0x6b4)](_0x1c8126[_0x496e91(0x56d)](_0x1c8126[_0x2537c1(0x6b4)](prev_chat,_0x1c8126[_0x496e91(0x700)]),document[_0x1f287c(0x696)+_0x238b5d(0x6ee)+_0x496e91(0x6e9)](_0x1c8126[_0x496e91(0x107)])[_0x2537c1(0x746)+_0x496e91(0x6f5)]),_0x1c8126[_0x1f287c(0x1e8)]);}else _0x34c7ac=_0x1fa9ba;}),_0x3ce325[_0x4f624c(0x226)]()[_0x442727(0x433)](_0x4cc976);}});}})[_0x51dd84(0x3fa)](_0x50c4a0=>{const _0x42a25e=_0x3069b6,_0x5498e3=_0x51dd84,_0x22ca0e=_0x51dd84,_0x303302=_0x51dd84,_0x5ad65a=_0x51dd84;_0xd2e3eb[_0x42a25e(0x3d0)](_0xd2e3eb[_0x42a25e(0x3cb)],_0xd2e3eb[_0x22ca0e(0x3cb)])?console[_0x5498e3(0x519)](_0xd2e3eb[_0x303302(0x323)],_0x50c4a0):_0x36cbe7+=_0x379e8f;});}});}function send_chat(_0x13c8e0){const _0x3d2402=_0x10d145,_0x3486b5=_0x59ea0c,_0x5d12a9=_0x10d145,_0x505f1f=_0x59ea0c,_0x4e76b1=_0x57c199,_0x258104={'lnmpr':function(_0x5ee1ae){return _0x5ee1ae();},'kiuUG':function(_0x28b5e7,_0xc2dbce){return _0x28b5e7(_0xc2dbce);},'fZqPO':function(_0x10e25a,_0x59c73f){return _0x10e25a+_0x59c73f;},'rJvzt':_0x3d2402(0x2e7)+_0x3486b5(0x652)+_0x3486b5(0x2b3)+_0x3486b5(0x677),'Vvtwi':_0x3486b5(0xd8)+_0x4e76b1(0x528)+_0x5d12a9(0x4c7)+_0x5d12a9(0x563)+_0x3486b5(0x126)+_0x4e76b1(0x6d9)+'\x20)','nxLtk':function(_0x30983f,_0x1a5770){return _0x30983f<_0x1a5770;},'fBUOJ':function(_0x33e188,_0x3cfc2e){return _0x33e188+_0x3cfc2e;},'SmaFL':_0x505f1f(0x3b0)+'es','hrDKT':function(_0x553cf3,_0x2a6d48){return _0x553cf3+_0x2a6d48;},'WCKKh':function(_0xd79185,_0x3a37d9){return _0xd79185!==_0x3a37d9;},'ipoDh':_0x4e76b1(0x1fa),'DwZph':function(_0x3e7db9,_0x5b86ea){return _0x3e7db9>_0x5b86ea;},'VwTCy':function(_0x2d3f9a,_0x570358){return _0x2d3f9a==_0x570358;},'LWfHt':_0x5d12a9(0x439)+']','oijna':_0x4e76b1(0x4db),'zPVna':_0x3d2402(0x1d1),'UwBGh':_0x5d12a9(0x6a9)+_0x3d2402(0x4be)+'t','eYlOv':function(_0x1414a4,_0x216f60){return _0x1414a4===_0x216f60;},'MEOBa':_0x4e76b1(0x6ce),'QfsXp':_0x3486b5(0x1ab),'hzWwa':function(_0x37b90a,_0x5647cc){return _0x37b90a===_0x5647cc;},'MmzEv':_0x3d2402(0x329),'XJAWc':_0x5d12a9(0xec),'VwKCi':_0x5d12a9(0x543),'Heezr':_0x3d2402(0x2b1),'XnvhV':_0x505f1f(0x6e3),'sGbHE':function(_0xb349a8,_0x493638){return _0xb349a8-_0x493638;},'VqUTL':_0x4e76b1(0x68b)+'pt','JNxBA':function(_0x5e9167,_0x4e1acd,_0x3dd8a3){return _0x5e9167(_0x4e1acd,_0x3dd8a3);},'mWQnP':function(_0x62e3e9,_0x4fe72e){return _0x62e3e9(_0x4fe72e);},'AXIXP':_0x505f1f(0xdb),'hXdDO':_0x5d12a9(0x1aa)+_0x3486b5(0x3ab)+_0x4e76b1(0x5cf)+_0x3486b5(0x6f1)+_0x3d2402(0x3ee),'mOYKt':_0x4e76b1(0x151)+'>','NLmFt':_0x505f1f(0x199),'iZJWW':_0x3d2402(0x665),'POuDG':_0x3d2402(0x3fd),'kqeUQ':function(_0x5c6334,_0x274fa8){return _0x5c6334!==_0x274fa8;},'UtbOy':_0x4e76b1(0x29c),'aFuMQ':_0x3d2402(0x5c5),'lCbLC':_0x4e76b1(0x6a9)+_0x3486b5(0x183),'UaGWp':function(_0x1b35fa,_0x507054){return _0x1b35fa+_0x507054;},'mFmsM':_0x505f1f(0x1ca)+_0x5d12a9(0x6cd)+_0x3d2402(0x4af)+_0x5d12a9(0x35e)+_0x4e76b1(0x30a)+_0x505f1f(0x5d5)+_0x5d12a9(0x508)+_0x4e76b1(0x45c)+_0x505f1f(0x28c)+_0x505f1f(0x339)+_0x3486b5(0x655),'AeVhn':_0x3d2402(0x22d)+_0x3d2402(0x575),'SxxRi':_0x3d2402(0xca),'ZSYSP':_0x3486b5(0x25c),'vylcM':_0x3486b5(0x2e3)+':','lYEJU':function(_0x160faf,_0x3f80b4){return _0x160faf!==_0x3f80b4;},'Jrhzt':_0x5d12a9(0x459),'CPdfX':function(_0x2564b6,_0x2663cc){return _0x2564b6>_0x2663cc;},'xfxAz':function(_0x4a8751,_0x3f12d6){return _0x4a8751>_0x3f12d6;},'JciiA':_0x5d12a9(0x552),'SrBpE':_0x4e76b1(0x512),'QPfJs':_0x505f1f(0x58c),'empHB':_0x505f1f(0x6ec),'qJJGN':_0x4e76b1(0x70d),'ALNWg':_0x5d12a9(0x1be),'tBJHx':_0x505f1f(0x227),'iBJJe':_0x5d12a9(0x59e),'qiVbM':_0x3d2402(0x371),'Efgyi':_0x3486b5(0x449),'xWmoZ':_0x505f1f(0xc7),'aJvpM':_0x5d12a9(0xd6),'EXEVs':_0x5d12a9(0x3bc),'WQHSt':_0x505f1f(0x6d4),'zeedc':function(_0x2b9db1,_0x19a1c2){return _0x2b9db1(_0x19a1c2);},'FaLZg':function(_0x40f84a,_0x51245c){return _0x40f84a!=_0x51245c;},'joxBc':function(_0x57caf6,_0xa959e0){return _0x57caf6+_0xa959e0;},'bZNsI':function(_0x1b2ea0,_0x30f4bc){return _0x1b2ea0+_0x30f4bc;},'NnTZm':function(_0x466b57,_0x166624){return _0x466b57+_0x166624;},'XNwaL':_0x3486b5(0x6a9),'WflBH':_0x3486b5(0x64b)+_0x5d12a9(0x6a5),'kMgso':_0x3486b5(0x6c9)+'果\x0a','WfXqU':function(_0x504d1f,_0x4e2ab6){return _0x504d1f+_0x4e2ab6;},'qamcH':function(_0x131e20,_0x349d98){return _0x131e20+_0x349d98;},'AlboT':function(_0x3de47f,_0x2c4611){return _0x3de47f+_0x2c4611;},'yGUfE':function(_0x4e25f6,_0x2c70e9){return _0x4e25f6+_0x2c70e9;},'EPBpp':_0x4e76b1(0x475)+_0x505f1f(0x2b8)+_0x3486b5(0x70e)+_0x3d2402(0xe4)+_0x3d2402(0x23b)+_0x5d12a9(0x109)+_0x3d2402(0x394)+'\x0a','kjvfF':_0x5d12a9(0x612),'jWCmJ':_0x5d12a9(0x28b),'SsaRg':_0x3d2402(0x64d)+_0x505f1f(0x406)+_0x3d2402(0x634),'UBYeJ':_0x5d12a9(0x237),'XeMHS':function(_0x2c9e1f,_0x56efcf,_0x570928){return _0x2c9e1f(_0x56efcf,_0x570928);},'MYFZa':function(_0x349038,_0x2ad502){return _0x349038(_0x2ad502);},'dOIzY':function(_0x9118d8,_0x3eada2){return _0x9118d8+_0x3eada2;},'QMifA':_0x505f1f(0x3b5),'rlUJI':_0x4e76b1(0x4ff),'qwipE':function(_0x323ff3,_0x58d9b2){return _0x323ff3+_0x58d9b2;},'awJEL':_0x505f1f(0x1aa)+_0x505f1f(0x3ab)+_0x505f1f(0x5cf)+_0x3d2402(0x136)+_0x505f1f(0x6f4)+'\x22>','vEIVO':_0x3d2402(0x16d)+_0x4e76b1(0x250)+_0x5d12a9(0x2a7)+_0x505f1f(0x1e6)+_0x4e76b1(0x2cc)+_0x4e76b1(0x584)};let _0x46daa2=document[_0x505f1f(0x696)+_0x3486b5(0x6ee)+_0x4e76b1(0x6e9)](_0x258104[_0x3486b5(0x19b)])[_0x505f1f(0x754)];_0x13c8e0&&(_0x258104[_0x5d12a9(0x521)](_0x258104[_0x4e76b1(0x2af)],_0x258104[_0x3d2402(0x2af)])?(_0x325ce9=_0x473a4e[_0x5d12a9(0x2a2)+_0x3d2402(0x37b)+'t'],_0x1c9cd5[_0x4e76b1(0x112)+'e'](),_0x258104[_0x3486b5(0x68d)](_0x29d3de)):(_0x46daa2=_0x13c8e0[_0x3486b5(0x2a2)+_0x3486b5(0x37b)+'t'],_0x13c8e0[_0x505f1f(0x112)+'e']()));if(_0x258104[_0x3486b5(0x64f)](_0x46daa2[_0x505f1f(0x613)+'h'],0x7*0x2f6+-0x16ae+0x1f4)||_0x258104[_0x505f1f(0x106)](_0x46daa2[_0x4e76b1(0x613)+'h'],-0x1f81+0x1f90+-0x5*-0x19))return;if(_0x258104[_0x4e76b1(0x5fe)](word_last[_0x505f1f(0x613)+'h'],0x1f*0x11c+-0x3f7+-0xc5*0x25))word_last[_0x505f1f(0x6da)](-0x2436+-0xf1*0x1f+-0x1*-0x4359);if(_0x46daa2[_0x505f1f(0x66d)+_0x3486b5(0x1a1)]('扮演')||_0x46daa2[_0x5d12a9(0x66d)+_0x4e76b1(0x1a1)]('模仿')||_0x46daa2[_0x5d12a9(0x66d)+_0x3486b5(0x1a1)](_0x258104[_0x505f1f(0x192)])||_0x46daa2[_0x5d12a9(0x66d)+_0x3d2402(0x1a1)]('帮我')||_0x46daa2[_0x5d12a9(0x66d)+_0x3d2402(0x1a1)](_0x258104[_0x4e76b1(0x74b)])||_0x46daa2[_0x505f1f(0x66d)+_0x3d2402(0x1a1)](_0x258104[_0x4e76b1(0x6ed)])||_0x46daa2[_0x4e76b1(0x66d)+_0x3d2402(0x1a1)]('请问')||_0x46daa2[_0x5d12a9(0x66d)+_0x4e76b1(0x1a1)]('请给')||_0x46daa2[_0x505f1f(0x66d)+_0x505f1f(0x1a1)]('请你')||_0x46daa2[_0x4e76b1(0x66d)+_0x3d2402(0x1a1)](_0x258104[_0x5d12a9(0x192)])||_0x46daa2[_0x505f1f(0x66d)+_0x3486b5(0x1a1)](_0x258104[_0x3486b5(0x2cd)])||_0x46daa2[_0x505f1f(0x66d)+_0x505f1f(0x1a1)](_0x258104[_0x3486b5(0x158)])||_0x46daa2[_0x505f1f(0x66d)+_0x5d12a9(0x1a1)](_0x258104[_0x3486b5(0x2b4)])||_0x46daa2[_0x505f1f(0x66d)+_0x3d2402(0x1a1)](_0x258104[_0x505f1f(0x5d9)])||_0x46daa2[_0x3d2402(0x66d)+_0x4e76b1(0x1a1)](_0x258104[_0x3486b5(0x35c)])||_0x46daa2[_0x5d12a9(0x66d)+_0x5d12a9(0x1a1)]('怎样')||_0x46daa2[_0x4e76b1(0x66d)+_0x3486b5(0x1a1)]('给我')||_0x46daa2[_0x5d12a9(0x66d)+_0x5d12a9(0x1a1)]('如何')||_0x46daa2[_0x4e76b1(0x66d)+_0x505f1f(0x1a1)]('谁是')||_0x46daa2[_0x3d2402(0x66d)+_0x4e76b1(0x1a1)]('查询')||_0x46daa2[_0x4e76b1(0x66d)+_0x3d2402(0x1a1)](_0x258104[_0x3d2402(0x32c)])||_0x46daa2[_0x505f1f(0x66d)+_0x3d2402(0x1a1)](_0x258104[_0x4e76b1(0x498)])||_0x46daa2[_0x5d12a9(0x66d)+_0x4e76b1(0x1a1)](_0x258104[_0x4e76b1(0x739)])||_0x46daa2[_0x3d2402(0x66d)+_0x4e76b1(0x1a1)](_0x258104[_0x3486b5(0x38c)])||_0x46daa2[_0x3d2402(0x66d)+_0x505f1f(0x1a1)]('哪个')||_0x46daa2[_0x5d12a9(0x66d)+_0x505f1f(0x1a1)]('哪些')||_0x46daa2[_0x505f1f(0x66d)+_0x505f1f(0x1a1)](_0x258104[_0x4e76b1(0x719)])||_0x46daa2[_0x3486b5(0x66d)+_0x4e76b1(0x1a1)](_0x258104[_0x5d12a9(0x29a)])||_0x46daa2[_0x5d12a9(0x66d)+_0x4e76b1(0x1a1)]('啥是')||_0x46daa2[_0x3486b5(0x66d)+_0x5d12a9(0x1a1)]('为啥')||_0x46daa2[_0x3d2402(0x66d)+_0x505f1f(0x1a1)]('怎么'))return _0x258104[_0x3d2402(0x437)](send_webchat,_0x13c8e0);if(_0x258104[_0x3d2402(0x4b0)](lock_chat,-0x20c+0x2a*0xe9+-0x242e))return;lock_chat=0xba1+0x6*-0x41f+0xd1a;const _0x2c8548=_0x258104[_0x5d12a9(0xe6)](_0x258104[_0x4e76b1(0x2ca)](_0x258104[_0x5d12a9(0x2f0)](document[_0x505f1f(0x696)+_0x3486b5(0x6ee)+_0x4e76b1(0x6e9)](_0x258104[_0x5d12a9(0x5dd)])[_0x3486b5(0x746)+_0x3486b5(0x6f5)][_0x4e76b1(0x180)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x3486b5(0x180)+'ce'](/<hr.*/gs,'')[_0x505f1f(0x180)+'ce'](/<[^>]+>/g,'')[_0x5d12a9(0x180)+'ce'](/\n\n/g,'\x0a'),_0x258104[_0x505f1f(0x120)]),search_queryquery),_0x258104[_0x3d2402(0x203)]);let _0x37e4de=_0x258104[_0x5d12a9(0x2ca)](_0x258104[_0x505f1f(0x130)](_0x258104[_0x3486b5(0x5cc)](_0x258104[_0x3d2402(0x66c)](_0x258104[_0x5d12a9(0x2b7)](_0x258104[_0x4e76b1(0x6db)](_0x258104[_0x5d12a9(0x284)](_0x258104[_0x3d2402(0x49a)],_0x258104[_0x3d2402(0x517)]),_0x2c8548),'\x0a'),word_last),_0x258104[_0x505f1f(0x642)]),_0x46daa2),_0x258104[_0x4e76b1(0x44a)]);const _0x5da3a1={};_0x5da3a1[_0x505f1f(0x2f4)+'t']=_0x37e4de,_0x5da3a1[_0x3d2402(0x2d8)+_0x3486b5(0x278)]=0x3e8,_0x5da3a1[_0x4e76b1(0x52e)+_0x5d12a9(0x732)+'e']=0.9,_0x5da3a1[_0x505f1f(0x3d6)]=0x1,_0x5da3a1[_0x3d2402(0x6af)+_0x3486b5(0x532)+_0x3d2402(0x380)+'ty']=0x0,_0x5da3a1[_0x3486b5(0x230)+_0x505f1f(0x156)+_0x3d2402(0x494)+'y']=0x1,_0x5da3a1[_0x3d2402(0x752)+'of']=0x1,_0x5da3a1[_0x4e76b1(0x54d)]=![],_0x5da3a1[_0x4e76b1(0x178)+_0x4e76b1(0x346)]=0x0,_0x5da3a1[_0x3d2402(0x504)+'m']=!![];const _0x312dfa={'method':_0x258104[_0x3486b5(0x64e)],'headers':headers,'body':_0x258104[_0x5d12a9(0xc8)](b64EncodeUnicode,JSON[_0x4e76b1(0xe9)+_0x3d2402(0x1fe)](_0x5da3a1))};_0x46daa2=_0x46daa2[_0x3486b5(0x180)+_0x3486b5(0x1f2)]('\x0a\x0a','\x0a')[_0x3d2402(0x180)+_0x4e76b1(0x1f2)]('\x0a\x0a','\x0a'),document[_0x3486b5(0x696)+_0x4e76b1(0x6ee)+_0x4e76b1(0x6e9)](_0x258104[_0x505f1f(0x38f)])[_0x3d2402(0x746)+_0x5d12a9(0x6f5)]='',_0x258104[_0x505f1f(0x70a)](markdownToHtml,_0x258104[_0x4e76b1(0x42e)](beautify,_0x46daa2),document[_0x3d2402(0x696)+_0x4e76b1(0x6ee)+_0x505f1f(0x6e9)](_0x258104[_0x3d2402(0x38f)])),chatTextRaw=_0x258104[_0x505f1f(0x66c)](_0x258104[_0x4e76b1(0x6ea)](_0x258104[_0x3d2402(0x5b7)],_0x46daa2),_0x258104[_0x5d12a9(0x483)]),chatTemp='',text_offset=-(-0x5a*-0x4+0x18*0x133+-0x1*0x1e2f),prev_chat=document[_0x5d12a9(0x40b)+_0x4e76b1(0x44e)+_0x505f1f(0x313)](_0x258104[_0x3d2402(0x550)])[_0x4e76b1(0x746)+_0x3d2402(0x6f5)],prev_chat=_0x258104[_0x505f1f(0x678)](_0x258104[_0x5d12a9(0x130)](_0x258104[_0x3d2402(0x712)](prev_chat,_0x258104[_0x5d12a9(0x5ad)]),document[_0x3d2402(0x696)+_0x5d12a9(0x6ee)+_0x505f1f(0x6e9)](_0x258104[_0x5d12a9(0x38f)])[_0x5d12a9(0x746)+_0x3d2402(0x6f5)]),_0x258104[_0x4e76b1(0x456)]),_0x258104[_0x505f1f(0x70a)](fetch,_0x258104[_0x4e76b1(0x640)],_0x312dfa)[_0x3486b5(0x433)](_0x266e8a=>{const _0xe1ed56=_0x505f1f,_0x47da19=_0x505f1f,_0x2dcbd9=_0x505f1f,_0x19b8a6=_0x3d2402,_0x5848e0=_0x4e76b1,_0xb72b0c={'cWjNc':function(_0x27c37f,_0x17f9a7){const _0x4735ed=_0x2a23;return _0x258104[_0x4735ed(0x572)](_0x27c37f,_0x17f9a7);},'MrByN':function(_0x49e063,_0x15277b){const _0x115c51=_0x2a23;return _0x258104[_0x115c51(0x5cc)](_0x49e063,_0x15277b);},'alopD':_0x258104[_0xe1ed56(0x68a)],'pcyza':function(_0x5c7c89,_0x52fff9){const _0x2979f5=_0xe1ed56;return _0x258104[_0x2979f5(0x676)](_0x5c7c89,_0x52fff9);},'nOdVR':function(_0x631ee3,_0x2836bf){const _0x258ceb=_0xe1ed56;return _0x258104[_0x258ceb(0x678)](_0x631ee3,_0x2836bf);},'UunQd':_0x258104[_0xe1ed56(0x55e)],'fDlSD':_0x258104[_0xe1ed56(0x5c4)],'ibyDM':function(_0x2503ee,_0x404ff6){const _0x5409f8=_0x2dcbd9;return _0x258104[_0x5409f8(0x388)](_0x2503ee,_0x404ff6);},'CVOEV':_0x258104[_0x47da19(0x52d)],'unTvs':function(_0x377951,_0xf6ddc4){const _0x44bf4d=_0x2dcbd9;return _0x258104[_0x44bf4d(0x5f3)](_0x377951,_0xf6ddc4);},'tlsmM':function(_0x2a521f,_0x1000a4){const _0x4e105b=_0x2dcbd9;return _0x258104[_0x4e105b(0x64f)](_0x2a521f,_0x1000a4);},'AZEfN':_0x258104[_0x19b8a6(0x1f4)],'yPumI':_0x258104[_0x5848e0(0x297)],'pCCwc':_0x258104[_0x19b8a6(0x282)],'tVIIa':_0x258104[_0xe1ed56(0x19b)],'dfGWp':function(_0x254c32,_0x3149a4){const _0x1740fa=_0x19b8a6;return _0x258104[_0x1740fa(0x47d)](_0x254c32,_0x3149a4);},'TGJLi':_0x258104[_0xe1ed56(0x22f)],'OLJhj':_0x258104[_0x5848e0(0x684)],'Qhjlu':function(_0xebe9ff,_0x1a36ce){const _0x648e7f=_0xe1ed56;return _0x258104[_0x648e7f(0x318)](_0xebe9ff,_0x1a36ce);},'ILMYd':_0x258104[_0x2dcbd9(0x533)],'aumQo':_0x258104[_0x19b8a6(0x48e)],'ocQNF':_0x258104[_0x5848e0(0x4d2)],'oTMMH':_0x258104[_0x47da19(0x2fd)],'jqyyI':_0x258104[_0x5848e0(0x6c8)],'yqbQj':function(_0x12cfda,_0x39e580){const _0x1e61c8=_0x5848e0;return _0x258104[_0x1e61c8(0xce)](_0x12cfda,_0x39e580);},'mevhl':_0x258104[_0x19b8a6(0x38f)],'EodbC':function(_0x3d9bce,_0xb40300,_0x2595d8){const _0x4746eb=_0x5848e0;return _0x258104[_0x4746eb(0x1a4)](_0x3d9bce,_0xb40300,_0x2595d8);},'MQOsb':function(_0x55db3e,_0x397697){const _0x136f57=_0x47da19;return _0x258104[_0x136f57(0xc8)](_0x55db3e,_0x397697);},'RkcNF':_0x258104[_0x5848e0(0x550)],'NnJHB':_0x258104[_0x2dcbd9(0x16c)],'wAGPv':_0x258104[_0x2dcbd9(0x456)],'fcQjZ':_0x258104[_0x5848e0(0x4fc)],'NeEwO':_0x258104[_0x19b8a6(0x3d1)],'QgbYU':_0x258104[_0xe1ed56(0x56c)]};if(_0x258104[_0x5848e0(0x509)](_0x258104[_0x2dcbd9(0x460)],_0x258104[_0x5848e0(0x4b4)])){const _0x58ddac=_0x266e8a[_0x2dcbd9(0xf6)][_0xe1ed56(0x2bd)+_0x47da19(0x273)]();let _0x116693='',_0x5ba9db='';_0x58ddac[_0x19b8a6(0x226)]()[_0x19b8a6(0x433)](function _0x440f16({done:_0x52a644,value:_0x1f8fc6}){const _0x21e94e=_0x47da19,_0x41dc76=_0x19b8a6,_0x5749f3=_0x19b8a6,_0x1ab812=_0x2dcbd9,_0x423cb2=_0xe1ed56,_0x2eaecb={'RroFT':function(_0x4e0c1f,_0x549794){const _0x38e4af=_0x2a23;return _0xb72b0c[_0x38e4af(0x707)](_0x4e0c1f,_0x549794);},'HIrin':_0xb72b0c[_0x21e94e(0x633)],'eBfdF':function(_0x5cebd4,_0x31bd96){const _0x4beda8=_0x21e94e;return _0xb72b0c[_0x4beda8(0x1da)](_0x5cebd4,_0x31bd96);},'FHmCS':function(_0x288f51,_0x55748d){const _0x486614=_0x21e94e;return _0xb72b0c[_0x486614(0x401)](_0x288f51,_0x55748d);},'dfdeV':_0xb72b0c[_0x21e94e(0x6f6)],'YSsfW':_0xb72b0c[_0x41dc76(0xe2)],'iXsyD':function(_0x19bc58,_0x42c719){const _0x5b66a0=_0x41dc76;return _0xb72b0c[_0x5b66a0(0x401)](_0x19bc58,_0x42c719);},'geBVR':function(_0x53bb5a,_0x35dcec){const _0x1eeb4e=_0x5749f3;return _0xb72b0c[_0x1eeb4e(0x534)](_0x53bb5a,_0x35dcec);},'HLIDg':_0xb72b0c[_0x21e94e(0x736)],'qsZqY':function(_0x31339e,_0x5ea573){const _0x5381fd=_0x21e94e;return _0xb72b0c[_0x5381fd(0x287)](_0x31339e,_0x5ea573);},'ANSyS':function(_0x485255,_0x556a3c){const _0xb3419=_0x21e94e;return _0xb72b0c[_0xb3419(0x464)](_0x485255,_0x556a3c);},'vVpmi':_0xb72b0c[_0x41dc76(0x1b1)],'gnjla':_0xb72b0c[_0x423cb2(0x6f3)],'DfGIh':_0xb72b0c[_0x5749f3(0x2c4)],'DHVEu':function(_0x2a70ee,_0x236a17){const _0x5638f3=_0x41dc76;return _0xb72b0c[_0x5638f3(0x707)](_0x2a70ee,_0x236a17);},'qZdwr':_0xb72b0c[_0x21e94e(0x51a)],'LNyAV':function(_0x1700a9,_0x407554){const _0x1730da=_0x21e94e;return _0xb72b0c[_0x1730da(0x744)](_0x1700a9,_0x407554);},'XCYAr':_0xb72b0c[_0x423cb2(0x4f2)],'SFOZt':_0xb72b0c[_0x423cb2(0x41f)],'mXPzd':function(_0x32e96e,_0x46c6b8){const _0x1f9b41=_0x423cb2;return _0xb72b0c[_0x1f9b41(0xc9)](_0x32e96e,_0x46c6b8);},'LavUY':_0xb72b0c[_0x41dc76(0x3dd)],'ElBQZ':function(_0x1af160,_0x50099e){const _0x5da3ff=_0x21e94e;return _0xb72b0c[_0x5da3ff(0x707)](_0x1af160,_0x50099e);},'UBgal':_0xb72b0c[_0x41dc76(0x330)],'aBYTq':_0xb72b0c[_0x1ab812(0x21d)],'PHZvq':_0xb72b0c[_0x41dc76(0x166)],'xexjF':function(_0x541cd1,_0x1104e0){const _0x3f5d3b=_0x5749f3;return _0xb72b0c[_0x3f5d3b(0x287)](_0x541cd1,_0x1104e0);},'PemkS':_0xb72b0c[_0x423cb2(0x3a1)],'ntmlS':function(_0x43d2b1,_0x77dbab){const _0x20de1a=_0x1ab812;return _0xb72b0c[_0x20de1a(0x48a)](_0x43d2b1,_0x77dbab);},'AMhCo':_0xb72b0c[_0x41dc76(0x5bc)],'EgBjQ':function(_0x58acfc,_0x1ec9ab,_0x45f378){const _0x393fe9=_0x41dc76;return _0xb72b0c[_0x393fe9(0x377)](_0x58acfc,_0x1ec9ab,_0x45f378);},'DksZM':function(_0x24c4a5,_0x53829d){const _0x7ccd98=_0x5749f3;return _0xb72b0c[_0x7ccd98(0x427)](_0x24c4a5,_0x53829d);},'ywzny':_0xb72b0c[_0x423cb2(0xee)],'IcJGO':function(_0x48564d,_0x1c04dd){const _0x5bc695=_0x41dc76;return _0xb72b0c[_0x5bc695(0x401)](_0x48564d,_0x1c04dd);},'sLRhe':_0xb72b0c[_0x21e94e(0x69f)],'eCYOq':_0xb72b0c[_0x41dc76(0x5f6)]};if(_0xb72b0c[_0x5749f3(0x534)](_0xb72b0c[_0x21e94e(0x5d1)],_0xb72b0c[_0x41dc76(0x1d4)])){if(_0x52a644)return;const _0x5e7c87=new TextDecoder(_0xb72b0c[_0x423cb2(0x2cb)])[_0x41dc76(0x70f)+'e'](_0x1f8fc6);return _0x5e7c87[_0x21e94e(0x1c4)]()[_0x21e94e(0x234)]('\x0a')[_0x1ab812(0x3a0)+'ch'](function(_0x5a1451){const _0x385c12=_0x5749f3,_0x15ccf0=_0x21e94e,_0x208ee5=_0x5749f3,_0x3ace30=_0x5749f3,_0x5bcbb5=_0x41dc76,_0x25f1ac={'BRVaC':function(_0x4dce1e,_0x390996){const _0x3a2cc8=_0x2a23;return _0x2eaecb[_0x3a2cc8(0x648)](_0x4dce1e,_0x390996);},'NyKeq':_0x2eaecb[_0x385c12(0x244)]};if(_0x2eaecb[_0x385c12(0x11c)](_0x2eaecb[_0x385c12(0x292)],_0x2eaecb[_0x385c12(0x292)]))try{_0x4f6c4a=_0x16a4b9[_0x3ace30(0x1d3)](_0x25f1ac[_0x3ace30(0x3f6)](_0x3b97e2,_0x2506f6))[_0x25f1ac[_0x5bcbb5(0x37a)]],_0x21c302='';}catch(_0x4727e7){_0x9eb927=_0x784a84[_0x208ee5(0x1d3)](_0x51df73)[_0x25f1ac[_0x5bcbb5(0x37a)]],_0x26c82b='';}else{if(_0x2eaecb[_0x208ee5(0x608)](_0x5a1451[_0x3ace30(0x613)+'h'],0x1*-0x315+-0x2425+-0x2*-0x13a0))_0x116693=_0x5a1451[_0x208ee5(0x6da)](-0x225f+0x53d+-0x4dc*-0x6);if(_0x2eaecb[_0x385c12(0x385)](_0x116693,_0x2eaecb[_0x15ccf0(0x2d5)])){if(_0x2eaecb[_0x5bcbb5(0x11c)](_0x2eaecb[_0x5bcbb5(0x734)],_0x2eaecb[_0x208ee5(0x38d)])){word_last+=_0x2eaecb[_0x5bcbb5(0x32b)](chatTextRaw,chatTemp),lock_chat=0x1e6+-0x22fc+-0xb*-0x302,document[_0x3ace30(0x696)+_0x208ee5(0x6ee)+_0x385c12(0x6e9)](_0x2eaecb[_0x5bcbb5(0x34d)])[_0x385c12(0x754)]='';return;}else{const _0xc526bd=_0x14e1e6[_0x208ee5(0x352)](_0x2f99e2,arguments);return _0x21083a=null,_0xc526bd;}}let _0x3914fc;try{if(_0x2eaecb[_0x15ccf0(0x1ec)](_0x2eaecb[_0x385c12(0x503)],_0x2eaecb[_0x208ee5(0x477)]))_0x1090fd+=_0x1fe6d6[_0x208ee5(0x139)+_0x15ccf0(0x256)+_0x3ace30(0x303)](_0x310be2[_0x26a214]);else try{if(_0x2eaecb[_0x15ccf0(0x496)](_0x2eaecb[_0x208ee5(0x2e1)],_0x2eaecb[_0x208ee5(0x2e1)]))_0x3914fc=JSON[_0x385c12(0x1d3)](_0x2eaecb[_0x15ccf0(0x59b)](_0x5ba9db,_0x116693))[_0x2eaecb[_0x3ace30(0x244)]],_0x5ba9db='';else try{_0x28c4c8=_0x4509d4[_0x15ccf0(0x1d3)](_0x2eaecb[_0x15ccf0(0x473)](_0x5994ba,_0x495320))[_0x2eaecb[_0x5bcbb5(0x244)]],_0x137b37='';}catch(_0x907e3e){_0x3780b2=_0x21cf88[_0x208ee5(0x1d3)](_0x9c01bf)[_0x2eaecb[_0x3ace30(0x244)]],_0x176375='';}}catch(_0x5e81d3){_0x2eaecb[_0x385c12(0x1ec)](_0x2eaecb[_0x5bcbb5(0x337)],_0x2eaecb[_0x3ace30(0x1e3)])?_0x2f8bfb=eQnjvR[_0x208ee5(0x420)](_0x28d032,eQnjvR[_0x208ee5(0x473)](eQnjvR[_0x208ee5(0x596)](eQnjvR[_0x3ace30(0x3c9)],eQnjvR[_0x15ccf0(0x293)]),');'))():(_0x3914fc=JSON[_0x15ccf0(0x1d3)](_0x116693)[_0x2eaecb[_0x15ccf0(0x244)]],_0x5ba9db='');}}catch(_0x502efb){if(_0x2eaecb[_0x385c12(0x11c)](_0x2eaecb[_0x15ccf0(0x36a)],_0x2eaecb[_0x385c12(0x36a)])){if(_0x5496e7){const _0x474e76=_0x5add63[_0x15ccf0(0x352)](_0x1f16e1,arguments);return _0x3be46c=null,_0x474e76;}}else _0x5ba9db+=_0x116693;}_0x3914fc&&_0x2eaecb[_0x208ee5(0x608)](_0x3914fc[_0x15ccf0(0x613)+'h'],-0x11d2+0x44*-0x50+-0x1389*-0x2)&&_0x2eaecb[_0x5bcbb5(0x174)](_0x3914fc[0x7*-0x221+0xe11+-0xd6*-0x1][_0x3ace30(0x178)+_0x385c12(0x346)][_0x15ccf0(0x2ed)+_0x3ace30(0x3e0)+'t'][-0x2*0x45d+-0x1*-0x20e3+-0x1829],text_offset)&&(_0x2eaecb[_0x15ccf0(0x1ec)](_0x2eaecb[_0x15ccf0(0x2d0)],_0x2eaecb[_0x15ccf0(0x2d0)])?(chatTemp+=_0x3914fc[-0xcfc+0xa31*0x2+-0x766][_0x385c12(0x28d)],text_offset=_0x3914fc[0x3ee+-0x283*0xd+0x331*0x9][_0x3ace30(0x178)+_0x208ee5(0x346)][_0x385c12(0x2ed)+_0x3ace30(0x3e0)+'t'][_0x2eaecb[_0x208ee5(0x24a)](_0x3914fc[0x1326+-0x2*0x53+-0x1280][_0x385c12(0x178)+_0x385c12(0x346)][_0x385c12(0x2ed)+_0x208ee5(0x3e0)+'t'][_0x15ccf0(0x613)+'h'],-0x204a+-0x2312+0x435d)]):_0x15e2b5+=_0x2febb4),chatTemp=chatTemp[_0x385c12(0x180)+_0x3ace30(0x1f2)]('\x0a\x0a','\x0a')[_0x3ace30(0x180)+_0x3ace30(0x1f2)]('\x0a\x0a','\x0a'),document[_0x208ee5(0x696)+_0x15ccf0(0x6ee)+_0x15ccf0(0x6e9)](_0x2eaecb[_0x385c12(0x34e)])[_0x5bcbb5(0x746)+_0x208ee5(0x6f5)]='',_0x2eaecb[_0x385c12(0x279)](markdownToHtml,_0x2eaecb[_0x3ace30(0x567)](beautify,chatTemp),document[_0x15ccf0(0x696)+_0x208ee5(0x6ee)+_0x5bcbb5(0x6e9)](_0x2eaecb[_0x15ccf0(0x34e)])),document[_0x3ace30(0x40b)+_0x385c12(0x44e)+_0x15ccf0(0x313)](_0x2eaecb[_0x3ace30(0x68c)])[_0x385c12(0x746)+_0x385c12(0x6f5)]=_0x2eaecb[_0x5bcbb5(0x299)](_0x2eaecb[_0x208ee5(0x596)](_0x2eaecb[_0x5bcbb5(0x648)](prev_chat,_0x2eaecb[_0x385c12(0x71d)]),document[_0x385c12(0x696)+_0x385c12(0x6ee)+_0x3ace30(0x6e9)](_0x2eaecb[_0x385c12(0x34e)])[_0x5bcbb5(0x746)+_0x15ccf0(0x6f5)]),_0x2eaecb[_0x385c12(0x14a)]);}}),_0x58ddac[_0x41dc76(0x226)]()[_0x423cb2(0x433)](_0x440f16);}else{var _0x345195=new _0x3b4dab(_0x5a117f[_0x41dc76(0x613)+'h']),_0x356f4d=new _0x113ac4(_0x345195);for(var _0x4454b9=-0x132b+0x1cb5*-0x1+-0x2*-0x17f0,_0x188599=_0x27238b[_0x1ab812(0x613)+'h'];_0xb72b0c[_0x423cb2(0x2de)](_0x4454b9,_0x188599);_0x4454b9++){_0x356f4d[_0x4454b9]=_0x4793a8[_0x423cb2(0x749)+_0x5749f3(0x4ec)](_0x4454b9);}return _0x345195;}});}else _0x9cea44=ouRLKv[_0x2dcbd9(0x676)](_0x4d5006,ouRLKv[_0x2dcbd9(0x4a6)](ouRLKv[_0x5848e0(0x4a6)](ouRLKv[_0x19b8a6(0x55e)],ouRLKv[_0x47da19(0x5c4)]),');'))();})[_0x505f1f(0x3fa)](_0x2d875c=>{const _0x35ae8f=_0x505f1f,_0x382a0c=_0x3d2402,_0x135c36=_0x3d2402,_0x46ec50=_0x3d2402,_0x4ccf5c=_0x3d2402,_0x236173={'RhPEq':_0x258104[_0x35ae8f(0xed)],'kVRiG':function(_0x338614,_0x2c7365){const _0x57ef3f=_0x35ae8f;return _0x258104[_0x57ef3f(0x284)](_0x338614,_0x2c7365);},'sxjGX':function(_0x3b72a5,_0x5cebf2){const _0x143e21=_0x35ae8f;return _0x258104[_0x143e21(0x5cc)](_0x3b72a5,_0x5cebf2);},'VZLdp':_0x258104[_0x35ae8f(0xfe)],'ZVAQE':function(_0x5125d3,_0x3ad295){const _0x313dd2=_0x382a0c;return _0x258104[_0x313dd2(0xc8)](_0x5125d3,_0x3ad295);},'bBkXG':_0x258104[_0x135c36(0x757)]};_0x258104[_0x46ec50(0x388)](_0x258104[_0x135c36(0x67f)],_0x258104[_0x35ae8f(0x6fc)])?console[_0x46ec50(0x519)](_0x258104[_0x382a0c(0x6f0)],_0x2d875c):_0x241f41[_0x46ec50(0x1d3)](_0x3730b3[_0x46ec50(0x3b0)+'es'][-0x267b*0x1+-0x269*-0x7+0xc*0x1cd][_0x135c36(0x28d)][_0x382a0c(0x180)+_0x382a0c(0x1f2)]('\x0a',''))[_0x35ae8f(0x3a0)+'ch'](_0x1a857c=>{const _0x28d214=_0x35ae8f,_0x57dc5e=_0x4ccf5c,_0x43af35=_0x135c36,_0x486cf1=_0x35ae8f,_0x441a34=_0x35ae8f;_0x50e7e3[_0x28d214(0x696)+_0x28d214(0x6ee)+_0x57dc5e(0x6e9)](_0x236173[_0x486cf1(0x5ac)])[_0x486cf1(0x746)+_0x486cf1(0x6f5)]+=_0x236173[_0x57dc5e(0x5bf)](_0x236173[_0x486cf1(0x1a0)](_0x236173[_0x28d214(0x55b)],_0x236173[_0x486cf1(0x48d)](_0x450626,_0x1a857c)),_0x236173[_0x486cf1(0x3c5)]);});});}function replaceUrlWithFootnote(_0x4d7a4e){const _0x3b4f8d=_0x469679,_0xdc1b43=_0x59ea0c,_0x557e9c=_0x469679,_0x3f656f=_0x469679,_0x193ab0=_0x469679,_0xa930d6={'nIsrS':function(_0x4c686b,_0x1fc1f7){return _0x4c686b(_0x1fc1f7);},'ipIVq':function(_0x498c9f,_0x4684e6){return _0x498c9f!==_0x4684e6;},'TfDEF':_0x3b4f8d(0x137),'DgVek':_0x3b4f8d(0x709),'zilGt':_0xdc1b43(0x6bc),'EAzLL':function(_0xfa17c6,_0x4c907d){return _0xfa17c6+_0x4c907d;},'UPqNs':function(_0x1dd30a,_0x2a9565){return _0x1dd30a-_0x2a9565;},'qqTzZ':function(_0xb301eb,_0x4c760d){return _0xb301eb<=_0x4c760d;},'rsiSF':_0x3b4f8d(0x340)+_0x557e9c(0x2e2),'JIblZ':function(_0x1ebb9c,_0x35258d){return _0x1ebb9c>_0x35258d;},'JcXwh':function(_0x3dc8d0,_0x19074b){return _0x3dc8d0===_0x19074b;},'VRvXf':_0x3b4f8d(0x62b),'qqopf':_0x3f656f(0xd1)},_0x356f29=/\((https?:\/\/[^\s()]+(?:\s|;)?(?:https?:\/\/[^\s()]+)*)\)/g,_0x56c102=new Set(),_0x4ba4f1=(_0x5eb5c7,_0x1ecc9f)=>{const _0x13d2b8=_0x193ab0,_0x4e3b19=_0x193ab0,_0x3d7bc6=_0x3f656f,_0x3e374c=_0x3f656f,_0x45d0fa=_0x3f656f,_0x57f279={'DKTDD':function(_0x2b8149,_0x5e46ac){const _0x2dadd6=_0x2a23;return _0xa930d6[_0x2dadd6(0x587)](_0x2b8149,_0x5e46ac);}};if(_0xa930d6[_0x13d2b8(0x588)](_0xa930d6[_0x4e3b19(0x620)],_0xa930d6[_0x4e3b19(0x1cc)])){if(_0x56c102[_0x13d2b8(0x24d)](_0x1ecc9f)){if(_0xa930d6[_0x13d2b8(0x588)](_0xa930d6[_0x45d0fa(0x617)],_0xa930d6[_0x13d2b8(0x617)]))gpSWbs[_0x3e374c(0x153)](_0x3c2fe8,'0');else return _0x5eb5c7;}const _0x5163aa=_0x1ecc9f[_0x3e374c(0x234)](/[;,；、，]/),_0x22b41c=_0x5163aa[_0x4e3b19(0x336)](_0x902070=>'['+_0x902070+']')[_0x45d0fa(0x26b)]('\x20'),_0xf6b6ce=_0x5163aa[_0x13d2b8(0x336)](_0x5d4042=>'['+_0x5d4042+']')[_0x3d7bc6(0x26b)]('\x0a');_0x5163aa[_0x3d7bc6(0x3a0)+'ch'](_0x5734dd=>_0x56c102[_0x45d0fa(0x3ba)](_0x5734dd)),res='\x20';for(var _0x524bfe=_0xa930d6[_0x3e374c(0x649)](_0xa930d6[_0x45d0fa(0x4b9)](_0x56c102[_0x13d2b8(0x3de)],_0x5163aa[_0x45d0fa(0x613)+'h']),-0x1c82+0x536*0x3+-0x3*-0x44b);_0xa930d6[_0x13d2b8(0x5fa)](_0x524bfe,_0x56c102[_0x3d7bc6(0x3de)]);++_0x524bfe)res+='[^'+_0x524bfe+']\x20';return res;}else _0x37a853=_0x2df5a6[_0x3d7bc6(0x2a2)+_0x3e374c(0x37b)+'t'],_0x744f2f[_0x13d2b8(0x112)+'e']();};let _0xd5155d=0x1*0xc89+0x2462+-0x1875*0x2,_0x6b6a5d=_0x4d7a4e[_0xdc1b43(0x180)+'ce'](_0x356f29,_0x4ba4f1);while(_0xa930d6[_0xdc1b43(0x187)](_0x56c102[_0xdc1b43(0x3de)],-0x1703+-0x1630+0x2d33)){if(_0xa930d6[_0x557e9c(0x5ec)](_0xa930d6[_0x3b4f8d(0x2f1)],_0xa930d6[_0x557e9c(0x4ca)]))try{_0x54cbb7=_0xa930d6[_0x3f656f(0x587)](_0x5b48fa,_0x2756e8);const _0x2e4368={};return _0x2e4368[_0x3b4f8d(0x13d)]=_0xa930d6[_0x193ab0(0x66b)],_0x47627f[_0x3b4f8d(0x513)+'e'][_0x193ab0(0x574)+'pt'](_0x2e4368,_0x4c1ce9,_0x53130a);}catch(_0x45962f){}else{const _0x12bbbc='['+_0xd5155d++ +_0xdc1b43(0x607)+_0x56c102[_0x557e9c(0x754)+'s']()[_0x557e9c(0x360)]()[_0x193ab0(0x754)],_0x2c44b1='[^'+_0xa930d6[_0x3b4f8d(0x4b9)](_0xd5155d,0x523*0x1+-0xa10+-0x1*-0x4ee)+_0xdc1b43(0x607)+_0x56c102[_0x3f656f(0x754)+'s']()[_0x557e9c(0x360)]()[_0xdc1b43(0x754)];_0x6b6a5d=_0x6b6a5d+'\x0a\x0a'+_0x2c44b1,_0x56c102[_0xdc1b43(0x623)+'e'](_0x56c102[_0x3f656f(0x754)+'s']()[_0xdc1b43(0x360)]()[_0x193ab0(0x754)]);}}return _0x6b6a5d;}function beautify(_0x51e96e){const _0x4316b8=_0x469679,_0x56cbf0=_0x10d145,_0x40c668=_0x57c199,_0x1127e5=_0x59ea0c,_0x31f6e9=_0x10d145,_0x4412f3={'JSVns':function(_0x48f25a,_0x4bc8e5){return _0x48f25a+_0x4bc8e5;},'PHSwb':_0x4316b8(0x3b0)+'es','oxbyl':_0x4316b8(0x135),'RwGLe':_0x56cbf0(0x289),'hWfcI':function(_0x523eb4,_0x488f9f){return _0x523eb4>=_0x488f9f;},'kythE':function(_0x5777dc,_0x2cb4ba){return _0x5777dc===_0x2cb4ba;},'CrdGX':_0x56cbf0(0x553),'FZScz':_0x1127e5(0x1c3),'xYSzY':_0x31f6e9(0x24f),'pBPuw':function(_0x2de0ab,_0x921596){return _0x2de0ab(_0x921596);},'DUKQk':function(_0x3af9c0,_0x4732ea){return _0x3af9c0+_0x4732ea;},'QyVTU':_0x40c668(0x540)+_0x4316b8(0x269)+'rl','mvMAE':_0x4316b8(0x522)+'l','cRsen':function(_0x44f77f,_0x59e0fe){return _0x44f77f(_0x59e0fe);},'TCcdU':function(_0x322508,_0x3386c3){return _0x322508(_0x3386c3);},'TCjjA':function(_0x3ab5d3,_0x103296){return _0x3ab5d3+_0x103296;},'wftOv':_0x4316b8(0x50c),'muMuN':function(_0x4eae94,_0x258dc5){return _0x4eae94(_0x258dc5);},'wtUEa':function(_0x4a7f9a,_0x41b339){return _0x4a7f9a+_0x41b339;},'OzApx':function(_0x5dc7de,_0x1b8e2e){return _0x5dc7de(_0x1b8e2e);},'ZedeH':function(_0xb79298,_0x59fcd1){return _0xb79298>=_0x59fcd1;},'FxKpw':function(_0x311776,_0x1b5c4d){return _0x311776!==_0x1b5c4d;},'rsbRS':_0x40c668(0x6d2),'uiPDe':function(_0xa2732b,_0x54e95a){return _0xa2732b+_0x54e95a;},'wnUMv':_0x40c668(0x16d)+_0x1127e5(0x1b6)+'l','mCURR':_0x56cbf0(0x16d)+_0x56cbf0(0x55d),'cfDns':function(_0x4d116d,_0x21944e){return _0x4d116d+_0x21944e;},'kVIGz':_0x1127e5(0x55d),'DFIio':function(_0x395411,_0x42438e){return _0x395411(_0x42438e);}};new_text=_0x51e96e[_0x31f6e9(0x180)+_0x40c668(0x1f2)]('（','(')[_0x56cbf0(0x180)+_0x31f6e9(0x1f2)]('）',')')[_0x40c668(0x180)+_0x4316b8(0x1f2)](',\x20',',')[_0x31f6e9(0x180)+_0x31f6e9(0x1f2)](_0x4412f3[_0x56cbf0(0x46a)],'')[_0x31f6e9(0x180)+_0x40c668(0x1f2)](_0x4412f3[_0x56cbf0(0x2fe)],'');for(let _0xd912a4=prompt[_0x40c668(0x52f)+_0x1127e5(0x6b1)][_0x4316b8(0x613)+'h'];_0x4412f3[_0x4316b8(0x6bd)](_0xd912a4,-0x5*0x6b7+-0x646+-0x65*-0x65);--_0xd912a4){_0x4412f3[_0x56cbf0(0x592)](_0x4412f3[_0x1127e5(0x2db)],_0x4412f3[_0x31f6e9(0x13c)])?(_0x23158e=_0x1a0a8e[_0x56cbf0(0x1d3)](_0x4412f3[_0x1127e5(0x715)](_0x419dd6,_0xcf490))[_0x4412f3[_0x4316b8(0x73d)]],_0x56b5b3=''):(new_text=new_text[_0x4316b8(0x180)+_0x31f6e9(0x1f2)](_0x4412f3[_0x4316b8(0x715)](_0x4412f3[_0x31f6e9(0x242)],_0x4412f3[_0x40c668(0x134)](String,_0xd912a4)),_0x4412f3[_0x56cbf0(0x63f)](_0x4412f3[_0x31f6e9(0x132)],_0x4412f3[_0x31f6e9(0x134)](String,_0xd912a4))),new_text=new_text[_0x40c668(0x180)+_0x56cbf0(0x1f2)](_0x4412f3[_0x4316b8(0x715)](_0x4412f3[_0x1127e5(0xe1)],_0x4412f3[_0x4316b8(0x481)](String,_0xd912a4)),_0x4412f3[_0x4316b8(0x715)](_0x4412f3[_0x40c668(0x132)],_0x4412f3[_0x40c668(0x209)](String,_0xd912a4))),new_text=new_text[_0x31f6e9(0x180)+_0x4316b8(0x1f2)](_0x4412f3[_0x31f6e9(0x4e9)](_0x4412f3[_0x56cbf0(0x42d)],_0x4412f3[_0x40c668(0x74c)](String,_0xd912a4)),_0x4412f3[_0x1127e5(0x206)](_0x4412f3[_0x40c668(0x132)],_0x4412f3[_0x4316b8(0x209)](String,_0xd912a4))));}new_text=_0x4412f3[_0x31f6e9(0x4ef)](replaceUrlWithFootnote,new_text);for(let _0x119c96=prompt[_0x56cbf0(0x52f)+_0x1127e5(0x6b1)][_0x40c668(0x613)+'h'];_0x4412f3[_0x1127e5(0x47a)](_0x119c96,-0x187d+0x95*-0x22+0x2c47);--_0x119c96){if(_0x4412f3[_0x56cbf0(0x687)](_0x4412f3[_0x1127e5(0x27e)],_0x4412f3[_0x1127e5(0x27e)])){if(_0x16dabc){const _0x592d10=_0xae215[_0x56cbf0(0x352)](_0x55b2ee,arguments);return _0x41914a=null,_0x592d10;}}else new_text=new_text[_0x4316b8(0x180)+'ce'](_0x4412f3[_0x1127e5(0x57e)](_0x4412f3[_0x31f6e9(0x55f)],_0x4412f3[_0x1127e5(0x134)](String,_0x119c96)),prompt[_0x31f6e9(0x52f)+_0x1127e5(0x6b1)][_0x119c96]),new_text=new_text[_0x4316b8(0x180)+'ce'](_0x4412f3[_0x40c668(0x206)](_0x4412f3[_0x4316b8(0x58f)],_0x4412f3[_0x31f6e9(0x4ef)](String,_0x119c96)),prompt[_0x1127e5(0x52f)+_0x56cbf0(0x6b1)][_0x119c96]),new_text=new_text[_0x40c668(0x180)+'ce'](_0x4412f3[_0x4316b8(0x704)](_0x4412f3[_0x40c668(0x692)],_0x4412f3[_0x56cbf0(0x4ba)](String,_0x119c96)),prompt[_0x1127e5(0x52f)+_0x4316b8(0x6b1)][_0x119c96]);}return new_text;}function chatmore(){const _0x51b22a=_0x59ea0c,_0x3fe9f6=_0x469679,_0x43c4cc=_0x2394fa,_0x3f79da=_0x2394fa,_0x4b298c=_0x59ea0c,_0x353250={'KhcCu':function(_0x21186b,_0x2cd4a6){return _0x21186b!==_0x2cd4a6;},'magjS':_0x51b22a(0x4c2),'pXbMk':_0x3fe9f6(0x6a9)+_0x43c4cc(0x183),'cRQdW':function(_0x48cf75,_0xae0201){return _0x48cf75+_0xae0201;},'HXdjE':_0x3fe9f6(0x1ca)+_0x51b22a(0x6cd)+_0x43c4cc(0x4af)+_0x3fe9f6(0x35e)+_0x4b298c(0x30a)+_0x43c4cc(0x5d5)+_0x4b298c(0x508)+_0x43c4cc(0x45c)+_0x4b298c(0x28c)+_0x4b298c(0x339)+_0x51b22a(0x655),'rpekC':function(_0x81fa70,_0x20926a){return _0x81fa70(_0x20926a);},'GZJyo':_0x3f79da(0x22d)+_0x3f79da(0x575),'BlpQg':function(_0x23da56,_0xd5fd7d){return _0x23da56===_0xd5fd7d;},'YmHzs':_0x43c4cc(0x186),'oxXMW':_0x3fe9f6(0x22e),'nibex':_0x43c4cc(0x237),'eFnmi':_0x3fe9f6(0x6a9),'OBXyk':_0x4b298c(0x624),'FpyOb':_0x4b298c(0x500)+_0x4b298c(0x605)+_0x51b22a(0x21e)+_0x4b298c(0xf2)+_0x43c4cc(0x32d)+_0x3fe9f6(0x469)+_0x3f79da(0x2d4)+_0x43c4cc(0x3c4)+_0x4b298c(0x189)+_0x3f79da(0x451)+_0x43c4cc(0x3d2)+_0x4b298c(0x27c)+_0x4b298c(0x565),'uVmhv':function(_0x414ce5,_0x2ba072){return _0x414ce5!=_0x2ba072;},'LujAV':function(_0x4718d6,_0x2544e9,_0x4d2521){return _0x4718d6(_0x2544e9,_0x4d2521);},'ULtkA':_0x3f79da(0x16d)+_0x51b22a(0x250)+_0x43c4cc(0x2a7)+_0x3f79da(0x1e6)+_0x3f79da(0x2cc)+_0x3fe9f6(0x584),'eJNfB':function(_0x394631,_0x33ceba){return _0x394631+_0x33ceba;}},_0x5b81c9={'method':_0x353250[_0x43c4cc(0x396)],'headers':headers,'body':_0x353250[_0x43c4cc(0x33a)](b64EncodeUnicode,JSON[_0x43c4cc(0xe9)+_0x43c4cc(0x1fe)]({'prompt':_0x353250[_0x43c4cc(0x3d5)](_0x353250[_0x4b298c(0x3d5)](_0x353250[_0x51b22a(0x3d5)](_0x353250[_0x43c4cc(0x3d5)](document[_0x3fe9f6(0x696)+_0x43c4cc(0x6ee)+_0x3fe9f6(0x6e9)](_0x353250[_0x3fe9f6(0x271)])[_0x4b298c(0x746)+_0x4b298c(0x6f5)][_0x3fe9f6(0x180)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x4b298c(0x180)+'ce'](/<hr.*/gs,'')[_0x3fe9f6(0x180)+'ce'](/<[^>]+>/g,'')[_0x3f79da(0x180)+'ce'](/\n\n/g,'\x0a'),'\x0a'),_0x353250[_0x43c4cc(0x416)]),original_search_query),_0x353250[_0x4b298c(0x6cc)]),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':![]}))};if(_0x353250[_0x51b22a(0x3e8)](document[_0x3f79da(0x696)+_0x3fe9f6(0x6ee)+_0x3f79da(0x6e9)](_0x353250[_0x43c4cc(0x383)])[_0x4b298c(0x746)+_0x51b22a(0x6f5)],''))return;_0x353250[_0x51b22a(0x37d)](fetch,_0x353250[_0x4b298c(0x601)],_0x5b81c9)[_0x51b22a(0x433)](_0x4b6416=>_0x4b6416[_0x43c4cc(0x740)]())[_0x3fe9f6(0x433)](_0x493656=>{const _0x3c76d7=_0x3fe9f6,_0x212be4=_0x51b22a,_0x230ccd=_0x3f79da,_0x1c5b6b=_0x3fe9f6,_0x1df278=_0x3fe9f6;if(_0x353250[_0x3c76d7(0x3e5)](_0x353250[_0x3c76d7(0x211)],_0x353250[_0x3c76d7(0x18a)])){const _0x5aa9e9=_0x3d354[_0x1c5b6b(0x708)+_0x3c76d7(0x654)+'r'][_0x212be4(0x43f)+_0x3c76d7(0x637)][_0x3c76d7(0x5a3)](_0x267186),_0x17dd92=_0x592a77[_0x21a47b],_0x3915ef=_0x42a9ef[_0x17dd92]||_0x5aa9e9;_0x5aa9e9[_0x212be4(0x4d6)+_0x3c76d7(0x4e6)]=_0x2c3587[_0x230ccd(0x5a3)](_0x45ad10),_0x5aa9e9[_0x230ccd(0x547)+_0x230ccd(0x41e)]=_0x3915ef[_0x1df278(0x547)+_0x3c76d7(0x41e)][_0x3c76d7(0x5a3)](_0x3915ef),_0x21757e[_0x17dd92]=_0x5aa9e9;}else JSON[_0x230ccd(0x1d3)](_0x493656[_0x1c5b6b(0x3b0)+'es'][-0x13*-0x7+-0x2e1*-0x8+0x1*-0x178d][_0x230ccd(0x28d)][_0x1df278(0x180)+_0x1c5b6b(0x1f2)]('\x0a',''))[_0x230ccd(0x3a0)+'ch'](_0x25350b=>{const _0x17eac5=_0x1c5b6b,_0x4d28fd=_0x1c5b6b,_0x3b1c30=_0x1c5b6b,_0x3d8227=_0x1df278,_0x3d6039=_0x1df278;if(_0x353250[_0x17eac5(0x39d)](_0x353250[_0x17eac5(0x5eb)],_0x353250[_0x4d28fd(0x5eb)])){const _0x835fd8=_0x103d97?function(){const _0x24beee=_0x17eac5;if(_0x3f3417){const _0x401b05=_0x475daa[_0x24beee(0x352)](_0x228929,arguments);return _0x50404e=null,_0x401b05;}}:function(){};return _0x8b4bcf=![],_0x835fd8;}else document[_0x3b1c30(0x696)+_0x3d8227(0x6ee)+_0x3b1c30(0x6e9)](_0x353250[_0x4d28fd(0x383)])[_0x3d6039(0x746)+_0x3d8227(0x6f5)]+=_0x353250[_0x4d28fd(0x3d5)](_0x353250[_0x4d28fd(0x3d5)](_0x353250[_0x3d6039(0x11f)],_0x353250[_0x3b1c30(0x33a)](String,_0x25350b)),_0x353250[_0x3b1c30(0x40f)]);});})[_0x43c4cc(0x3fa)](_0xbf3b4a=>console[_0x4b298c(0x519)](_0xbf3b4a)),chatTextRawPlusComment=_0x353250[_0x51b22a(0xf0)](chatTextRaw,'\x0a\x0a'),text_offset=-(-0xb1d+-0x69a*0x1+0x7e*0x24);}let chatTextRaw='',text_offset=-(0xe4e*0x2+0xdd9+-0x23c*0x13);const _0x5b1d06={};_0x5b1d06[_0x57c199(0x20e)+_0x10d145(0x4bd)+'pe']=_0x469679(0x24c)+_0x57c199(0x2c1)+_0x2394fa(0x726)+'n';const headers=_0x5b1d06;function _0x2501(){const _0xfb887e=['tor','dOIzY','XtfqD','能帮忙','QPfJs','Selec','ANGnu','vylcM','t_ans','\x20PRIV','yPumI','stion','HTML','UunQd','BSJKX','wPyFc','$]*)','\x20(tru','bKLeQ','ZSYSP','\x20KEY-','nbEdl','识，删除无','cCFlz','BuCZF','wFaLI','nnePq','cfDns','REgUd','aRXcz','MrByN','const','FhuHU','XeMHS','jerlD','PtIKr','介绍一下','harle','decod','WbbJo','fVLGt','qwipE','zDVBg','cbYBO','JSVns','mdFgv','VmCJZ','zrtXp','EXEVs','ouTEP','zxBPt','KjjIz','sLRhe','M0iHK','Dmmoq','cRFVu','RRXdU','ucKsK','MzyCf','input','cLNSL','n/jso','PtIYC','vIgvK','aYvdF','，不得重复','gYAWN','pOImY','18eLN','ITTBs','qvvql','Rrwly','jKsIA','ratur','QpJsg','gnjla','hdtHW','CVOEV','AFxgx','HpSzf','xWmoZ','后，不得重','BarbI','lWraW','PHSwb','YuTwD','o7j8Q','json','fedmr','GMHlI','MYbrO','dfGWp','pdVYf','inner','BJNSf','Z_$][','charC','论，可以用','SrBpE','muMuN','afLhP','tuAZB','IPaiQ','urMif','dBYRw','best_','YfwMh','value','ytKIS','rRhcj','AeVhn','bdOxV','tyRcX','找一个','mWQnP','Qhjlu','PoNvk','u9MCf','LpcyB','VIfyz','sGbHE','VJGHu','AcqaD','sJZNQ','VNcIc','azEVL','rErMF','fGiri','什么样','NAkqW','{}.co','FWgpQ','KfGvv','chat','cMPPh','nMVvL','tbGiE','NcsBB','DWWOF','mvMAE','fDlSD','eQjpr','s的人工智','cASQd','joxBc','容：\x0a','YbUAl','strin','GwPEj','zEvLH','bafru','lCbLC','RkcNF','call','eJNfB','hCNyb','知识才能回','PJUtw','WaKbn','g9vMj','body','ozRMJ','hfaEe','pfMkO','hxItf','sbQSC','ldkaF','198EBqpbY','mFmsM','clHDm','wgysn','xgVOn','szNUj','aNZgz','info','gLHBl','CPdfX','enqXy','cnBcw','定保密，不','gfrcj','wFcat','oRawA','WCjPC','count','slYuc','LChWD','uage=','remov','文中用(链','UIILX','kvGuE','kn688','CYuCW','oktua','QthMA','iZfEX','mXuZO','geBVR','sVQQj','yWNbn','HXdjE','WflBH','t=jso','DDdHv','ZMHzZ','vCuAk','z8ufS','rn\x20th','MRcDU','RviUT','ctAIo','hikbg','fsgOd','DkKmr','eral&','NKait','OrPEb','WfXqU','jBvNE','QyVTU','ClIif','pBPuw','链接:','t_que','KbAtC','NlXoy','fromC','dCHcK','bxoUk','FZScz','name','xuzYu','JlDiv','QAB--','vqCmc','THDFK','VzqID','chain','nUEbI','pRkdO','GnzGy','75uOe','ngyyE','eCYOq','引入语。\x0a','mMEDK','jVEPJ','OacAh','CtSrf','XMvMK','</div','jcpKr','DKTDD','qBGKp','XyFpi','nce_p','njRZQ','qJJGN','lLYhL','HyXCX','zvMWP','AJhGi','pixfM','EmRvk','SHzmM','UHlqK','9VXPa','xtXbE','HtSWY','cyJVe','RSPlM','oTMMH','MZSFO','enjtr','Qrhfm','pUMUq','TIPnx','hXdDO','https','CdXxr','chat_','jxPyL','zFe7i','wuqkq','buvxf','xexjF','more','yFzUr','aUmHX','logpr','nPcEx','gDcOE','cPxlM','bVbgX','nymOi','LfZNc','Charl','repla','uxvVX','dEEul','_more','HveXb','iaEHD','dOuKJ','JIblZ','wrtpN','组格式[\x22','oxXMW','kTYzR','CDuAO','sJtkM','jpDQL','kKPsj','SLlpV','Bjpat','JciiA','OYuet','xcsIJ','IBCgK','kwjmO','FSvBl','zBSSz','THdBs','OIuvp','UwBGh','zXvrf','lwJSi','pngid','pkcs8','sxjGX','des','yygfm','intro','JNxBA','PtsLR','HWHWF','wJ8BS','YGpts','BEGIN','<div\x20','cNBKf','YVxjy','CXxwL','JWToI','xKbyX','bQhvN','AZEfN','Xnfkt','WHgLw','uNeYL','prHnP','://ur','fqyIX','omiXz','hZgOx','hveMg','state','vEmCT','9482sxvimF','为什么','rLfIK','cPnQE','cLGWc','FdFSQ','TkOaz','trim','aXamd','conso','Zgxg4','-MIIB','zNblE','<butt','fFpaR','DgVek','RiZrA','KFtwn','hopTm','OFCKc','bGnyW','mFHoQ','parse','NeEwO','jAooK','gvcWi','jtjgg','gdZGC','gorie','pcyza','e=&sa','oxes','Kjm9F','fhFJl','TBWzs','vPkIE','forma','的是“','aBYTq','NpKjE','90njvRId','kg/co','应内容来源','wClVX','ZxLmE','UIfpc','nHcGa','LNyAV','FnTuK','YDvRZ','你是一个叫','raws','VjCTw','ceAll','34Odt','LWfHt','BAQEF','BgpNJ','JNxXI','hQZpf','qCpDm','zFkKE','xNMyR','rgqCI','WFFHT','gify','searc','XoAxx','GbBIQ','mOkvk','kMgso','oPocZ','aQHhD','wtUEa','HLBRx','PASeO','TCcdU','warn','YgSF4','bYUEm','KJEnV','Conte','grHrd','\x0a以上是“','YmHzs','rtpbH','XwJNK','XZVuu','不要放在最','MMzrP','Fekoh','54712ogEsLn','hZAbU','pEMRk','gHkMe','AgnIq','ocQNF','要更多网络','zA-Z_','Yiobw','QkSGc','fesea','TclQI','VBWNS','GnZcJ','read','什么是','ROqkD','ZaBQq','90ceN','gger','dTMIz','</but','SUTuN','MEOBa','prese','2RHU6','ion\x20*','qWxNo','split','fOsiB','NhwOp','POST','AQgvn','tCAGh','pNpOY','能。以上设','ELGxJ','byteL','hUQHB','jmrPp','UBLIC','xinay','xYSzY','qlEkx','HIrin','UxQHx','gbFGS','FpiWz','HKQmY','vMmGC','ntmlS','VZLNJ','appli','has','rmLPA','(url','://se','VZEoQ','BfDmw','HzlXw','eIfPZ','kCuiG','odePo','cgkfg','qjXIU','zGGBQ','FkYlw','jbzgU','mkMqH','OMOVb','NhhDn','ummTa','RIVAT','jLaHk','EpcCh','SEpiF','体中文写一','归纳发表评','EgRSl','vHKaz','DwNzN','s://u','iaixZ','join','nMZMK','ZuZJp','beQhS','LKlBg','SyohG','eFnmi','QxSjb','ader','IkGpG','OCcTN','ApwkO','RLyav','okens','EgBjQ','xYHOB','JmIuO','q3\x22,\x22','mmqgR','rsbRS','vQGYC','sclji','tIDlb','zPVna','CTAoq','UaGWp',')+)+)','wCdrk','unTvs','KlfdY','链接：','NGzSX','\x0a提问：','ebcha','text','SsHAQ','DwymF','AsQgs','bPutZ','HLIDg','YSsfW','PJylX','XZTAn','frtrp','oijna','XLLhc','IcJGO','WQHSt','VCgWb','uwrEh','mHuQD','dpryf','E\x20KEY','MjRXB','CGjRw','textC','vKsdH','SIDis','CnAhW','SCPKv','arch.','irjYc','XokWT','qpips','XEbea','QhQBc','QjEBl','VaLVj','Jrhzt','sOWni','CnRgN','dfRih','nctio','ALNWg','funct','mOwZp','AlboT','内部代号C','NhvdN','acget','rCJIf','YyXuu','getRe','接)标注对','terva','snGjA','catio','务，如果使','RmlXM','pCCwc','kHqII','RoblI','infob','CejSF','mVDaq','bZNsI','QgbYU','mplet','empHB','test','ltuXx','PemkS','gzCkG','LwqDg','Pcazy','独立问题，','vVpmi','prKXb','JJMNv','max_t','DVBYv','BCRyE','CrdGX','aGeEp','EkvkX','cWjNc','UpQfh','WoKrT','LavUY','AEP','Error','rzFsN','mqQMt','mtbtk','retur','tFbxc','VoSmj','evlWK','DtGYG','WciAJ','text_','es的搜索','XmlXj','NnTZm','VRvXf','OhetW','IpyYb','promp','gLnXF','RCNyQ','XCwIt','aSCHp','a-zA-','SJwJO','qaDTy','KZAEm','Heezr','RwGLe','NAoRc','_rang','vvPlt','sWYGl','int','OJbAv','SYnFJ','EYaPZ','xydPv','SoBxr','qYbvB','ore\x22\x20','Mngrr','bekdX','lPWUT','SBjsg','息。\x0a不要','mWNOv','gvjap','SqTMI','ById','EkmNB','bdUhq','xsywQ','HsOaP','hzWwa','CymwM','s=gen','EwToq','jatIn','mfaLG','nue','vIUeF','kIfUv','gpEDE','tDFPw','cNUHW','关内容，在','gkqhk','njIdH','iyUxe','，用户搜索','ycdOV','pRkxw','DHVEu','qiVbM','答的，不含','vGsif','Q8AMI','aumQo','Esxyk','TNLla','bWWNK','fdqwQ','TKbLH','map','UBgal','BeQZq','t(thi','rpekC','IyFtw','XzhHi','uTHnp','HPMmx','gzzRf','RSA-O','---EN','AjoDI','ATcYM','WxGbj','zeHln','obs','用了网络知','pGpnA','ExIMG','oxeWc','mtCLi','fucNS','qZdwr','AMhCo','vfhib','围绕关键词','gslMN','apply','sUbyF','Djuxb','aWLZq','MCTzv','jrMez','qMsAe','gnAlk','yIDQu','KIENJ','iBJJe','gdfwB','btn_m','(((.+','next','IcFQv','KZSiC','mgcVi','YYnEG','iUuAB','AAOCA','MWoTQ','iZOti','ATE\x20K','PHZvq','yEnHY','LBVNM','LIvuA','VYHND','sUsXe','neRkH','告诉我','sZHHH','DGdSd','yvVNM','gFRqy','ri5nt','EodbC','ldLVU','tion','NyKeq','onten','ljdvt','LujAV','NMfga','CAQEA','penal','gnLlQ','oCfqR','pXbMk','gNkVc','ANSyS','KKCtA','HGltO','WCKKh','JkeMh','ipZaK','dRuDK','aJvpM','DfGIh','VvvmK','VqUTL','uCYez','GVOjy','wPgyz','RfSnk','告诉任何人','ZydJB','nibex','omQaj','sDbUn','LPpih','pOwdV','xpADe','kRTDE','KhcCu','beLwS','iBvlB','forEa','jqyyI','piQDw','RFPJM','nRLBJ','kedCg','zhSHp','arch?','OwmqD','VGfHs','ApNOo','class','ZpKHB','cEOQs','MAlSo','\x0a以上是任','choic','FIheP','impor','FLBbi','eGekH','提问：','假定搜索结','IjANB','rMplG','ojFqA','add','HADjh','哪一个','vfQxy','vcQbA','dBnBq','PEwnN','djheq','wswPx','pCRlM','json数','bBkXG','&time','KQWvi','ylkMu','dfdeV','yJNJn','BZVrP','PcuJv','qvhSs','-----','WqUDF','SCwuG','iZJWW','q2\x22,\x22','LkajO','BExQd','cRQdW','top_p','EWLge','pCGxw','grpgr','spki','oCjhC','oeiYS','ILMYd','size','OnLBn','offse','SeOZB','tblUO','izgFy','pfBWI','BlpQg','OyWwi','”，结合你','uVmhv','hBwEv','KIUjx','437301XiEzEY','bInuP','zh-CN','wer\x22>','dAtOP','rSgCJ','GQXKS','THddh','JwGKk','EYyGh','vOkhl','BRVaC','WdMfi','XQvkd','OQXva','catch','引擎机器人','decry','utf-8','hDQnh','Mpvyq','jqiFD','nOdVR','hfLLR','mcFPl','imLua','ZehbJ','emoji','zHqdK','KVSZN','VZHWA','EGqlI','getEl','conti','1362040oWPPbU','Lyzmu','GZJyo','HyYbE','zwnre','cSqeZ','spdYN','qgUFT','init','OBXyk','gKYrj','xOWkq','cmRNJ','CFAOT','QaKkN','vePrm','osApJ','ing','OLJhj','eBfdF','AWgxQ','WPBuQ','Jlftr','dDZqt','aIgUw','识。用简体','MQOsb','kwTLh','Ppnco','xHxrr','o9qQ4','actio','wftOv','MYFZa','lwxvP','rTasm','aIdmG','iFLQl','then','&cate','kbwsL','zztgY','zeedc','PBxaC','[DONE','SOHml','VQSjj','xbuMg','tYVNe','phoTY','proto','vXwGH','rMOYm','句语言幽默','UGbxA','Ldnje','mFcpu','nbaEn','bsDbO','GBDGm','查一下','SsaRg','CLAUq','kXRFr','fuPrS','ement','oQjvy','irvyL','q1\x22,\x22','nQmlG','gRbZd','niZzP','OzHSs','mOYKt','ZvCgV','data','WjlUo','xvfvT','753275ZwFpHu','end_w','mUAQn','NQEVx','XQylK','UtbOy','Rmsmx','bElCZ','GumZV','tlsmM','KFFAq','displ','bODsd','ZaPdi','代词的完整','oxbyl','cbqIm','RRUqG','PMoat','rRDmH','IGveU','trace','mGoOk','lnrqp','RroFT','IOZmX','设定：你是','XNOMt','SFOZt','nftNf','PGoZB','ZedeH','OdtSl','CrEUf','eYlOv','cgwyF','PjtGf','SlUqw','cRsen','PdbEF','rlUJI','QaQxD','InIUw','scMBa','while','QDpPf','tpUbz','yqbQj','r8Ljj','BQOMB','ZVAQE','XJAWc','LbvSW','JFcrZ','RdCwH','quOmY','vmeCK','enalt','vvcqw','mXPzd','eYsTM','Efgyi','vNqCc','EPBpp','MeKgj','pRouA','aXcmy','Yfvxj','VuYYu','0-9a-','\x5c(\x20*\x5c','xjVJI','brPjd','KqEBp','KjTRH','fZqPO','*(?:[','DvsGw','RPpro','”有关的信','moji的','stmsS','onKor','7ERH2','ass=\x22','FaLZg','SswRM','uhBPy','VFasi','aFuMQ','复上文。结','NLxZX','eqdBm','EVaFL','UPqNs','DFIio','tKey','BuiJv','nt-Ty','_inpu','zauhU','BfXYQ','table','RMnel','GjDaK','NrsCX','qzfNJ','pbhac','ctor(','uGMvi','提及已有内','qqopf','pClAt','hFEfJ','zpqij','oGvSj','DYpDO','hQlqj','kgVMm','VwKCi','EBKBc','excep','POISI','__pro','WdLFV','IJfLg','lVrrC','Jpiql','GkKBN','6f2AV','soYxE','bqPmo','gIDCI','jOGGx','seqsh','FncRw','yTmaL','pBVHW','5U9h1','to__','中文完成任','AIZpZ','TCjjA','YlssC','UGyvh','odeAt','jthJr','Mhcon','OzApx','Syngk','KSuAW','TGJLi','INLQq','WmFQz','hKbeH','geIWL','dltgx','Og4N1','UkXCv','ZCvGw','----','NLmFt','BvEfh','2A/dY','\x0a回答：','”的网络知','setIn','mLney','XCYAr','strea','ElCzi','fy7vC','CcyYK','ck=\x22s','kqeUQ','KoWXz','HgsDd','(链接','AOEED','JhFJz','nUDtP','fcfSy','LcmKY','写一段','subtl','CUKqT','GlcRs','tlIUX','kjvfF','UcWJb','error','tVIIa','dteYE','uXjmR','zjTTN','rAcWC','BbqOF','KnZhQ','lYEJU','(链接ur','iG9w0','uvVEG','pQUsZ','Rdfkt','HuMvK','nstru','Objec','WfeFV','kYZhv','IpfEE','ipoDh','tempe','url_p','blqsq','GPMmO','ency_','MmzEv','ibyDM','uZzOs','GZNzN','conte','jQyum','MiKTu','tmWJU','GPAhK','iaPeU','WFEBt','ThXne','\x5c+\x5c+\x20','(http','EkRng','QjXAE','XIIFe','的知识总结','GKZBS','nYwvM','toStr','PaSad','hf6oa','xPZXA','EhEgX','gdxyG','echo','bJFBY','ugRcC','AXIXP','gjqKv','请推荐','ejAvF','XtpKI','BdXNO','xJABB','BbRfP','4hMjlty','mVwyt','pwqbQ','VZLdp','WjAhF','url','rJvzt','wnUMv','oiTTO','heUac','JRKkk','\x22retu','tOmuu','q4\x22]：','hNxqE','DksZM','FFTTf','MIUCR','ziyiT','END\x20P','POuDG','iflxT','zxPWD','mTXtx','OPJzs','FhbLJ','nxLtk','cmFTn','encry','ton>','YmTAq','PRomM','gxHKP','hqdoY','bawmy','wUjwa','nfpqz','nsKOH','uiPDe','jCUNY','aqCQk','JrKUg','qvebM','IgCBr','ions','WklBz','NnsOK','nIsrS','ipIVq','AzGCq','aIAtv','fPhlk','写一个','Slnam','bkkuB','mCURR','SUnIZ','链接，链接','kythE','dLSnA','aMdXt','5eepH','FHmCS','KWlov','JZQCn','HEPqi','LHHaO','ElBQZ','fwIDA','yQKyE','有什么','etusg','zRnNC','OLFYv','VnMCx','bind','sPWKR','x+el7','BkLgJ','59tVf','syhbS','mCfyk','bcPqp','Tjfhc','RhPEq','awJEL','UkiBJ','adXdh','NSRlY','UCmYk','PqbJE','naKRg','cYzLe','995740RDsnfY','UAAUk','QMifA','SHA-2','AgynX','VwoUu','ngxnq','mevhl','5Aqvo','WYxPD','kVRiG','wKVvl','PEHcq','ndczE','qObrJ','Vvtwi','iZHXg','bIFUG','yRpLB','VhyEY','mJTKE','NHfiX','fbCiU','fBUOJ','rBdKV','IRVWW','=\x22cha','D\x20PUB','fcQjZ','Fgnxf','RCJzZ','PHXeR','oncli','mTZHp','bTqBs','UwyUO','tBJHx','FSGXd','XdLFl','rVWmJ','XNwaL','KSqnk','MgcIv','gDxlK','jWlaQ','WQLwA','kzGAr','Xknnm','voTof','yvjsI','hZNyV','ombpQ','DghMm','sAaXG','magjS','JcXwh','qLTCX','LcslY','FQTum','RRclH','qELdi','xYfyH','DwZph','kkNVU','WGUiq','wAGPv','subst','CmzDc','exec','qqTzZ','puYPe','DBfVK','nGRds','xfxAz','qAqkm','Jubhq','ULtkA','BpWQL','deLve','iYnwq','识。给出需','aDzBg',']:\x20','qsZqY','UpfIh','DCedW','VQTgx','VpPbX','Njdjw','upFdu','srzsI','pqkUa','aFPVJ','已知：','lengt','STvOl','RE0jW','gxQAH','zilGt','Ga7JP','debu','wXWTg','ueRYF','kg/se','pYHpX','qqKQJ','g0KQO','TfDEF','NpHDM','fAymY','delet','以上是“','qgAMf','dfun4','EhuBS','Y----','Gttzo','amfiz','cvwgB','KrmGQ','gECSV','cwZos','XxoYe','SgYhe','kZqau','WfWRE','alopD','的回答：','cFKgF','ryvrg','type','gqkJj','AOSiM','aqqMt','D33//','XHz/b','ring','ESazm','DUKQk','vEIVO','\x20的网络知','jWCmJ','uaSlK','3DGOX','erVay','PJRkD','ZJAcD','iXsyD','EAzLL','hgKAv','\x0a以上是关','ZdJEx','\x0a给出带有','UBYeJ','VwTCy','9kXxJ','zgwRb','n\x20(fu','SWwlU','ructo','s)\x22>','EFcEI','VTyfL','DyNyf','qxGTu','NlqdS','fYItq','kAujI','eunNr','ength','57ZXD','EY---','132148OvGFFR','yeKrZ','PuXOK','e)\x20{}','VHelV','Orq2W','twIhF','UtFva','FHPkZ','fCAgy','rsiSF','qamcH','inclu','lerTb','PhLGG','rch=0','&lang','FBARo','AhGrR','CBIVI','xDgSe','kiuUG','n()\x20','hrDKT','VFyQA','style','的、含有e','KbVbg','ADDMx','ymWro','SxxRi','SUlQU','HSotA','zQxCb','Uxouz','QfsXp','qyQYU','khUKu','FxKpw','CuTbM','RRnda','SmaFL','#prom','ywzny','lnmpr','果。\x0a用简','ZRneN','sQcRM','LhyLO','kVIGz','MwVjG','oUslh','IC\x20KE','query','fgthH','GcJtb','asqbu','noZmN','\x20PUBL','Dubqf','qNNFF','cDHMO','NnJHB','OJHgL','fjXwO','ZDcZZ','UJpQP','xChjT','键词“','LLylW','XmScS','aJLUe','#chat','txUZd','gmYDW','NvnTh','NYqZf','dCKPm','frequ','WvWAL','air','nHcTv','qoFiD','pdVIS','WKlWb','upZft','md+az','DkLXV','jfotB','IhFGA','xsWpe','SgoUv','hWfcI','WFOpI','KkNMJ','kqcfP','LIC\x20K','机器人：','WJfRm','XEblN','SoafZ','dQjhy','hfLvo','XnvhV','”的搜索结','MSMKq','VzgDE','FpyOb','on\x20cl','zxhJM','WsqYd','bWVxx','qXSRc','WpcjF','xTvAX','哪一些','UGCzO','VHBlB','mZODy','Yjzoh','is\x22)(','slice','yGUfE','ITqOl','dCeTX','Fivzb','kSbLj','TAdVz','JDEIv','cqNzA','tdVUp','log','b8kQG','NMQPu','ygYkK','VAZbM'];_0x2501=function(){return _0xfb887e;};return _0x2501();}let prompt=JSON[_0x57c199(0x1d3)](atob(document[_0x2394fa(0x696)+_0x59ea0c(0x6ee)+_0x2394fa(0x6e9)](_0x2394fa(0x68b)+'pt')[_0x2394fa(0x2a2)+_0x2394fa(0x37b)+'t']));chatTextRawIntro='',text_offset=-(0x266c+-0x16fe+-0xf6d);const _0xefd690={};function _0x2a23(_0x537f18,_0x574ed1){const _0x5b67c6=_0x2501();return _0x2a23=function(_0x4f0859,_0xd19597){_0x4f0859=_0x4f0859-(0x133e*-0x1+-0x1d09+-0x1887*-0x2);let _0x17be4c=_0x5b67c6[_0x4f0859];return _0x17be4c;},_0x2a23(_0x537f18,_0x574ed1);}_0xefd690[_0x469679(0x2f4)+'t']=_0x469679(0x1ef)+_0x469679(0x17f)+_0x469679(0x2ee)+_0x2394fa(0x3fb)+_0x10d145(0x328)+_0x57c199(0x1e2)+original_search_query+(_0x469679(0x4aa)+_0x10d145(0x30f)+_0x469679(0x3b6)+_0x59ea0c(0x68e)+_0x10d145(0x264)+_0x2394fa(0x442)+_0x2394fa(0x67b)+_0x59ea0c(0x4ab)+_0x59ea0c(0x14b)+_0x59ea0c(0x6c2)),_0xefd690[_0x2394fa(0x2d8)+_0x2394fa(0x278)]=0x400,_0xefd690[_0x469679(0x52e)+_0x2394fa(0x732)+'e']=0.2,_0xefd690[_0x2394fa(0x3d6)]=0x1,_0xefd690[_0x469679(0x6af)+_0x469679(0x532)+_0x2394fa(0x380)+'ty']=0x0,_0xefd690[_0x469679(0x230)+_0x57c199(0x156)+_0x469679(0x494)+'y']=0.5,_0xefd690[_0x10d145(0x752)+'of']=0x1,_0xefd690[_0x59ea0c(0x54d)]=![],_0xefd690[_0x10d145(0x178)+_0x59ea0c(0x346)]=0x0,_0xefd690[_0x469679(0x504)+'m']=!![];const optionsIntro={'method':_0x59ea0c(0x237),'headers':headers,'body':b64EncodeUnicode(JSON[_0x469679(0xe9)+_0x10d145(0x1fe)](_0xefd690))};fetch(_0x10d145(0x16d)+_0x59ea0c(0x250)+_0x2394fa(0x2a7)+_0x59ea0c(0x1e6)+_0x59ea0c(0x2cc)+_0x59ea0c(0x584),optionsIntro)[_0x10d145(0x433)](_0x1bd707=>{const _0x5d9ae3=_0x57c199,_0xa48d77=_0x10d145,_0x268706=_0x59ea0c,_0x327550=_0x59ea0c,_0x11176e=_0x57c199,_0x30c0a5={'XwJNK':_0x5d9ae3(0x6a9)+_0x5d9ae3(0x183),'cSqeZ':function(_0xe5baba,_0x1e779e){return _0xe5baba+_0x1e779e;},'Yiobw':_0xa48d77(0x1ca)+_0xa48d77(0x6cd)+_0xa48d77(0x4af)+_0x327550(0x35e)+_0x268706(0x30a)+_0x327550(0x5d5)+_0x5d9ae3(0x508)+_0x327550(0x45c)+_0x5d9ae3(0x28c)+_0x11176e(0x339)+_0x268706(0x655),'Mpvyq':function(_0x390adb,_0x5e00e9){return _0x390adb(_0x5e00e9);},'KbVbg':_0x327550(0x22d)+_0xa48d77(0x575),'pdVYf':function(_0x230c14){return _0x230c14();},'PtsLR':function(_0x3dd6b5,_0x487a56){return _0x3dd6b5===_0x487a56;},'IkGpG':_0x5d9ae3(0x241),'cnBcw':_0xa48d77(0x2e3)+':','sZHHH':_0x5d9ae3(0x3b0)+'es','sclji':function(_0x47587f,_0x14b29c){return _0x47587f-_0x14b29c;},'JkeMh':function(_0x43a626,_0x39aaec,_0x151f1a){return _0x43a626(_0x39aaec,_0x151f1a);},'cEOQs':function(_0x5b8c82,_0x41b97a){return _0x5b8c82<_0x41b97a;},'mVwyt':_0xa48d77(0x3af)+'务\x20','ygYkK':_0x11176e(0x641)+_0xa48d77(0x426)+_0x268706(0x4e7)+_0xa48d77(0x2c2)+_0x5d9ae3(0x347)+_0xa48d77(0x6ff)+_0xa48d77(0x324)+_0xa48d77(0x113)+_0x11176e(0x2be)+_0x327550(0x1e7)+_0x5d9ae3(0x591)+_0x327550(0x215)+_0x268706(0x73a)+_0x11176e(0x4b5)+'果：','JmIuO':_0x11176e(0x2b5)+_0x268706(0x232)+_0x11176e(0x4a1)+')','FIheP':_0xa48d77(0x53f)+_0xa48d77(0x4a7)+_0x5d9ae3(0x2f9)+_0xa48d77(0x748)+_0x327550(0x4a0)+_0x327550(0x21f)+_0x268706(0x6f9),'NpKjE':function(_0x560783,_0x4726e9){return _0x560783(_0x4726e9);},'SEpiF':_0xa48d77(0x415),'jthJr':_0x327550(0x144),'MSMKq':_0x5d9ae3(0x724),'pCGxw':_0xa48d77(0x6cf),'AjoDI':_0x327550(0x32e),'SYnFJ':function(_0x1f7593,_0x17668b){return _0x1f7593>_0x17668b;},'VZHWA':function(_0x1a59c1,_0x428c3a){return _0x1a59c1==_0x428c3a;},'rRDmH':_0x327550(0x439)+']','wKVvl':_0x11176e(0x353),'DVBYv':_0x11176e(0x16f)+_0x5d9ae3(0x40c)+_0xa48d77(0x31e),'iyUxe':_0x11176e(0x16f)+_0xa48d77(0x175),'mHuQD':function(_0x629029,_0x359a6e){return _0x629029!==_0x359a6e;},'RRclH':_0x327550(0x11d),'cPxlM':_0x327550(0x3df),'deLve':_0x5d9ae3(0x1ce),'mmqgR':_0xa48d77(0x343),'WjAhF':_0x5d9ae3(0x667),'tCAGh':_0xa48d77(0x254),'HPMmx':_0x11176e(0x5cd),'KFFAq':_0xa48d77(0x13f),'szNUj':_0x5d9ae3(0xdb),'mZODy':_0x5d9ae3(0x60d),'grpgr':_0x5d9ae3(0x3fd),'RCNyQ':_0x268706(0x133),'YYnEG':function(_0x5b4cfa,_0x38d7c4){return _0x5b4cfa+_0x38d7c4;},'jVEPJ':_0x5d9ae3(0x2e7)+_0x268706(0x652)+_0x268706(0x2b3)+_0x268706(0x677),'aDzBg':_0x11176e(0xd8)+_0x11176e(0x528)+_0x11176e(0x4c7)+_0x327550(0x563)+_0x327550(0x126)+_0x5d9ae3(0x6d9)+'\x20)','kXRFr':_0x11176e(0x169),'mCfyk':function(_0x3bcd10,_0x1055fe){return _0x3bcd10===_0x1055fe;},'UkXCv':_0xa48d77(0x5ab),'lVrrC':_0x5d9ae3(0x53d),'hBwEv':_0x268706(0x237),'qvhSs':_0x11176e(0x350)+'“','yvjsI':_0x327550(0x3e7)+_0x268706(0x544)+_0x268706(0x265)+_0x268706(0x74a)+_0x5d9ae3(0x406)+_0x11176e(0x72a)+_0xa48d77(0x4c9)+_0xa48d77(0xe7),'nPcEx':_0x327550(0x6a9),'grHrd':function(_0x2d09f7,_0x35b1ae,_0x2b047a){return _0x2d09f7(_0x35b1ae,_0x2b047a);},'VzgDE':_0x268706(0x16d)+_0x327550(0x250)+_0x268706(0x2a7)+_0x327550(0x1e6)+_0xa48d77(0x2cc)+_0x11176e(0x584),'txUZd':_0x268706(0x526),'hfLvo':_0x327550(0x19a),'qzfNJ':_0x11176e(0x72c),'scMBa':_0x11176e(0x36e),'NAkqW':_0x327550(0x18f),'bJFBY':function(_0x20a3ac,_0x1aa010){return _0x20a3ac>_0x1aa010;},'cyJVe':_0x11176e(0x616),'Uxouz':_0x327550(0x54c),'CFAOT':_0x268706(0x5d6),'OPJzs':_0xa48d77(0x294),'gDcOE':function(_0x5d710c,_0x13384a){return _0x5d710c-_0x13384a;},'OwmqD':function(_0x28499b,_0x4f4d24){return _0x28499b===_0x4f4d24;},'mOwZp':_0xa48d77(0x29e),'NSRlY':_0x11176e(0x135),'lwJSi':_0x327550(0x289),'GPAhK':function(_0x5e57ff,_0x101dc5){return _0x5e57ff>=_0x101dc5;},'KnZhQ':_0x327550(0x24f),'vCuAk':_0x268706(0x540)+_0xa48d77(0x269)+'rl','BfDmw':_0xa48d77(0x522)+'l','wUjwa':_0x5d9ae3(0x50c),'eGekH':function(_0x17dadc,_0x5e2ed9){return _0x17dadc(_0x5e2ed9);},'WCjPC':function(_0x1446b1,_0x77e2b0){return _0x1446b1+_0x77e2b0;},'azEVL':function(_0x39e637,_0x38afd7){return _0x39e637>=_0x38afd7;},'nymOi':_0x11176e(0x16d)+_0xa48d77(0x1b6)+'l','lwxvP':function(_0x1fff6f,_0x373522){return _0x1fff6f+_0x373522;},'rLfIK':_0x327550(0x16d)+_0x11176e(0x55d),'mJTKE':function(_0x96ca50,_0x443d42){return _0x96ca50+_0x443d42;},'fbCiU':_0x327550(0x55d),'nbaEn':function(_0x116695,_0x3ecb5b){return _0x116695(_0x3ecb5b);},'naKRg':function(_0x2b52d2,_0x564031){return _0x2b52d2===_0x564031;},'vPkIE':_0x11176e(0x3c2),'CrEUf':function(_0x3600cb,_0x43c6f3){return _0x3600cb>_0x43c6f3;},'oeiYS':function(_0x2cbe46,_0x40b783){return _0x2cbe46==_0x40b783;},'XzhHi':function(_0x37553,_0x3d396f){return _0x37553===_0x3d396f;},'rAcWC':_0xa48d77(0x5a0),'bVbgX':_0x11176e(0x326),'nfpqz':function(_0x5200c9,_0x5eb194){return _0x5200c9(_0x5eb194);},'BbRfP':function(_0x410de2,_0x24af5e,_0x4aa835){return _0x410de2(_0x24af5e,_0x4aa835);},'QDpPf':_0xa48d77(0x4b6),'OhetW':_0xa48d77(0x5f8),'SUlQU':function(_0x131d3a,_0x4e480c){return _0x131d3a+_0x4e480c;},'zBSSz':function(_0x2e8ec8,_0x7f126f){return _0x2e8ec8!==_0x7f126f;},'RviUT':_0x5d9ae3(0x61b),'cmFTn':_0x268706(0x562),'YDvRZ':function(_0x2e0546,_0x34c86b){return _0x2e0546===_0x34c86b;},'Yjzoh':_0x327550(0x159),'kRTDE':_0xa48d77(0x58a),'ldkaF':function(_0x4b10ad,_0x479067){return _0x4b10ad>_0x479067;},'nbEdl':function(_0x546b83,_0x7780ad){return _0x546b83>_0x7780ad;},'nftNf':function(_0x43a0e2,_0x2f8087){return _0x43a0e2===_0x2f8087;},'mfaLG':_0x11176e(0x6e2),'VjCTw':_0x268706(0x36c),'NlXoy':function(_0xf4afcc,_0x418c5e){return _0xf4afcc-_0x418c5e;},'qXSRc':function(_0x505555,_0x1c9d4c){return _0x505555+_0x1c9d4c;},'pngid':_0xa48d77(0x16f)+_0x11176e(0x1a3),'vcQbA':function(_0x3601a0,_0x260915){return _0x3601a0(_0x260915);},'iZOti':_0x327550(0x340)+_0x268706(0x2e2),'gIDCI':function(_0xc8d5c3,_0x548012){return _0xc8d5c3-_0x548012;},'rErMF':function(_0x4c2a9b,_0x8ee055){return _0x4c2a9b===_0x8ee055;},'syhbS':_0xa48d77(0x19c),'RPpro':function(_0x136333,_0x4ec4e6){return _0x136333+_0x4ec4e6;},'vfQxy':_0x5d9ae3(0x619),'UGbxA':_0x327550(0x22b),'VNcIc':_0x5d9ae3(0x42c)+'n','jAooK':_0xa48d77(0x487)+_0x268706(0x6fa)+_0x11176e(0x664),'fedmr':_0x268706(0x10e)+'er','Ldnje':_0x327550(0x3ce)+_0x11176e(0x1a9)+_0x5d9ae3(0x6f2)+_0x5d9ae3(0x369)+_0x327550(0x660)+'--','qELdi':_0x327550(0x3ce)+_0x5d9ae3(0x56b)+_0x11176e(0x260)+_0xa48d77(0x29f)+_0x11176e(0x3ce),'PJUtw':_0xa48d77(0x19f),'DDdHv':_0x327550(0x5b8)+'56','mqQMt':_0x11176e(0x3fc)+'pt','spdYN':function(_0x5cc2a2,_0x1f0c37){return _0x5cc2a2+_0x1f0c37;},'qvebM':function(_0x418850,_0x7dce80){return _0x418850+_0x7dce80;},'NMfga':function(_0x285f3d){return _0x285f3d();},'VJGHu':function(_0x227f1a,_0x285433){return _0x227f1a===_0x285433;},'vXwGH':_0x327550(0x4b8)},_0x132ba3=_0x1bd707[_0x5d9ae3(0xf6)][_0x327550(0x2bd)+_0xa48d77(0x273)]();let _0x3ae682='',_0x56d393='';_0x132ba3[_0x5d9ae3(0x226)]()[_0x11176e(0x433)](function _0x49b788({done:_0x5707bb,value:_0x1555c9}){const _0x4535c5=_0xa48d77,_0x249f88=_0x268706,_0x377473=_0x11176e,_0x5969bf=_0x327550,_0x19e60e=_0x268706,_0x508292={'CdXxr':function(_0xef790,_0x256e9f){const _0x2b190e=_0x2a23;return _0x30c0a5[_0x2b190e(0x4df)](_0xef790,_0x256e9f);},'IPaiQ':function(_0x56b423,_0x20054b){const _0x35e15a=_0x2a23;return _0x30c0a5[_0x35e15a(0xd4)](_0x56b423,_0x20054b);},'BbqOF':_0x30c0a5[_0x4535c5(0x5a8)],'imLua':function(_0x23e80b,_0x576ed8){const _0x2be45c=_0x4535c5;return _0x30c0a5[_0x2be45c(0x4a9)](_0x23e80b,_0x576ed8);},'tpUbz':_0x30c0a5[_0x4535c5(0x372)],'EBKBc':function(_0x5429e5,_0x81b2b6){const _0x5287f0=_0x249f88;return _0x30c0a5[_0x5287f0(0x4a9)](_0x5429e5,_0x81b2b6);},'WklBz':_0x30c0a5[_0x4535c5(0x3bd)],'wPyFc':_0x30c0a5[_0x377473(0x443)],'nGRds':_0x30c0a5[_0x5969bf(0xd2)],'kgVMm':_0x30c0a5[_0x5969bf(0x1d5)],'beQhS':_0x30c0a5[_0x377473(0x741)],'GPMmO':_0x30c0a5[_0x249f88(0x444)],'ADDMx':_0x30c0a5[_0x19e60e(0x5f1)],'EgRSl':function(_0x5bb6c0,_0xc66582){const _0x487a1f=_0x249f88;return _0x30c0a5[_0x487a1f(0x3ff)](_0x5bb6c0,_0xc66582);},'fPhlk':_0x30c0a5[_0x5969bf(0xf3)],'MAlSo':_0x30c0a5[_0x19e60e(0x368)],'fGiri':_0x30c0a5[_0x5969bf(0x122)],'Jlftr':_0x30c0a5[_0x377473(0x2e5)],'UkiBJ':_0x30c0a5[_0x4535c5(0x27b)],'WPBuQ':_0x30c0a5[_0x19e60e(0x3b1)],'SUnIZ':_0x30c0a5[_0x19e60e(0x263)],'nHcTv':function(_0x3fa64c,_0x4ea835){const _0x2fba51=_0x4535c5;return _0x30c0a5[_0x2fba51(0x413)](_0x3fa64c,_0x4ea835);},'xDgSe':_0x30c0a5[_0x5969bf(0x4ed)],'kzGAr':function(_0x323b55,_0x27c602){const _0x45160e=_0x377473;return _0x30c0a5[_0x45160e(0x582)](_0x323b55,_0x27c602);},'jCUNY':_0x30c0a5[_0x249f88(0x6ca)],'NvnTh':function(_0x14c452,_0x56122f){const _0x134e42=_0x5969bf;return _0x30c0a5[_0x134e42(0x1e4)](_0x14c452,_0x56122f);},'VGfHs':function(_0x590034){const _0x51c44d=_0x377473;return _0x30c0a5[_0x51c44d(0x37e)](_0x590034);}};if(_0x30c0a5[_0x377473(0xcf)](_0x30c0a5[_0x4535c5(0x440)],_0x30c0a5[_0x249f88(0x440)])){if(_0x5707bb)return;const _0x4b6445=new TextDecoder(_0x30c0a5[_0x19e60e(0x3d9)])[_0x19e60e(0x70f)+'e'](_0x1555c9);return _0x4b6445[_0x4535c5(0x1c4)]()[_0x377473(0x234)]('\x0a')[_0x19e60e(0x3a0)+'ch'](function(_0x351e20){const _0x1e5638=_0x19e60e,_0x375251=_0x249f88,_0x16f40e=_0x5969bf,_0x161eca=_0x4535c5,_0x5cf9be=_0x19e60e,_0x1d3a22={'zjTTN':_0x30c0a5[_0x1e5638(0x213)],'LKlBg':function(_0x4060ea,_0x50a807){const _0x4422d9=_0x1e5638;return _0x30c0a5[_0x4422d9(0x412)](_0x4060ea,_0x50a807);},'qxGTu':_0x30c0a5[_0x1e5638(0x220)],'FncRw':function(_0x50b1d7,_0x433fac){const _0x4120f0=_0x1e5638;return _0x30c0a5[_0x4120f0(0x3ff)](_0x50b1d7,_0x433fac);},'snGjA':_0x30c0a5[_0x1e5638(0x67c)],'WFOpI':function(_0xb8b48f){const _0x809dc2=_0x16f40e;return _0x30c0a5[_0x809dc2(0x745)](_0xb8b48f);},'cYzLe':function(_0xdea9ba,_0x2d8163){const _0xfa167d=_0x1e5638;return _0x30c0a5[_0xfa167d(0x1a5)](_0xdea9ba,_0x2d8163);},'OrPEb':_0x30c0a5[_0x1e5638(0x274)],'SeOZB':_0x30c0a5[_0x5cf9be(0x108)],'FBARo':_0x30c0a5[_0x5cf9be(0x372)],'eQjpr':function(_0x178ce5,_0x2d57c9){const _0x51f283=_0x161eca;return _0x30c0a5[_0x51f283(0x280)](_0x178ce5,_0x2d57c9);},'jtjgg':function(_0x5ea4dd,_0x245ab8,_0x281e42){const _0x15a9c9=_0x161eca;return _0x30c0a5[_0x15a9c9(0x389)](_0x5ea4dd,_0x245ab8,_0x281e42);},'jBvNE':function(_0xd34f5a,_0x120b19){const _0xa22ffa=_0x161eca;return _0x30c0a5[_0xa22ffa(0x280)](_0xd34f5a,_0x120b19);},'UJpQP':function(_0x3e1357,_0x2c8279){const _0x4c376c=_0x1e5638;return _0x30c0a5[_0x4c376c(0x3ad)](_0x3e1357,_0x2c8279);},'CDuAO':_0x30c0a5[_0x1e5638(0x559)],'RiZrA':_0x30c0a5[_0x161eca(0x6e7)],'hNxqE':_0x30c0a5[_0x16f40e(0x27b)],'QthMA':_0x30c0a5[_0x161eca(0x3b1)],'ummTa':function(_0x594282,_0x4a8fb2){const _0x511958=_0x5cf9be;return _0x30c0a5[_0x511958(0x1e4)](_0x594282,_0x4a8fb2);},'GVOjy':_0x30c0a5[_0x5cf9be(0x263)],'ltuXx':_0x30c0a5[_0x16f40e(0x4ed)],'geIWL':_0x30c0a5[_0x1e5638(0x6ca)],'jmrPp':function(_0x420191){const _0x1ad130=_0x16f40e;return _0x30c0a5[_0x1ad130(0x745)](_0x420191);},'XEblN':_0x30c0a5[_0x16f40e(0x3d8)],'gdfwB':_0x30c0a5[_0x375251(0x342)],'aSCHp':function(_0x1324cc,_0x3ef663){const _0xbadf28=_0x16f40e;return _0x30c0a5[_0xbadf28(0x305)](_0x1324cc,_0x3ef663);},'NKait':function(_0x342fd0,_0x2d266e){const _0x32b296=_0x1e5638;return _0x30c0a5[_0x32b296(0x409)](_0x342fd0,_0x2d266e);},'xJABB':_0x30c0a5[_0x16f40e(0x46e)],'aFPVJ':_0x30c0a5[_0x16f40e(0x5c0)],'ugRcC':_0x30c0a5[_0x161eca(0x2d9)],'InIUw':_0x30c0a5[_0x16f40e(0x327)],'bekdX':function(_0x54fcce,_0x39c82d){const _0x45dc24=_0x375251;return _0x30c0a5[_0x45dc24(0x29d)](_0x54fcce,_0x39c82d);},'xTvAX':_0x30c0a5[_0x5cf9be(0x5f0)],'MeKgj':_0x30c0a5[_0x375251(0x17b)],'MjRXB':_0x30c0a5[_0x5cf9be(0x603)],'acget':_0x30c0a5[_0x375251(0x27d)],'cgwyF':_0x30c0a5[_0x375251(0x55c)],'uNeYL':_0x30c0a5[_0x16f40e(0x239)],'dRuDK':_0x30c0a5[_0x5cf9be(0x33e)],'REgUd':_0x30c0a5[_0x161eca(0x465)],'bkkuB':_0x30c0a5[_0x161eca(0x102)],'gzzRf':_0x30c0a5[_0x1e5638(0x6d7)],'rTasm':_0x30c0a5[_0x161eca(0x3d9)],'GQXKS':_0x30c0a5[_0x375251(0x2f6)],'mgcVi':function(_0x3b6883,_0x1e3ac0){const _0x4af4fd=_0x16f40e;return _0x30c0a5[_0x4af4fd(0x364)](_0x3b6883,_0x1e3ac0);},'Slnam':_0x30c0a5[_0x16f40e(0x14d)],'bPutZ':_0x30c0a5[_0x16f40e(0x606)],'UcWJb':_0x30c0a5[_0x161eca(0x44c)],'lWraW':function(_0x161c09,_0x51539b){const _0x12fd31=_0x375251;return _0x30c0a5[_0x12fd31(0x305)](_0x161c09,_0x51539b);},'zGGBQ':function(_0x3cf7fb,_0x59af01){const _0x1c3e38=_0x16f40e;return _0x30c0a5[_0x1c3e38(0x5a9)](_0x3cf7fb,_0x59af01);},'mMEDK':_0x30c0a5[_0x1e5638(0x4f9)],'ryvrg':_0x30c0a5[_0x375251(0x4d9)],'AgnIq':_0x30c0a5[_0x5cf9be(0x3e9)],'jcpKr':function(_0x1ba4a9,_0x50c969){const _0xdacff6=_0x161eca;return _0x30c0a5[_0xdacff6(0x412)](_0x1ba4a9,_0x50c969);},'NhhDn':function(_0x31731c,_0x56d9d6){const _0x4740f9=_0x5cf9be;return _0x30c0a5[_0x4740f9(0x364)](_0x31731c,_0x56d9d6);},'HveXb':_0x30c0a5[_0x5cf9be(0x3cd)],'Dmmoq':_0x30c0a5[_0x161eca(0x5e6)],'INLQq':_0x30c0a5[_0x16f40e(0x179)],'aQHhD':function(_0xa45576,_0xf6ba52,_0x16ce40){const _0x4f65d1=_0x5cf9be;return _0x30c0a5[_0x4f65d1(0x20f)](_0xa45576,_0xf6ba52,_0x16ce40);},'EFcEI':_0x30c0a5[_0x375251(0x6cb)],'gLnXF':_0x30c0a5[_0x5cf9be(0x6aa)],'yWNbn':_0x30c0a5[_0x5cf9be(0x6c7)],'Ppnco':function(_0x40faff,_0x8b63a5){const _0x5eda41=_0x161eca;return _0x30c0a5[_0x5eda41(0x412)](_0x40faff,_0x8b63a5);},'CuTbM':_0x30c0a5[_0x375251(0x4c5)],'WJfRm':_0x30c0a5[_0x1e5638(0x486)],'BJNSf':_0x30c0a5[_0x5cf9be(0xd7)],'neRkH':function(_0x2a86a8,_0x51b787){const _0x3b339d=_0x375251;return _0x30c0a5[_0x3b339d(0x54e)](_0x2a86a8,_0x51b787);},'DwymF':_0x30c0a5[_0x1e5638(0x164)],'piQDw':_0x30c0a5[_0x161eca(0x683)],'RRXdU':function(_0x47eb59,_0x592026){const _0x4b9af1=_0x5cf9be;return _0x30c0a5[_0x4b9af1(0x280)](_0x47eb59,_0x592026);},'JFcrZ':function(_0x44ec8a,_0x309b8a,_0x841b52){const _0x532c22=_0x5cf9be;return _0x30c0a5[_0x532c22(0x389)](_0x44ec8a,_0x309b8a,_0x841b52);},'LChWD':_0x30c0a5[_0x1e5638(0x41a)],'cwZos':_0x30c0a5[_0x16f40e(0x570)],'DBfVK':function(_0x276f02,_0x2ca19e){const _0x2df844=_0x16f40e;return _0x30c0a5[_0x2df844(0x17a)](_0x276f02,_0x2ca19e);},'cgkfg':function(_0x5d5868,_0x5282e8){const _0x2dd01c=_0x375251;return _0x30c0a5[_0x2dd01c(0x3a8)](_0x5d5868,_0x5282e8);},'Rrwly':_0x30c0a5[_0x375251(0x2b6)],'NQEVx':_0x30c0a5[_0x161eca(0x5b0)],'WxGbj':_0x30c0a5[_0x375251(0x19d)],'kSbLj':function(_0x387bd9,_0x3803a8){const _0x31979a=_0x1e5638;return _0x30c0a5[_0x31979a(0x53b)](_0x387bd9,_0x3803a8);},'PqbJE':_0x30c0a5[_0x16f40e(0x520)],'SJwJO':function(_0x34eda9,_0x28def2){const _0x57d45a=_0x16f40e;return _0x30c0a5[_0x57d45a(0x1e4)](_0x34eda9,_0x28def2);},'nUEbI':_0x30c0a5[_0x161eca(0x124)],'aWLZq':_0x30c0a5[_0x161eca(0x252)],'GlcRs':_0x30c0a5[_0x161eca(0x57b)],'Mngrr':function(_0x59ae58,_0x58b97e){const _0x5b4e3c=_0x1e5638;return _0x30c0a5[_0x5b4e3c(0x3b4)](_0x59ae58,_0x58b97e);},'BpWQL':function(_0x3d58c7,_0x129109){const _0x5327b9=_0x375251;return _0x30c0a5[_0x5327b9(0x10d)](_0x3d58c7,_0x129109);},'Rmsmx':function(_0x10f9f5,_0x2754fb){const _0x2827c1=_0x161eca;return _0x30c0a5[_0x2827c1(0xd3)](_0x10f9f5,_0x2754fb);},'WmFQz':_0x30c0a5[_0x1e5638(0x17d)],'SlUqw':function(_0x5c5823,_0xe7c7d1){const _0x1dc7bb=_0x161eca;return _0x30c0a5[_0x1dc7bb(0x3b4)](_0x5c5823,_0xe7c7d1);},'pRkxw':function(_0x2c68a3,_0x49ecb9){const _0x5eeb26=_0x16f40e;return _0x30c0a5[_0x5eeb26(0x42f)](_0x2c68a3,_0x49ecb9);},'DGdSd':_0x30c0a5[_0x16f40e(0x1bf)],'WaKbn':function(_0x15a4e2,_0x49644d){const _0x1b0c61=_0x375251;return _0x30c0a5[_0x1b0c61(0x5c9)](_0x15a4e2,_0x49644d);},'VnMCx':_0x30c0a5[_0x1e5638(0x5cb)],'ylkMu':function(_0x59e0fc,_0x39b66b){const _0x595cba=_0x161eca;return _0x30c0a5[_0x595cba(0x446)](_0x59e0fc,_0x39b66b);}};if(_0x30c0a5[_0x5cf9be(0x5b3)](_0x30c0a5[_0x375251(0x1e0)],_0x30c0a5[_0x161eca(0x1e0)])){if(_0x30c0a5[_0x1e5638(0x47c)](_0x351e20[_0x375251(0x613)+'h'],0x1b78+0x94e+0x15*-0x1c0))_0x3ae682=_0x351e20[_0x16f40e(0x6da)](-0x770*0x4+-0x4c4+0x228a);if(_0x30c0a5[_0x161eca(0x3dc)](_0x3ae682,_0x30c0a5[_0x16f40e(0x46e)])){if(_0x30c0a5[_0x1e5638(0x33c)](_0x30c0a5[_0x16f40e(0x51e)],_0x30c0a5[_0x375251(0x17c)])){const _0x23a50c='['+_0x5b6735++ +_0x375251(0x607)+_0xc89a6d[_0x375251(0x754)+'s']()[_0x161eca(0x360)]()[_0x16f40e(0x754)],_0x1cc5b8='[^'+_0x508292[_0x375251(0x16e)](_0x54b725,0x863*-0x3+-0x26ce+0x3ff8)+_0x161eca(0x607)+_0x35a5a4[_0x1e5638(0x754)+'s']()[_0x161eca(0x360)]()[_0x1e5638(0x754)];_0x251064=_0x527eec+'\x0a\x0a'+_0x1cc5b8,_0x2c0d13[_0x161eca(0x623)+'e'](_0x43d52f[_0x161eca(0x754)+'s']()[_0x161eca(0x360)]()[_0x16f40e(0x754)]);}else{text_offset=-(0x2e9*-0x2+-0x1*0x9a9+0xf7c);const _0x29849d={'method':_0x30c0a5[_0x161eca(0x3e9)],'headers':headers,'body':_0x30c0a5[_0x5cf9be(0x57c)](b64EncodeUnicode,JSON[_0x16f40e(0xe9)+_0x5cf9be(0x1fe)](prompt[_0x16f40e(0x458)]))};_0x30c0a5[_0x1e5638(0x557)](fetch,_0x30c0a5[_0x161eca(0x6cb)],_0x29849d)[_0x16f40e(0x433)](_0x2b7ebd=>{const _0x464420=_0x1e5638,_0x47b30a=_0x5cf9be,_0x32ced4=_0x161eca,_0x3ee3a9=_0x375251,_0xd0f3b2=_0x375251;if(_0x508292[_0x464420(0x74f)](_0x508292[_0x47b30a(0x51f)],_0x508292[_0x464420(0x51f)])){const _0x5b6b97=_0x2b7ebd[_0x464420(0xf6)][_0x464420(0x2bd)+_0xd0f3b2(0x273)]();let _0x448bcd='',_0x151c68='';_0x5b6b97[_0x3ee3a9(0x226)]()[_0xd0f3b2(0x433)](function _0x3ea6ac({done:_0x496999,value:_0xbf667d}){const _0x2e30f5=_0x464420,_0x836145=_0x47b30a,_0xcaed92=_0x3ee3a9,_0x2ba256=_0x47b30a,_0x5e6744=_0xd0f3b2,_0x569c73={'VAZbM':_0x1d3a22[_0x2e30f5(0x51d)],'irvyL':function(_0x2fe8fd,_0x8f7ec5){const _0x53b381=_0x2e30f5;return _0x1d3a22[_0x53b381(0x26f)](_0x2fe8fd,_0x8f7ec5);},'ljdvt':_0x1d3a22[_0x836145(0x659)],'RfSnk':function(_0x47844a,_0x4bf022){const _0x135024=_0x836145;return _0x1d3a22[_0x135024(0x4e2)](_0x47844a,_0x4bf022);},'PASeO':_0x1d3a22[_0xcaed92(0x2c0)],'onKor':function(_0x509609){const _0xd90191=_0x836145;return _0x1d3a22[_0xd90191(0x6be)](_0x509609);},'SOHml':function(_0x3aaa68,_0x1e9285){const _0x1da593=_0xcaed92;return _0x1d3a22[_0x1da593(0x5b4)](_0x3aaa68,_0x1e9285);},'gDxlK':_0x1d3a22[_0x2e30f5(0x12f)],'Jubhq':_0x1d3a22[_0x2e30f5(0x3e1)],'BgpNJ':_0x1d3a22[_0x5e6744(0x672)],'tFbxc':function(_0x3ca732,_0xd01e52){const _0x3f6ef6=_0x2ba256;return _0x1d3a22[_0x3f6ef6(0x26f)](_0x3ca732,_0xd01e52);},'qgAMf':function(_0x1f555f,_0x2f6553){const _0x3c478c=_0x2ba256;return _0x1d3a22[_0x3c478c(0xe3)](_0x1f555f,_0x2f6553);},'gYAWN':function(_0x88c171,_0x57dae4,_0x4cf500){const _0x1250c8=_0x5e6744;return _0x1d3a22[_0x1250c8(0x1d7)](_0x88c171,_0x57dae4,_0x4cf500);},'ozRMJ':function(_0x15bbbe,_0x2cb569){const _0x16a3bd=_0x5e6744;return _0x1d3a22[_0x16a3bd(0x131)](_0x15bbbe,_0x2cb569);},'tYVNe':function(_0x38d6a4,_0x2c1421){const _0x4d52dc=_0x2e30f5;return _0x1d3a22[_0x4d52dc(0x6a3)](_0x38d6a4,_0x2c1421);},'dCeTX':_0x1d3a22[_0x5e6744(0x18c)],'UAAUk':_0x1d3a22[_0x2ba256(0x1cd)],'yTmaL':_0x1d3a22[_0x2e30f5(0x566)],'fgthH':_0x1d3a22[_0x5e6744(0x119)],'zxBPt':function(_0x55624e,_0x58e6f2){const _0x2df771=_0x5e6744;return _0x1d3a22[_0x2df771(0x25f)](_0x55624e,_0x58e6f2);},'hKbeH':_0x1d3a22[_0xcaed92(0x391)],'OJHgL':_0x1d3a22[_0x5e6744(0x2cf)],'LIvuA':_0x1d3a22[_0xcaed92(0x4f6)],'MCTzv':function(_0x416597){const _0x5eab85=_0x2ba256;return _0x1d3a22[_0x5eab85(0x23f)](_0x416597);},'BdXNO':_0x1d3a22[_0x2ba256(0x6c4)],'fhFJl':_0x1d3a22[_0xcaed92(0x35d)],'WciAJ':function(_0x2b260b,_0x38849f){const _0x1bc237=_0x5e6744;return _0x1d3a22[_0x1bc237(0x2f8)](_0x2b260b,_0x38849f);},'Syngk':function(_0x42845c,_0x422f02){const _0xafcb1c=_0x5e6744;return _0x1d3a22[_0xafcb1c(0x12e)](_0x42845c,_0x422f02);},'XoAxx':_0x1d3a22[_0x5e6744(0x556)],'JWToI':_0x1d3a22[_0x2ba256(0x611)],'sbQSC':_0x1d3a22[_0x836145(0x54f)],'uGMvi':_0x1d3a22[_0xcaed92(0x485)],'KVSZN':function(_0x4155bd,_0x25b892){const _0x321135=_0x2e30f5;return _0x1d3a22[_0x321135(0x30c)](_0x4155bd,_0x25b892);},'jatIn':_0x1d3a22[_0x2e30f5(0x6d3)],'ZdJEx':_0x1d3a22[_0x836145(0x49b)],'TBWzs':_0x1d3a22[_0x2e30f5(0x2a0)],'Djuxb':_0x1d3a22[_0xcaed92(0x2ba)],'izgFy':_0x1d3a22[_0x2ba256(0x47e)],'ApNOo':_0x1d3a22[_0xcaed92(0x1b4)],'Dubqf':_0x1d3a22[_0x5e6744(0x38b)],'afLhP':_0x1d3a22[_0xcaed92(0x705)],'cRFVu':_0x1d3a22[_0xcaed92(0x58e)],'VFyQA':function(_0x2c0b4a,_0x96cee1){const _0x166ece=_0xcaed92;return _0x1d3a22[_0x166ece(0x5b4)](_0x2c0b4a,_0x96cee1);},'jWlaQ':_0x1d3a22[_0x2e30f5(0x33f)],'xOWkq':_0x1d3a22[_0x2e30f5(0x430)],'ZaBQq':_0x1d3a22[_0x5e6744(0x3f1)],'hfaEe':function(_0x2b1f5c,_0x522e6c){const _0x5bfe18=_0xcaed92;return _0x1d3a22[_0x5bfe18(0x26f)](_0x2b1f5c,_0x522e6c);},'IpyYb':function(_0x2f846e,_0x25b476){const _0x35b2c5=_0x836145;return _0x1d3a22[_0x35b2c5(0x363)](_0x2f846e,_0x25b476);},'Fivzb':_0x1d3a22[_0x2ba256(0x58d)],'KoWXz':_0x1d3a22[_0x836145(0x291)],'gxHKP':_0x1d3a22[_0x836145(0x518)],'pEMRk':function(_0xa16123,_0x438a7e){const _0x3bbbe2=_0xcaed92;return _0x1d3a22[_0x3bbbe2(0x73c)](_0xa16123,_0x438a7e);},'AQgvn':function(_0x595b8a,_0xa8fedb){const _0x2fdf3d=_0x5e6744;return _0x1d3a22[_0x2fdf3d(0x12e)](_0x595b8a,_0xa8fedb);},'fsgOd':function(_0x18e71e,_0x30afcd){const _0x11c300=_0x5e6744;return _0x1d3a22[_0x11c300(0x259)](_0x18e71e,_0x30afcd);},'BfXYQ':_0x1d3a22[_0xcaed92(0x14c)],'enjtr':_0x1d3a22[_0x2ba256(0x636)],'bdOxV':function(_0x3cbba1){const _0x3813d6=_0x5e6744;return _0x1d3a22[_0x3813d6(0x6be)](_0x3cbba1);},'hqdoY':_0x1d3a22[_0xcaed92(0x21c)],'JZQCn':function(_0x29484e,_0x44de72){const _0x48babb=_0x836145;return _0x1d3a22[_0x48babb(0x25f)](_0x29484e,_0x44de72);},'KqEBp':function(_0x590c7f,_0x2713c3){const _0x15a7e4=_0x836145;return _0x1d3a22[_0x15a7e4(0x152)](_0x590c7f,_0x2713c3);},'VTyfL':function(_0x311dda,_0x25b132){const _0x25522c=_0x5e6744;return _0x1d3a22[_0x25522c(0x25e)](_0x311dda,_0x25b132);},'BCRyE':_0x1d3a22[_0x5e6744(0x184)],'vHKaz':_0x1d3a22[_0x2e30f5(0x71f)],'UCmYk':_0x1d3a22[_0x2e30f5(0x4f3)],'uvVEG':function(_0x190c8d,_0x4984a9,_0xf51310){const _0x2029bd=_0xcaed92;return _0x1d3a22[_0x2029bd(0x205)](_0x190c8d,_0x4984a9,_0xf51310);},'hopTm':_0x1d3a22[_0x2e30f5(0x656)],'buvxf':_0x1d3a22[_0x836145(0x2f5)],'MzyCf':_0x1d3a22[_0x836145(0x11e)],'STvOl':function(_0x49e943,_0x295b79){const _0x16071b=_0x836145;return _0x1d3a22[_0x16071b(0x429)](_0x49e943,_0x295b79);},'sOWni':function(_0x4644de,_0x475e24){const _0x194fcc=_0x2e30f5;return _0x1d3a22[_0x194fcc(0x259)](_0x4644de,_0x475e24);},'zNblE':_0x1d3a22[_0xcaed92(0x688)],'OFCKc':function(_0xd618e1,_0x104245){const _0x281fc8=_0x2ba256;return _0x1d3a22[_0x281fc8(0x259)](_0xd618e1,_0x104245);},'KKCtA':_0x1d3a22[_0xcaed92(0x6c3)],'DkKmr':_0x1d3a22[_0x2e30f5(0x747)],'MWoTQ':function(_0x2b31d5,_0x3db188){const _0x2809b1=_0x836145;return _0x1d3a22[_0x2809b1(0x370)](_0x2b31d5,_0x3db188);},'xYHOB':function(_0x80dc11,_0x3c84f9){const _0x50b9cc=_0xcaed92;return _0x1d3a22[_0x50b9cc(0x259)](_0x80dc11,_0x3c84f9);},'SsHAQ':_0x1d3a22[_0x5e6744(0x28f)],'quOmY':_0x1d3a22[_0x2e30f5(0x3a2)],'hxItf':function(_0xe0d38d,_0x59eb77){const _0x583c2f=_0x5e6744;return _0x1d3a22[_0x583c2f(0x721)](_0xe0d38d,_0x59eb77);},'BSJKX':function(_0x2d08fa,_0x2ee004,_0x3fb54d){const _0xb2039b=_0x2ba256;return _0x1d3a22[_0xb2039b(0x490)](_0x2d08fa,_0x2ee004,_0x3fb54d);}};if(_0x1d3a22[_0x5e6744(0x30c)](_0x1d3a22[_0x5e6744(0x110)],_0x1d3a22[_0xcaed92(0x62e)])){if(_0x496999)return;const _0x3789da=new TextDecoder(_0x1d3a22[_0x2ba256(0x430)])[_0x5e6744(0x70f)+'e'](_0xbf667d);return _0x3789da[_0x836145(0x1c4)]()[_0x2e30f5(0x234)]('\x0a')[_0x2ba256(0x3a0)+'ch'](function(_0x4f63c8){const _0xa049a5=_0xcaed92,_0x203dfb=_0xcaed92,_0x2d11a6=_0x836145,_0x55ab5f=_0x836145,_0x3739fb=_0x836145,_0x246228={'UxQHx':function(_0x3a9de1,_0x213ab6){const _0x5b788c=_0x2a23;return _0x569c73[_0x5b788c(0x625)](_0x3a9de1,_0x213ab6);},'vmeCK':function(_0x142691,_0x18ce8c,_0x57586a){const _0xbbb40c=_0x2a23;return _0x569c73[_0xbbb40c(0x72b)](_0x142691,_0x18ce8c,_0x57586a);},'OYuet':function(_0x4c3612,_0xdad670){const _0x352e35=_0x2a23;return _0x569c73[_0x352e35(0xf7)](_0x4c3612,_0xdad670);},'EhuBS':function(_0xa29e5a,_0x37543a){const _0x2b8994=_0x2a23;return _0x569c73[_0x2b8994(0x43d)](_0xa29e5a,_0x37543a);},'HsOaP':function(_0x59cc69,_0x2aedc3){const _0x6fa20a=_0x2a23;return _0x569c73[_0x6fa20a(0x2e8)](_0x59cc69,_0x2aedc3);},'hUQHB':_0x569c73[_0xa049a5(0x6dd)],'ngyyE':_0x569c73[_0xa049a5(0x5b6)],'ITqOl':_0x569c73[_0x203dfb(0x4e3)],'XLLhc':_0x569c73[_0x55ab5f(0x697)],'wgysn':function(_0x486620,_0x4d1d25){const _0x54f6cb=_0x2d11a6;return _0x569c73[_0x54f6cb(0x71b)](_0x486620,_0x4d1d25);},'zHqdK':_0x569c73[_0x3739fb(0x4f5)],'pCRlM':_0x569c73[_0x3739fb(0x6a0)],'bIFUG':_0x569c73[_0x2d11a6(0x36d)],'SCPKv':function(_0x1d0654){const _0x52c683=_0x2d11a6;return _0x569c73[_0x52c683(0x356)](_0x1d0654);},'NlqdS':function(_0x322ee1,_0x301898){const _0x51e132=_0x55ab5f;return _0x569c73[_0x51e132(0x43a)](_0x322ee1,_0x301898);},'UHlqK':_0x569c73[_0x55ab5f(0x555)],'aGeEp':_0x569c73[_0x2d11a6(0x1de)],'CnAhW':function(_0x184106,_0x25a17f){const _0x1afb06=_0xa049a5;return _0x569c73[_0x1afb06(0x2ec)](_0x184106,_0x25a17f);},'XokWT':function(_0x13d2ac,_0xf47ba4){const _0x68b3b2=_0xa049a5;return _0x569c73[_0x68b3b2(0x4f0)](_0x13d2ac,_0xf47ba4);},'nHcGa':_0x569c73[_0x203dfb(0x200)],'NhvdN':function(_0x50b9f2,_0x42f721){const _0x5d2770=_0xa049a5;return _0x569c73[_0x5d2770(0x43a)](_0x50b9f2,_0x42f721);},'iZfEX':_0x569c73[_0x55ab5f(0x1ae)],'gRbZd':_0x569c73[_0x2d11a6(0xfb)],'ZaPdi':_0x569c73[_0xa049a5(0x4c8)],'ziyiT':function(_0x38dfae,_0x5865c1){const _0x441184=_0x203dfb;return _0x569c73[_0x441184(0x408)](_0x38dfae,_0x5865c1);},'PaSad':_0x569c73[_0x2d11a6(0x31c)],'UpfIh':_0x569c73[_0x3739fb(0x64c)],'RRUqG':_0x569c73[_0x2d11a6(0x1f6)],'AgynX':_0x569c73[_0xa049a5(0x1df)],'zxPWD':_0x569c73[_0x2d11a6(0x354)],'xuzYu':_0x569c73[_0x2d11a6(0x3e3)],'kCuiG':_0x569c73[_0x55ab5f(0x3aa)],'DyNyf':_0x569c73[_0x203dfb(0x69c)],'sDbUn':_0x569c73[_0xa049a5(0x74d)],'AhGrR':_0x569c73[_0x55ab5f(0x720)],'uZzOs':function(_0xfe6713,_0x4870ab){const _0x415dea=_0x2d11a6;return _0x569c73[_0x415dea(0x679)](_0xfe6713,_0x4870ab);},'ouTEP':_0x569c73[_0x3739fb(0x5e1)],'ctAIo':_0x569c73[_0xa049a5(0x418)],'PRomM':_0x569c73[_0xa049a5(0x600)],'YuTwD':function(_0x27c56d,_0xa88b40){const _0x1ee6d0=_0x203dfb;return _0x569c73[_0x1ee6d0(0x679)](_0x27c56d,_0xa88b40);},'WvWAL':_0x569c73[_0xa049a5(0x229)],'pQUsZ':function(_0x1cd688,_0x4a3dbe){const _0x54ac4b=_0x55ab5f;return _0x569c73[_0x54ac4b(0xf8)](_0x1cd688,_0x4a3dbe);},'tblUO':function(_0x395b59,_0xe9895f){const _0x13c9ad=_0x203dfb;return _0x569c73[_0x13c9ad(0x2f3)](_0x395b59,_0xe9895f);},'ELGxJ':_0x569c73[_0x2d11a6(0x6de)],'fCAgy':_0x569c73[_0x55ab5f(0x50a)]};if(_0x569c73[_0xa049a5(0x408)](_0x569c73[_0x203dfb(0x578)],_0x569c73[_0x55ab5f(0x578)]))_0x36dcea[_0x203dfb(0x696)+_0xa049a5(0x6ee)+_0x3739fb(0x6e9)](_0x569c73[_0x3739fb(0x6e8)])[_0x2d11a6(0x746)+_0x3739fb(0x6f5)]+=_0x569c73[_0x3739fb(0x450)](_0x569c73[_0x3739fb(0x450)](_0x569c73[_0x55ab5f(0x37c)],_0x569c73[_0x55ab5f(0x393)](_0x4c0f2c,_0x475833)),_0x569c73[_0x203dfb(0x208)]);else{if(_0x569c73[_0x2d11a6(0x21a)](_0x4f63c8[_0xa049a5(0x613)+'h'],-0x40*0x6f+-0xc1d*0x3+0x401d))_0x448bcd=_0x4f63c8[_0x55ab5f(0x6da)](-0x1*0x8bf+0x10c1+0x4*-0x1ff);if(_0x569c73[_0xa049a5(0x238)](_0x448bcd,_0x569c73[_0x2d11a6(0x200)])){if(_0x569c73[_0x55ab5f(0x12b)](_0x569c73[_0x3739fb(0x4c0)],_0x569c73[_0x3739fb(0x168)]))DNUENj[_0xa049a5(0x4ad)](_0x7183f4);else{document[_0x55ab5f(0x696)+_0xa049a5(0x6ee)+_0x55ab5f(0x6e9)](_0x569c73[_0x203dfb(0x6e8)])[_0x203dfb(0x746)+_0x55ab5f(0x6f5)]='',_0x569c73[_0x3739fb(0x758)](chatmore);const _0x5dc1b7={'method':_0x569c73[_0x3739fb(0x579)],'headers':headers,'body':_0x569c73[_0x2d11a6(0x598)](b64EncodeUnicode,JSON[_0x203dfb(0xe9)+_0xa049a5(0x1fe)]({'prompt':_0x569c73[_0x3739fb(0x4a4)](_0x569c73[_0x55ab5f(0x2f3)](_0x569c73[_0x203dfb(0x2e8)](_0x569c73[_0xa049a5(0x657)](_0x569c73[_0x203dfb(0x2da)],original_search_query),_0x569c73[_0x2d11a6(0x267)]),document[_0x55ab5f(0x696)+_0x55ab5f(0x6ee)+_0x2d11a6(0x6e9)](_0x569c73[_0x203dfb(0x5b1)])[_0x203dfb(0x746)+_0x3739fb(0x6f5)][_0x55ab5f(0x180)+'ce'](/<a.*?>.*?<\/a.*?>/g,'')[_0x203dfb(0x180)+'ce'](/<hr.*/gs,'')[_0x203dfb(0x180)+'ce'](/<[^>]+>/g,'')[_0x3739fb(0x180)+'ce'](/\n\n/g,'\x0a')),'\x0a'),'max_tokens':0x5dc,'temperature':0.7,'top_p':0x1,'frequency_penalty':0x0,'presence_penalty':0x2,'best_of':0x1,'echo':![],'logprobs':0x0,'stream':!![]}))};_0x569c73[_0x55ab5f(0x524)](fetch,_0x569c73[_0x3739fb(0x1cf)],_0x5dc1b7)[_0x3739fb(0x433)](_0x5cd662=>{const _0x1220b2=_0x203dfb,_0x43d46a=_0xa049a5,_0xe2d2ae=_0x3739fb,_0x2ba9e9=_0x55ab5f,_0x10f918=_0x2d11a6,_0xc77238={};_0xc77238[_0x1220b2(0x411)]=_0x246228[_0x1220b2(0x577)];const _0x2ead33=_0xc77238;if(_0x246228[_0x1220b2(0x73e)](_0x246228[_0x43d46a(0x6b0)],_0x246228[_0x10f918(0x6b0)])){const _0x4c418a=_0x5cd662[_0x2ba9e9(0xf6)][_0xe2d2ae(0x2bd)+_0x2ba9e9(0x273)]();let _0x501a80='',_0x2e98a4='';_0x4c418a[_0x1220b2(0x226)]()[_0x2ba9e9(0x433)](function _0x3b282f({done:_0x65b2f8,value:_0x2ffba7}){const _0x2477bb=_0xe2d2ae,_0x1756d0=_0x10f918,_0x37db3b=_0x2ba9e9,_0x5d7882=_0xe2d2ae,_0x2037ef=_0x10f918,_0xd7539a={'AsQgs':function(_0x22e10c,_0xb47604){const _0x2dce39=_0x2a23;return _0x246228[_0x2dce39(0x245)](_0x22e10c,_0xb47604);},'qyQYU':function(_0x2cc86b,_0x152e4f,_0x231c88){const _0x252da6=_0x2a23;return _0x246228[_0x252da6(0x493)](_0x2cc86b,_0x152e4f,_0x231c88);},'POISI':function(_0x16b473,_0x41c66e){const _0x42fc28=_0x2a23;return _0x246228[_0x42fc28(0x193)](_0x16b473,_0x41c66e);},'fYItq':function(_0xca7ad7,_0x30cb5f){const _0x80b87e=_0x2a23;return _0x246228[_0x80b87e(0x627)](_0xca7ad7,_0x30cb5f);},'yEnHY':function(_0x231856,_0x3f424f){const _0x3dc937=_0x2a23;return _0x246228[_0x3dc937(0x317)](_0x231856,_0x3f424f);},'VmCJZ':function(_0x524b2a,_0x527f4d){const _0x44890a=_0x2a23;return _0x246228[_0x44890a(0x317)](_0x524b2a,_0x527f4d);},'bKLeQ':function(_0x377163,_0x56539c){const _0x1f0490=_0x2a23;return _0x246228[_0x1f0490(0x317)](_0x377163,_0x56539c);},'MYbrO':_0x246228[_0x2477bb(0x23e)],'ZMHzZ':_0x246228[_0x1756d0(0x149)],'WHgLw':_0x246228[_0x2477bb(0x6dc)],'Jpiql':_0x246228[_0x1756d0(0x298)],'ombpQ':function(_0x46a9ce,_0xeb3770){const _0x1baf3d=_0x37db3b;return _0x246228[_0x1baf3d(0x100)](_0x46a9ce,_0xeb3770);},'kTYzR':_0x246228[_0x5d7882(0x407)],'aqCQk':function(_0x35efb8,_0x1f5e2a){const _0xed2d09=_0x37db3b;return _0x246228[_0xed2d09(0x317)](_0x35efb8,_0x1f5e2a);},'bsDbO':_0x246228[_0x5d7882(0x3c3)],'gbFGS':_0x246228[_0x2037ef(0x5c6)],'zvMWP':function(_0x280d67){const _0xebd651=_0x37db3b;return _0x246228[_0xebd651(0x2a6)](_0x280d67);},'Lyzmu':function(_0x159fa8,_0x65d59){const _0x76d584=_0x2477bb;return _0x246228[_0x76d584(0x65a)](_0x159fa8,_0x65d59);},'DCedW':_0x246228[_0x1756d0(0x160)],'LwqDg':_0x246228[_0x37db3b(0x2dc)],'pBVHW':function(_0x2e5461,_0x4bd63e){const _0x4e8633=_0x2037ef;return _0x246228[_0x4e8633(0x2a5)](_0x2e5461,_0x4bd63e);},'mOkvk':function(_0x7b93bf,_0x5bfc7e){const _0x127885=_0x37db3b;return _0x246228[_0x127885(0x2a9)](_0x7b93bf,_0x5bfc7e);},'cmRNJ':_0x246228[_0x37db3b(0x1eb)],'BkLgJ':function(_0x4b3f8d,_0x378d72){const _0x2d011c=_0x2037ef;return _0x246228[_0x2d011c(0x2b9)](_0x4b3f8d,_0x378d72);},'JwGKk':_0x246228[_0x1756d0(0x11a)],'ldLVU':_0x246228[_0x2037ef(0x453)],'VCgWb':_0x246228[_0x2477bb(0x468)],'soYxE':function(_0x2a05f0,_0x2f3524){const _0x48cebe=_0x37db3b;return _0x246228[_0x48cebe(0x56a)](_0x2a05f0,_0x2f3524);},'NAoRc':_0x246228[_0x37db3b(0x548)],'OacAh':_0x246228[_0x1756d0(0x609)],'EwToq':_0x246228[_0x1756d0(0x46c)],'PEHcq':_0x246228[_0x1756d0(0x5b9)],'uTHnp':_0x246228[_0x2037ef(0x56e)],'JDEIv':function(_0x3025dc,_0x71483e){const _0x12021a=_0x5d7882;return _0x246228[_0x12021a(0x56a)](_0x3025dc,_0x71483e);},'PJRkD':_0x246228[_0x2037ef(0x13e)],'slYuc':_0x246228[_0x5d7882(0x255)],'xtXbE':_0x246228[_0x37db3b(0x658)],'EYaPZ':_0x246228[_0x2477bb(0x398)],'qMsAe':_0x246228[_0x37db3b(0x673)],'hZgOx':function(_0x5a30c4,_0x21e59e){const _0x49d9ed=_0x2477bb;return _0x246228[_0x49d9ed(0x627)](_0x5a30c4,_0x21e59e);}};if(_0x246228[_0x37db3b(0x535)](_0x246228[_0x2477bb(0x71a)],_0x246228[_0x5d7882(0x71a)])){if(_0x65b2f8)return;const _0x575c23=new TextDecoder(_0x246228[_0x37db3b(0x129)])[_0x1756d0(0x70f)+'e'](_0x2ffba7);return _0x575c23[_0x1756d0(0x1c4)]()[_0x5d7882(0x234)]('\x0a')[_0x2477bb(0x3a0)+'ch'](function(_0x477821){const _0x3b582e=_0x5d7882,_0x42a9b3=_0x1756d0,_0x5c3b49=_0x1756d0,_0x573704=_0x1756d0,_0x1fd388=_0x2037ef,_0x93b891={'rMplG':function(_0x586dd4,_0x53dc3d){const _0x79ff9b=_0x2a23;return _0xd7539a[_0x79ff9b(0x65b)](_0x586dd4,_0x53dc3d);},'GbBIQ':function(_0x2ec79b,_0x740b0e){const _0x389cf0=_0x2a23;return _0xd7539a[_0x389cf0(0x36b)](_0x2ec79b,_0x740b0e);},'gnAlk':function(_0x2c24a0,_0x406cb1){const _0x51ccca=_0x2a23;return _0xd7539a[_0x51ccca(0x717)](_0x2c24a0,_0x406cb1);},'CBIVI':function(_0x4b50fd,_0x57a491){const _0x533152=_0x2a23;return _0xd7539a[_0x533152(0x6fb)](_0x4b50fd,_0x57a491);},'qjXIU':_0xd7539a[_0x3b582e(0x743)],'Mhcon':_0xd7539a[_0x3b582e(0x123)],'bxoUk':_0xd7539a[_0x3b582e(0x1b3)],'FQTum':_0xd7539a[_0x3b582e(0x4da)],'LfZNc':function(_0x3fff1e,_0x5bc918){const _0x13f29=_0x5c3b49;return _0xd7539a[_0x13f29(0x5e8)](_0x3fff1e,_0x5bc918);},'KjjIz':_0xd7539a[_0x42a9b3(0x18b)],'uXjmR':function(_0x3147dc,_0x416fb2){const _0x48bc27=_0x573704;return _0xd7539a[_0x48bc27(0x580)](_0x3147dc,_0x416fb2);},'xydPv':_0xd7539a[_0x42a9b3(0x447)],'dltgx':_0xd7539a[_0x42a9b3(0x246)],'QxSjb':function(_0x4ad9ab,_0x4a87b1){const _0x155500=_0x3b582e;return _0xd7539a[_0x155500(0x5e8)](_0x4ad9ab,_0x4a87b1);},'beLwS':function(_0x570b9f){const _0x3cffcd=_0x5c3b49;return _0xd7539a[_0x3cffcd(0x15b)](_0x570b9f);}};if(_0xd7539a[_0x573704(0x40e)](_0xd7539a[_0x1fd388(0x60a)],_0xd7539a[_0x1fd388(0x2d2)])){if(_0x469dd1){const _0x463db6=_0x2d50e1[_0x3b582e(0x352)](_0x24a8eb,arguments);return _0x5986a7=null,_0x463db6;}}else{if(_0xd7539a[_0x3b582e(0x4e4)](_0x477821[_0x573704(0x613)+'h'],-0x1d3+0x1*-0xe3b+0x1014*0x1))_0x501a80=_0x477821[_0x1fd388(0x6da)](0x57*0x3f+0x1*0x22af+0x1c09*-0x2);if(_0xd7539a[_0x42a9b3(0x202)](_0x501a80,_0xd7539a[_0x5c3b49(0x419)])){if(_0xd7539a[_0x5c3b49(0x5a6)](_0xd7539a[_0x5c3b49(0x3f3)],_0xd7539a[_0x3b582e(0x3f3)])){lock_chat=0x26*0x5c+-0x10*-0x48+-0x1228,document[_0x42a9b3(0x40b)+_0x573704(0x44e)+_0x1fd388(0x313)](_0xd7539a[_0x573704(0x378)])[_0x5c3b49(0x67a)][_0x1fd388(0x466)+'ay']='',document[_0x5c3b49(0x40b)+_0x3b582e(0x44e)+_0x573704(0x313)](_0xd7539a[_0x3b582e(0x29b)])[_0x42a9b3(0x67a)][_0x573704(0x466)+'ay']='';return;}else _0x5a8b47+=_0x1ee84d[-0xda9+-0x802+0x15ab][_0x1fd388(0x28d)],_0x13fa15=_0x5d07e6[-0x1818+0x5*0x48b+-0x161*-0x1][_0x5c3b49(0x178)+_0x573704(0x346)][_0x573704(0x2ed)+_0x573704(0x3e0)+'t'][_0xd7539a[_0x5c3b49(0x290)](_0x3c61d3[0x3*-0xa3d+0x1301+0x2*0x5db][_0x5c3b49(0x178)+_0x42a9b3(0x346)][_0x42a9b3(0x2ed)+_0x42a9b3(0x3e0)+'t'][_0x42a9b3(0x613)+'h'],-0xeac+0x3f3*-0x1+0x12a0)];}let _0x52fe41;try{if(_0xd7539a[_0x573704(0x4dd)](_0xd7539a[_0x1fd388(0x2ff)],_0xd7539a[_0x1fd388(0x2ff)])){if(_0x93b891[_0x42a9b3(0x3b8)](_0x93b891[_0x573704(0x201)](_0x93b891[_0x42a9b3(0x201)](_0x93b891[_0x3b582e(0x359)](_0x93b891[_0x5c3b49(0x674)](_0x93b891[_0x1fd388(0x674)](_0x4d99ef[_0x573704(0x458)][_0x573704(0x2f4)+'t'],_0x597345),'\x0a'),_0x93b891[_0x42a9b3(0x258)]),_0x239a6f),_0x93b891[_0x5c3b49(0x4ee)])[_0x1fd388(0x613)+'h'],0x25b9+0x1fc3+-0x3e74))_0x4dce52[_0x1fd388(0x458)][_0x1fd388(0x2f4)+'t']+=_0x93b891[_0x573704(0x201)](_0x4b7bdf,'\x0a');}else try{_0xd7539a[_0x5c3b49(0x4dd)](_0xd7539a[_0x5c3b49(0x14e)],_0xd7539a[_0x1fd388(0x14e)])?_0x26ea85+=_0x4c2caf:(_0x52fe41=JSON[_0x573704(0x1d3)](_0xd7539a[_0x573704(0x36b)](_0x2e98a4,_0x501a80))[_0xd7539a[_0x573704(0x31b)]],_0x2e98a4='');}catch(_0x4c998d){_0xd7539a[_0x5c3b49(0x5a6)](_0xd7539a[_0x42a9b3(0x5c1)],_0xd7539a[_0x42a9b3(0x33d)])?_0xded3a2+=_0x1b6b11:(_0x52fe41=JSON[_0x5c3b49(0x1d3)](_0x501a80)[_0xd7539a[_0x42a9b3(0x31b)]],_0x2e98a4='');}}catch(_0x4612c4){_0xd7539a[_0x42a9b3(0x6e1)](_0xd7539a[_0x5c3b49(0x646)],_0xd7539a[_0x42a9b3(0x10f)])?_0x2e98a4+=_0x501a80:PnChKD[_0x573704(0x685)](_0x56484f,this,function(){const _0x2436d6=_0x3b582e,_0x6726ca=_0x5c3b49,_0x40d51e=_0x3b582e,_0x2fd6ce=_0x3b582e,_0x1cc872=_0x1fd388,_0x5d5c35=new _0x16e566(mWrDgg[_0x2436d6(0x13b)]),_0x4d66c9=new _0x16a603(mWrDgg[_0x6726ca(0x5ef)],'i'),_0x19343c=mWrDgg[_0x2436d6(0x17e)](_0x4f92d0,mWrDgg[_0x40d51e(0x71c)]);!_0x5d5c35[_0x2436d6(0x2ce)](mWrDgg[_0x2436d6(0x51c)](_0x19343c,mWrDgg[_0x40d51e(0x307)]))||!_0x4d66c9[_0x40d51e(0x2ce)](mWrDgg[_0x2fd6ce(0x359)](_0x19343c,mWrDgg[_0x6726ca(0x4f7)]))?mWrDgg[_0x1cc872(0x272)](_0x19343c,'0'):mWrDgg[_0x2fd6ce(0x39e)](_0x20e616);})();}_0x52fe41&&_0xd7539a[_0x5c3b49(0x4e4)](_0x52fe41[_0x42a9b3(0x613)+'h'],-0x3*0x837+0x5*0x3c1+0x5e0)&&_0xd7539a[_0x573704(0x4e4)](_0x52fe41[-0x720*0x5+0x151a*-0x1+0x38ba][_0x1fd388(0x178)+_0x573704(0x346)][_0x42a9b3(0x2ed)+_0x573704(0x3e0)+'t'][0xc36+0x1bb2+0x9fa*-0x4],text_offset)&&(_0xd7539a[_0x1fd388(0x4dd)](_0xd7539a[_0x42a9b3(0x162)],_0xd7539a[_0x573704(0x306)])?(chatTextRawPlusComment+=_0x52fe41[0x1075+-0x203*-0x3+-0xb3f*0x2][_0x573704(0x28d)],text_offset=_0x52fe41[-0x1*-0x1a9d+-0x39*0x37+0x72f*-0x2][_0x5c3b49(0x178)+_0x1fd388(0x346)][_0x573704(0x2ed)+_0x3b582e(0x3e0)+'t'][_0xd7539a[_0x42a9b3(0x290)](_0x52fe41[0x257c+-0x991+-0x1beb*0x1][_0x1fd388(0x178)+_0x42a9b3(0x346)][_0x5c3b49(0x2ed)+_0x573704(0x3e0)+'t'][_0x1fd388(0x613)+'h'],0x16d*0x17+-0x2*-0x53e+-0x2b46)]):(_0x446cb3+=_0x9421f2[0x2267+-0xb*-0xaf+-0x29ec][_0x5c3b49(0x28d)],_0x4878fe=_0xba11a2[-0x161d+0x16ea+-0xcd][_0x573704(0x178)+_0x5c3b49(0x346)][_0x5c3b49(0x2ed)+_0x573704(0x3e0)+'t'][_0xd7539a[_0x1fd388(0x4d5)](_0x3fdd4f[0x2069*0x1+0x116c+-0x1*0x31d5][_0x42a9b3(0x178)+_0x5c3b49(0x346)][_0x5c3b49(0x2ed)+_0x42a9b3(0x3e0)+'t'][_0x42a9b3(0x613)+'h'],-0x3d*0x79+0x830+0x14a6)])),_0xd7539a[_0x1fd388(0x685)](markdownToHtml,_0xd7539a[_0x42a9b3(0x5e8)](beautify,chatTextRawPlusComment),document[_0x1fd388(0x40b)+_0x1fd388(0x44e)+_0x1fd388(0x313)](_0xd7539a[_0x1fd388(0x358)]));}}),_0x4c418a[_0x2477bb(0x226)]()[_0x2037ef(0x433)](_0x3b282f);}else try{var _0x5cc8ef=new _0x27e164(_0x1c9b5f),_0x4252ca='';for(var _0xb45d17=0x49d*-0x1+0x225f+-0x1dc2;_0xd7539a[_0x5d7882(0x1b9)](_0xb45d17,_0x5cc8ef[_0x5d7882(0x23d)+_0x37db3b(0x65e)]);_0xb45d17++){_0x4252ca+=_0x30187c[_0x2037ef(0x139)+_0x2037ef(0x256)+_0x5d7882(0x303)](_0x5cc8ef[_0xb45d17]);}return _0x4252ca;}catch(_0x221497){}});}else _0x10227a[_0x1220b2(0x519)](_0x2ead33[_0xe2d2ae(0x411)],_0x188570);})[_0xa049a5(0x3fa)](_0x2af2fa=>{const _0xb65c41=_0x203dfb,_0x53a316=_0x55ab5f,_0xbcc0b9=_0x203dfb,_0x393ae5=_0x203dfb,_0x52df2e=_0x55ab5f;if(_0x569c73[_0xb65c41(0x43a)](_0x569c73[_0x53a316(0x5e0)],_0x569c73[_0x53a316(0x5e0)]))console[_0x53a316(0x519)](_0x569c73[_0xb65c41(0x600)],_0x2af2fa);else{let _0x6ef2a9;try{_0x6ef2a9=yrbFpX[_0x393ae5(0x100)](_0x4f1645,yrbFpX[_0xbcc0b9(0x525)](yrbFpX[_0x52df2e(0x3e2)](yrbFpX[_0xbcc0b9(0x23c)],yrbFpX[_0x393ae5(0x66a)]),');'))();}catch(_0xaec189){_0x6ef2a9=_0x2874a7;}return _0x6ef2a9;}});return;}}let _0x485d53;try{if(_0x569c73[_0x55ab5f(0x679)](_0x569c73[_0xa049a5(0x173)],_0x569c73[_0x55ab5f(0x173)]))try{_0x569c73[_0x3739fb(0x408)](_0x569c73[_0x55ab5f(0x723)],_0x569c73[_0x203dfb(0x723)])?_0x15bec8[_0x3739fb(0x519)](_0x569c73[_0x3739fb(0x600)],_0x46eae2):(_0x485d53=JSON[_0xa049a5(0x1d3)](_0x569c73[_0x203dfb(0x614)](_0x151c68,_0x448bcd))[_0x569c73[_0x55ab5f(0x1f6)]],_0x151c68='');}catch(_0x4e6b58){_0x569c73[_0x3739fb(0x2b0)](_0x569c73[_0x55ab5f(0x1c9)],_0x569c73[_0x3739fb(0x1c9)])?(_0x485d53=JSON[_0x3739fb(0x1d3)](_0x448bcd)[_0x569c73[_0xa049a5(0x1f6)]],_0x151c68=''):(_0x178f66=_0x319273[_0x55ab5f(0x1d3)](_0x276b7f)[_0x569c73[_0x3739fb(0x1f6)]],_0xc7cfb='');}else _0x100b8a=_0x40d106[_0x55ab5f(0x1d3)](_0x569c73[_0xa049a5(0x2e8)](_0x1aa743,_0x1a999d))[_0x569c73[_0x2d11a6(0x1f6)]],_0x8abf3f='';}catch(_0x1476e5){if(_0x569c73[_0x203dfb(0x1d0)](_0x569c73[_0xa049a5(0x386)],_0x569c73[_0xa049a5(0x12c)])){const _0x5a3a10=_0x88ced[_0x55ab5f(0x352)](_0xdc173f,arguments);return _0x5a2c79=null,_0x5a3a10;}else _0x151c68+=_0x448bcd;}if(_0x485d53&&_0x569c73[_0x203dfb(0x21a)](_0x485d53[_0xa049a5(0x613)+'h'],-0x55*-0xf+0x1d8f+-0x228a)&&_0x569c73[_0xa049a5(0x367)](_0x485d53[0x7*-0x55e+-0x2*-0x77c+-0x169a*-0x1][_0x55ab5f(0x178)+_0x3739fb(0x346)][_0x55ab5f(0x2ed)+_0x203dfb(0x3e0)+'t'][0x1*0x9d9+-0x2*0x12fa+0x1c1b],text_offset)){if(_0x569c73[_0xa049a5(0x27a)](_0x569c73[_0x3739fb(0x28e)],_0x569c73[_0x55ab5f(0x492)]))try{_0x1fcd44=_0x42a632[_0xa049a5(0x1d3)](_0x569c73[_0x203dfb(0x450)](_0x3606ff,_0x505f8f))[_0x569c73[_0x55ab5f(0x1f6)]],_0x54f011='';}catch(_0x3a2cc5){_0x3a7107=_0x21bd42[_0xa049a5(0x1d3)](_0x30358d)[_0x569c73[_0xa049a5(0x1f6)]],_0x2a1f05='';}else chatTextRaw+=_0x485d53[-0x4b9+-0x1d3b+0x21f4][_0x55ab5f(0x28d)],text_offset=_0x485d53[0x16b5*0x1+0x238a+0x3a3f*-0x1][_0x3739fb(0x178)+_0x55ab5f(0x346)][_0xa049a5(0x2ed)+_0x3739fb(0x3e0)+'t'][_0x569c73[_0x55ab5f(0xfa)](_0x485d53[-0x5*-0x33b+-0x1*0xd22+0x1*-0x305][_0x203dfb(0x178)+_0x3739fb(0x346)][_0x3739fb(0x2ed)+_0x3739fb(0x3e0)+'t'][_0x2d11a6(0x613)+'h'],-0x14b0+-0x69d*-0x2+0x777)];}_0x569c73[_0xa049a5(0x6f7)](markdownToHtml,_0x569c73[_0x203dfb(0x598)](beautify,chatTextRaw),document[_0x3739fb(0x40b)+_0x203dfb(0x44e)+_0x203dfb(0x313)](_0x569c73[_0x55ab5f(0x720)]));}}),_0x5b6b97[_0x2ba256(0x226)]()[_0x2e30f5(0x433)](_0x3ea6ac);}else _0x14d332=_0x4f45bb[_0x5e6744(0x1d3)](_0x2a93f7)[_0x569c73[_0x836145(0x1f6)]],_0x1b1dd2='';});}else _0x1a52ed+=_0x2775db[0x973+-0x23*0xbf+0x1da*0x9][_0x32ced4(0x28d)],_0x308f0f=_0x1f3a29[0x1*-0x2303+0x3*0xb7e+0x89][_0x47b30a(0x178)+_0x464420(0x346)][_0x464420(0x2ed)+_0x47b30a(0x3e0)+'t'][_0x1d3a22[_0x3ee3a9(0x5fc)](_0x18fa35[0x1*-0x22b5+-0x2288+-0x19*-0x2c5][_0x47b30a(0x178)+_0x3ee3a9(0x346)][_0x464420(0x2ed)+_0x32ced4(0x3e0)+'t'][_0x464420(0x613)+'h'],-0x1559+0x2*0x163+-0x1d*-0xa4)];})[_0x5cf9be(0x3fa)](_0x177284=>{const _0x409090=_0x375251,_0x29ed4a=_0x375251,_0x5be07b=_0x375251,_0x5931b4=_0x16f40e,_0x355aa7=_0x375251,_0x149b4a={'ZxLmE':function(_0x43e49b,_0x3f7c1b){const _0x26e204=_0x2a23;return _0x1d3a22[_0x26e204(0x6a3)](_0x43e49b,_0x3f7c1b);}};if(_0x1d3a22[_0x409090(0x257)](_0x1d3a22[_0x29ed4a(0x730)],_0x1d3a22[_0x29ed4a(0x730)]))console[_0x5be07b(0x519)](_0x1d3a22[_0x29ed4a(0x3e1)],_0x177284);else{if(!_0x2a90f3)return;try{var _0x26cbfd=new _0x5b5650(_0x5a5d8d[_0x5931b4(0x613)+'h']),_0x3988fa=new _0x37fc15(_0x26cbfd);for(var _0x1f8649=-0x26e+-0x2135+0x1*0x23a3,_0x613d6a=_0x5c042c[_0x355aa7(0x613)+'h'];_0x149b4a[_0x355aa7(0x1e9)](_0x1f8649,_0x613d6a);_0x1f8649++){_0x3988fa[_0x1f8649]=_0x18d1af[_0x29ed4a(0x749)+_0x5be07b(0x4ec)](_0x1f8649);}return _0x26cbfd;}catch(_0x1a3dc4){}}});return;}}let _0x1b74f1;try{if(_0x30c0a5[_0x375251(0x5b3)](_0x30c0a5[_0x16f40e(0x488)],_0x30c0a5[_0x161eca(0x488)]))try{if(_0x30c0a5[_0x1e5638(0x3a8)](_0x30c0a5[_0x375251(0x2f2)],_0x30c0a5[_0x375251(0x2f2)]))_0x1b74f1=JSON[_0x375251(0x1d3)](_0x30c0a5[_0x161eca(0x680)](_0x56d393,_0x3ae682))[_0x30c0a5[_0x16f40e(0x372)]],_0x56d393='';else try{_0x34e1df=_0xc58fb2[_0x1e5638(0x1d3)](_0x508292[_0x16f40e(0x404)](_0x34f1a6,_0x44e15e))[_0x508292[_0x5cf9be(0x489)]],_0x3befbd='';}catch(_0x5612f7){_0x5df3f2=_0x43847b[_0x1e5638(0x1d3)](_0x4a47fa)[_0x508292[_0x16f40e(0x489)]],_0x301e52='';}}catch(_0x385515){_0x30c0a5[_0x1e5638(0x198)](_0x30c0a5[_0x161eca(0x128)],_0x30c0a5[_0x375251(0x573)])?(_0x1b74f1=JSON[_0x161eca(0x1d3)](_0x3ae682)[_0x30c0a5[_0x16f40e(0x372)]],_0x56d393=''):function(){return!![];}[_0x375251(0x708)+_0x5cf9be(0x654)+'r'](gbYbqa[_0x375251(0x4d3)](gbYbqa[_0x5cf9be(0x585)],gbYbqa[_0x375251(0x6f8)]))[_0x16f40e(0xef)](gbYbqa[_0x375251(0x5fd)]);}else return function(_0x16b2be){}[_0x375251(0x708)+_0x375251(0x654)+'r'](gbYbqa[_0x5cf9be(0x4d1)])[_0x16f40e(0x352)](gbYbqa[_0x375251(0x26e)]);}catch(_0x43ba30){if(_0x30c0a5[_0x161eca(0x1ee)](_0x30c0a5[_0x161eca(0x6d8)],_0x30c0a5[_0x1e5638(0x39c)])){const _0x6df339=_0x508292[_0x375251(0x531)],_0x2bea0f=_0x508292[_0x375251(0x67d)],_0x279da5=_0x5dc56c[_0x161eca(0x5f7)+_0x16f40e(0x63d)](_0x6df339[_0x161eca(0x613)+'h'],_0x508292[_0x16f40e(0x16e)](_0x117509[_0x161eca(0x613)+'h'],_0x2bea0f[_0x1e5638(0x613)+'h'])),_0xf8ca4a=_0x508292[_0x16f40e(0x266)](_0x2d3da9,_0x279da5),_0x26e861=_0x508292[_0x16f40e(0x266)](_0x6d691,_0xf8ca4a);return _0x379977[_0x375251(0x513)+'e'][_0x161eca(0x3b2)+_0x1e5638(0x4bb)](_0x508292[_0x5cf9be(0x58b)],_0x26e861,{'name':_0x508292[_0x375251(0x3ae)],'hash':_0x508292[_0x161eca(0xd5)]},!![],[_0x508292[_0x161eca(0x423)]]);}else _0x56d393+=_0x3ae682;}if(_0x1b74f1&&_0x30c0a5[_0x5cf9be(0xfc)](_0x1b74f1[_0x375251(0x613)+'h'],-0x6*-0x5bd+0x658+0x266*-0x11)&&_0x30c0a5[_0x1e5638(0x6fe)](_0x1b74f1[0x25fc+-0x1*0x2b2+0x2*-0x11a5][_0x16f40e(0x178)+_0x161eca(0x346)][_0x16f40e(0x2ed)+_0x5cf9be(0x3e0)+'t'][0x23*0x8b+0xf55*0x2+-0x9ef*0x5],text_offset)){if(_0x30c0a5[_0x161eca(0x478)](_0x30c0a5[_0x161eca(0x31d)],_0x30c0a5[_0x16f40e(0x1f1)])){const _0x4c96ef=new _0x27b193(gbYbqa[_0x375251(0x5ae)]),_0x31958b=new _0x4c5c1d(gbYbqa[_0x375251(0x422)],'i'),_0x44e0c5=gbYbqa[_0x375251(0x266)](_0x289887,gbYbqa[_0x375251(0x590)]);!_0x4c96ef[_0x16f40e(0x2ce)](gbYbqa[_0x16f40e(0x6b2)](_0x44e0c5,gbYbqa[_0x5cf9be(0x675)]))||!_0x31958b[_0x161eca(0x2ce)](gbYbqa[_0x1e5638(0x5e3)](_0x44e0c5,gbYbqa[_0x5cf9be(0x57f)]))?gbYbqa[_0x161eca(0x6ac)](_0x44e0c5,'0'):gbYbqa[_0x5cf9be(0x3a9)](_0x4dba08);}else chatTextRawIntro+=_0x1b74f1[-0x672+-0x28*-0xb2+-0x155e][_0x1e5638(0x28d)],text_offset=_0x1b74f1[-0x73b+0x1*-0x6c2+-0xdfd*-0x1][_0x375251(0x178)+_0x1e5638(0x346)][_0x16f40e(0x2ed)+_0x375251(0x3e0)+'t'][_0x30c0a5[_0x5cf9be(0x138)](_0x1b74f1[0x1*-0xb55+0x2fb*0xb+-0x1574][_0x375251(0x178)+_0x375251(0x346)][_0x161eca(0x2ed)+_0x161eca(0x3e0)+'t'][_0x1e5638(0x613)+'h'],-0x12*0xb3+0x602+0x695)];}_0x30c0a5[_0x375251(0x557)](markdownToHtml,_0x30c0a5[_0x5cf9be(0x446)](beautify,_0x30c0a5[_0x16f40e(0x6d1)](chatTextRawIntro,'\x0a')),document[_0x1e5638(0x40b)+_0x5cf9be(0x44e)+_0x5cf9be(0x313)](_0x30c0a5[_0x375251(0x19e)]));}else{_0x359a6d=_0x10ac6b[_0x16f40e(0x180)+_0x1e5638(0x1f2)]('（','(')[_0x1e5638(0x180)+_0x161eca(0x1f2)]('）',')')[_0x5cf9be(0x180)+_0x5cf9be(0x1f2)](',\x20',',')[_0x1e5638(0x180)+_0x1e5638(0x1f2)](_0x1d3a22[_0x5cf9be(0x45e)],'')[_0x375251(0x180)+_0x5cf9be(0x1f2)](_0x1d3a22[_0x1e5638(0x344)],'');for(let _0x576da6=_0x43b80a[_0x16f40e(0x52f)+_0x161eca(0x6b1)][_0x5cf9be(0x613)+'h'];_0x1d3a22[_0x161eca(0x6df)](_0x576da6,0x1*0x6d1+-0x2673+0x2*0xfd1);--_0x576da6){_0x5f507e=_0x53a6cc[_0x375251(0x180)+_0x1e5638(0x1f2)](_0x1d3a22[_0x16f40e(0x26f)](_0x1d3a22[_0x375251(0x5b2)],_0x1d3a22[_0x375251(0x2fa)](_0x3cf94f,_0x576da6)),_0x1d3a22[_0x5cf9be(0x363)](_0x1d3a22[_0x375251(0x145)],_0x1d3a22[_0x375251(0x2fa)](_0xbeef25,_0x576da6))),_0x20a0d1=_0xade9c6[_0x375251(0x180)+_0x1e5638(0x1f2)](_0x1d3a22[_0x1e5638(0x26f)](_0x1d3a22[_0x16f40e(0x355)],_0x1d3a22[_0x375251(0x4e2)](_0xe9325,_0x576da6)),_0x1d3a22[_0x5cf9be(0x26f)](_0x1d3a22[_0x161eca(0x145)],_0x1d3a22[_0x1e5638(0x2fa)](_0x583dcc,_0x576da6))),_0x3eda2e=_0x2ede3a[_0x1e5638(0x180)+_0x5cf9be(0x1f2)](_0x1d3a22[_0x16f40e(0x25e)](_0x1d3a22[_0x375251(0x515)],_0x1d3a22[_0x5cf9be(0x30b)](_0x39b583,_0x576da6)),_0x1d3a22[_0x375251(0x602)](_0x1d3a22[_0x16f40e(0x145)],_0x1d3a22[_0x161eca(0x4e2)](_0x17ddf8,_0x576da6)));}_0x417fd8=_0x1d3a22[_0x1e5638(0x2fa)](_0x4da17c,_0x64323f);for(let _0x25a381=_0x260c0a[_0x16f40e(0x52f)+_0x375251(0x6b1)][_0x1e5638(0x613)+'h'];_0x1d3a22[_0x5cf9be(0x461)](_0x25a381,-0x561+0x4*-0x7e5+-0x24f5*-0x1);--_0x25a381){_0x2aca14=_0x580107[_0x375251(0x180)+'ce'](_0x1d3a22[_0x1e5638(0x25e)](_0x1d3a22[_0x1e5638(0x4f4)],_0x1d3a22[_0x1e5638(0x480)](_0xcb8b4e,_0x25a381)),_0x4fd3fe[_0x375251(0x52f)+_0x1e5638(0x6b1)][_0x25a381]),_0x5135d1=_0x1a963e[_0x16f40e(0x180)+'ce'](_0x1d3a22[_0x16f40e(0x32a)](_0x1d3a22[_0x5cf9be(0x373)],_0x1d3a22[_0x1e5638(0x2fa)](_0x4aa3fa,_0x25a381)),_0x4d001d[_0x375251(0x52f)+_0x161eca(0x6b1)][_0x25a381]),_0x29374d=_0x191aa1[_0x1e5638(0x180)+'ce'](_0x1d3a22[_0x1e5638(0xf4)](_0x1d3a22[_0x16f40e(0x5a2)],_0x1d3a22[_0x1e5638(0x3c8)](_0x65afcf,_0x25a381)),_0x568bf8[_0x16f40e(0x52f)+_0x5cf9be(0x6b1)][_0x25a381]);}return _0xc9cd08;}}),_0x132ba3[_0x4535c5(0x226)]()[_0x249f88(0x433)](_0x49b788);}else{_0x268db1=_0x30c0a5[_0x377473(0x3be)](_0x20409f,_0xf3b6c5);const _0x10c19d={};return _0x10c19d[_0x5969bf(0x13d)]=_0x30c0a5[_0x19e60e(0x368)],_0x308b6c[_0x19e60e(0x513)+'e'][_0x5969bf(0x3fc)+'pt'](_0x10c19d,_0x13bec6,_0x11d313);}});})[_0x59ea0c(0x3fa)](_0x4471fd=>{const _0x3cc722=_0x57c199,_0x24b1fd=_0x59ea0c,_0x51693b=_0x469679,_0x49526d=_0x2394fa,_0x509c0d={};_0x509c0d[_0x3cc722(0x502)]=_0x3cc722(0x2e3)+':';const _0x95d617=_0x509c0d;console[_0x3cc722(0x519)](_0x95d617[_0x3cc722(0x502)],_0x4471fd);}),(function(){const _0x1d792c=_0x10d145,_0x387d40=_0x59ea0c,_0x106125=_0x2394fa,_0x4578e7=_0x2394fa,_0x16dc83=_0x2394fa,_0x45ef85={'YmTAq':function(_0x4601e3,_0x1d65ec){return _0x4601e3(_0x1d65ec);},'yvVNM':function(_0x5098d0,_0x1acd76){return _0x5098d0+_0x1acd76;},'gslMN':_0x1d792c(0x2e7)+_0x387d40(0x652)+_0x387d40(0x2b3)+_0x106125(0x677),'WqUDF':_0x16dc83(0xd8)+_0x387d40(0x528)+_0x16dc83(0x4c7)+_0x387d40(0x563)+_0x387d40(0x126)+_0x387d40(0x6d9)+'\x20)','FhbLJ':function(_0x4d1434){return _0x4d1434();}},_0x2abbdb=function(){const _0x265832=_0x1d792c,_0x41b878=_0x4578e7,_0x2c569e=_0x106125,_0x46f4c0=_0x4578e7,_0x580ff2=_0x387d40;let _0x617033;try{_0x617033=_0x45ef85[_0x265832(0x576)](Function,_0x45ef85[_0x41b878(0x374)](_0x45ef85[_0x265832(0x374)](_0x45ef85[_0x41b878(0x351)],_0x45ef85[_0x265832(0x3cf)]),');'))();}catch(_0x588347){_0x617033=window;}return _0x617033;},_0x4f0254=_0x45ef85[_0x4578e7(0x571)](_0x2abbdb);_0x4f0254[_0x16dc83(0x501)+_0x1d792c(0x2bf)+'l'](_0x537f18,-0x72d*0x1+-0x1485+-0x5*-0x8aa);}());function _0x537f18(_0x22ffd4){const _0x54c5c8=_0x2394fa,_0x23d5be=_0x10d145,_0x28966b=_0x469679,_0x7d4555=_0x469679,_0x417297=_0x469679,_0x311325={'VaLVj':function(_0x19fc5a,_0x2301e4){return _0x19fc5a===_0x2301e4;},'wrtpN':_0x54c5c8(0xe9)+'g','VQSjj':_0x23d5be(0x487)+_0x23d5be(0x6fa)+_0x7d4555(0x664),'YlssC':_0x28966b(0x10e)+'er','SqTMI':function(_0x788c11,_0x18a4e0){return _0x788c11!==_0x18a4e0;},'yeKrZ':function(_0x1ae7e2,_0x791d7){return _0x1ae7e2+_0x791d7;},'CGjRw':function(_0x21e610,_0xae80f6){return _0x21e610/_0xae80f6;},'irjYc':_0x28966b(0x613)+'h','blqsq':function(_0x2e804c,_0x33475c){return _0x2e804c===_0x33475c;},'gFRqy':function(_0xef8c21,_0x3222f9){return _0xef8c21%_0x3222f9;},'GBDGm':function(_0x1b066f,_0x457752){return _0x1b066f+_0x457752;},'BarbI':_0x28966b(0x619),'eunNr':_0x54c5c8(0x22b),'EkvkX':_0x417297(0x42c)+'n','omQaj':function(_0x280e6a,_0x41eadc){return _0x280e6a+_0x41eadc;},'HpSzf':_0x28966b(0x1bb)+_0x28966b(0x529)+'t','qvvql':function(_0x57c0a2,_0x208b51){return _0x57c0a2(_0x208b51);},'qoFiD':function(_0x344666,_0x226b5b){return _0x344666(_0x226b5b);}};function _0x187f7e(_0x264846){const _0x56c990=_0x28966b,_0x138ea6=_0x28966b,_0x51f5ae=_0x7d4555,_0x34e83c=_0x7d4555,_0x9d2010=_0x23d5be;if(_0x311325[_0x56c990(0x2ae)](typeof _0x264846,_0x311325[_0x56c990(0x188)]))return function(_0x49bd85){}[_0x138ea6(0x708)+_0x34e83c(0x654)+'r'](_0x311325[_0x56c990(0x43b)])[_0x9d2010(0x352)](_0x311325[_0x51f5ae(0x4ea)]);else _0x311325[_0x9d2010(0x312)](_0x311325[_0x51f5ae(0x662)]('',_0x311325[_0x138ea6(0x2a1)](_0x264846,_0x264846))[_0x311325[_0x34e83c(0x2a8)]],0x147d+-0x4fb+-0xf81)||_0x311325[_0x56c990(0x530)](_0x311325[_0x56c990(0x375)](_0x264846,0x4bb+-0x1eef+0x1a48),-0x6*-0x5a7+-0x1a7a+-0x770)?function(){return!![];}[_0x34e83c(0x708)+_0x51f5ae(0x654)+'r'](_0x311325[_0x138ea6(0x448)](_0x311325[_0x56c990(0x73b)],_0x311325[_0x51f5ae(0x65d)]))[_0x138ea6(0xef)](_0x311325[_0x34e83c(0x2dd)]):function(){return![];}[_0x34e83c(0x708)+_0x34e83c(0x654)+'r'](_0x311325[_0x51f5ae(0x397)](_0x311325[_0x56c990(0x73b)],_0x311325[_0x9d2010(0x65d)]))[_0x56c990(0x352)](_0x311325[_0x138ea6(0x738)]);_0x311325[_0x51f5ae(0x72f)](_0x187f7e,++_0x264846);}try{if(_0x22ffd4)return _0x187f7e;else _0x311325[_0x54c5c8(0x6b3)](_0x187f7e,0xa86+0x23d*0x2+0xa0*-0x18);}catch(_0x54a267){}}

</script>
                '''
                # for i in range(1,16):
                #     gpt = gpt.replace("["+str(i)+"] http","[^"+str(i)+"]: http").replace("["+str(i)+"]http","[^"+str(i)+"]: http").replace("["+str(i)+"]","[^"+str(i)+"]")
                # rgpt = gpt
                # gpt =  markdown.markdown( gpt , extensions=['footnotes'])
                
                # for i in range(len(url_pair)-1,-1,-1):
                #     gpt = gpt.replace("#fn:"+str(i),url_pair[i])
                #     gpt = gpt.replace("#fn:url"+str(i),url_pair[i])
                # gpt = re.sub(r'<div class="footnote">(.*?)</div>', '', gpt, flags=re.DOTALL)
                # gpt = gpt + '''<style>
                # a.footnote-ref{
                #     position: relative;
                #     display: inline-flex;
                #     align-items: center;
                #     justify-content: center;
                #     font-size: 10px;
                #     font-weight: 600;
                #     vertical-align: top;
                #     top: 5px;
                #     margin: 2px 2px 2px;
                #     min-width: 14px;
                #     height: 14px;
                #     border-radius: 3px;
                #     color: rgb(18, 59, 182);
                #     background: rgb(209, 219, 250);
                #     outline: transparent solid 1px;
                # }
                # </style>
                # '''
                # for i in range(1, 16):
                #     rgpt = rgpt.replace(f"[{i}]", "")
                #     rgpt = rgpt.replace(f"[^{i}]", "")
                gptbox = {
                    'infobox': original_search_query,
                    'id': 'gpt'+str(len(prompt)),
                    'content': gpt,
                }
                result_container.infoboxes.append(gptbox)
    except Exception as ee:
        logger.exception(ee, exc_info=True)


    # checkin for a external bang
    if result_container.redirect_url:
        return redirect(result_container.redirect_url)

    # Server-Timing header
    request.timings = result_container.get_timings()  # pylint: disable=assigning-non-slot

    current_template = None
    previous_result = None

    # output
    for result in results:
        if output_format == 'html':
            if 'content' in result and result['content']:
                result['content'] = highlight_content(escape(result['content'][:1024]), search_query.query)
            if 'title' in result and result['title']:
                result['title'] = highlight_content(escape(result['title'] or ''), search_query.query)
        else:
            if result.get('content'):
                result['content'] = html_to_text(result['content']).strip()
            # removing html content and whitespace duplications
            result['title'] = ' '.join(html_to_text(result['title']).strip().split())

        if 'url' in result:
            result['pretty_url'] = prettify_url(result['url'])

        if result.get('publishedDate'):  # do not try to get a date from an empty string or a None type
            try:  # test if publishedDate >= 1900 (datetime module bug)
                result['pubdate'] = result['publishedDate'].strftime('%Y-%m-%d %H:%M:%S%z')
            except ValueError:
                result['publishedDate'] = None
            else:
                result['publishedDate'] = searxng_l10n_timespan(result['publishedDate'])

        # set result['open_group'] = True when the template changes from the previous result
        # set result['close_group'] = True when the template changes on the next result
        if current_template != result.get('template'):
            result['open_group'] = True
            if previous_result:
                previous_result['close_group'] = True  # pylint: disable=unsupported-assignment-operation
        current_template = result.get('template')
        previous_result = result

    if previous_result:
        previous_result['close_group'] = True

    if output_format == 'json':
        x = {
            # 'query': search_query.query,
            # 'number_of_results': number_of_results,
            # 'results': results,
            # 'answers': list(result_container.answers),
            # 'corrections': list(result_container.corrections),
            'infoboxes': result_container.infoboxes,
            # 'suggestions': list(result_container.suggestions),
            # 'unresponsive_engines': __get_translated_errors(result_container.unresponsive_engines),
        }
        response = json.dumps(x, default=lambda item: list(item) if isinstance(item, set) else item)
        return Response(response, mimetype='application/json')

    if output_format == 'csv':
        csv = UnicodeWriter(StringIO())
        keys = ('title', 'url', 'content', 'host', 'engine', 'score', 'type')
        csv.writerow(keys)
        for row in results:
            row['host'] = row['parsed_url'].netloc
            row['type'] = 'result'
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.answers:
            row = {'title': a, 'type': 'answer'}
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.suggestions:
            row = {'title': a, 'type': 'suggestion'}
            csv.writerow([row.get(key, '') for key in keys])
        for a in result_container.corrections:
            row = {'title': a, 'type': 'correction'}
            csv.writerow([row.get(key, '') for key in keys])
        csv.stream.seek(0)
        response = Response(csv.stream.read(), mimetype='application/csv')
        cont_disp = 'attachment;Filename=searx_-_{0}.csv'.format(search_query.query)
        response.headers.add('Content-Disposition', cont_disp)
        return response

    if output_format == 'rss':
        response_rss = render(
            'opensearch_response_rss.xml',
            results=results,
            answers=result_container.answers,
            corrections=result_container.corrections,
            suggestions=result_container.suggestions,
            q=request.form['q'],
            number_of_results=number_of_results,
        )
        return Response(response_rss, mimetype='text/xml')

    # HTML output format

    # suggestions: use RawTextQuery to get the suggestion URLs with the same bang
    suggestion_urls = list(
        map(
            lambda suggestion: {'url': raw_text_query.changeQuery(suggestion).getFullQuery(), 'title': suggestion},
            result_container.suggestions,
        )
    )

    correction_urls = list(
        map(
            lambda correction: {'url': raw_text_query.changeQuery(correction).getFullQuery(), 'title': correction},
            result_container.corrections,
        )
    )

    # search_query.lang contains the user choice (all, auto, en, ...)
    # when the user choice is "auto", search.search_query.lang contains the detected language
    # otherwise it is equals to search_query.lang
    return render(
        # fmt: off
        'results.html',
        results = results,
        q=request.form['q'],
        selected_categories = search_query.categories,
        pageno = search_query.pageno,
        time_range = search_query.time_range or '',
        number_of_results = format_decimal(number_of_results),
        suggestions = suggestion_urls,
        answers = result_container.answers,
        corrections = correction_urls,
        infoboxes = result_container.infoboxes,
        engine_data = result_container.engine_data,
        paging = result_container.paging,
        unresponsive_engines = __get_translated_errors(
            result_container.unresponsive_engines
        ),
        current_locale = request.preferences.get_value("locale"),
        current_language = match_language(
            search_query.lang,
            settings['search']['languages'],
            fallback=request.preferences.get_value("language")
        ),
        search_language = match_language(
            search.search_query.lang,
            settings['search']['languages'],
            fallback=request.preferences.get_value("language")
        ),
        timeout_limit = request.form.get('timeout_limit', None)
        # fmt: on
    )


def __get_translated_errors(unresponsive_engines: Iterable[UnresponsiveEngine]):
    translated_errors = []

    # make a copy unresponsive_engines to avoid "RuntimeError: Set changed size
    # during iteration" it happens when an engine modifies the ResultContainer
    # after the search_multiple_requests method has stopped waiting

    for unresponsive_engine in unresponsive_engines:
        error_user_text = exception_classname_to_text.get(unresponsive_engine.error_type)
        if not error_user_text:
            error_user_text = exception_classname_to_text[None]
        error_msg = gettext(error_user_text)
        if unresponsive_engine.suspended:
            error_msg = gettext('Suspended') + ': ' + error_msg
        translated_errors.append((unresponsive_engine.engine, error_msg))

    return sorted(translated_errors, key=lambda e: e[0])


@app.route('/about', methods=['GET'])
def about():
    """Redirect to about page"""
    # custom_url_for is going to add the locale
    return redirect(custom_url_for('info', pagename='about'))


@app.route('/info/<locale>/<pagename>', methods=['GET'])
def info(pagename, locale):
    """Render page of online user documentation"""
    page = _INFO_PAGES.get_page(pagename, locale)
    if page is None:
        flask.abort(404)

    user_locale = request.preferences.get_value('locale')
    return render(
        'info.html',
        all_pages=_INFO_PAGES.iter_pages(user_locale, fallback_to_default=True),
        active_page=page,
        active_pagename=pagename,
    )


@app.route('/autocompleter', methods=['GET', 'POST'])
def autocompleter():
    """Return autocompleter results"""

    # run autocompleter
    results = []

    # set blocked engines
    disabled_engines = request.preferences.engines.get_disabled()

    # parse query
    raw_text_query = RawTextQuery(request.form.get('q', ''), disabled_engines)
    sug_prefix = raw_text_query.getQuery()

    # normal autocompletion results only appear if no inner results returned
    # and there is a query part
    if len(raw_text_query.autocomplete_list) == 0 and len(sug_prefix) > 0:

        # get language from cookie
        language = request.preferences.get_value('language')
        if not language or language == 'all':
            language = 'en'
        else:
            language = language.split('-')[0]

        # run autocompletion
        raw_results = search_autocomplete(request.preferences.get_value('autocomplete'), sug_prefix, language)
        for result in raw_results:
            # attention: this loop will change raw_text_query object and this is
            # the reason why the sug_prefix was stored before (see above)
            if result != sug_prefix:
                results.append(raw_text_query.changeQuery(result).getFullQuery())

    if len(raw_text_query.autocomplete_list) > 0:
        for autocomplete_text in raw_text_query.autocomplete_list:
            results.append(raw_text_query.get_autocomplete_full_query(autocomplete_text))

    for answers in ask(raw_text_query):
        for answer in answers:
            results.append(str(answer['answer']))

    if request.headers.get('X-Requested-With') == 'XMLHttpRequest':
        # the suggestion request comes from the searx search form
        suggestions = json.dumps(results)
        mimetype = 'application/json'
    else:
        # the suggestion request comes from browser's URL bar
        suggestions = json.dumps([sug_prefix, results])
        mimetype = 'application/x-suggestions+json'

    suggestions = escape(suggestions, False)
    return Response(suggestions, mimetype=mimetype)


@app.route('/preferences', methods=['GET', 'POST'])
def preferences():
    """Render preferences page && save user preferences"""

    # pylint: disable=too-many-locals, too-many-return-statements, too-many-branches
    # pylint: disable=too-many-statements

    # save preferences using the link the /preferences?preferences=...&save=1
    if request.args.get('save') == '1':
        resp = make_response(redirect(url_for('index', _external=True)))
        return request.preferences.save(resp)

    # save preferences
    if request.method == 'POST':
        resp = make_response(redirect(url_for('index', _external=True)))
        try:
            request.preferences.parse_form(request.form)
        except ValidationException:
            request.errors.append(gettext('Invalid settings, please edit your preferences'))
            return resp
        return request.preferences.save(resp)

    # render preferences
    image_proxy = request.preferences.get_value('image_proxy')  # pylint: disable=redefined-outer-name
    disabled_engines = request.preferences.engines.get_disabled()
    allowed_plugins = request.preferences.plugins.get_enabled()

    # stats for preferences page
    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))

    engines_by_category = {}

    for c in categories:  # pylint: disable=consider-using-dict-items
        engines_by_category[c] = [e for e in categories[c] if e.name in filtered_engines]
        # sort the engines alphabetically since the order in settings.yml is meaningless.
        list.sort(engines_by_category[c], key=lambda e: e.name)

    # get first element [0], the engine time,
    # and then the second element [1] : the time (the first one is the label)
    stats = {}  # pylint: disable=redefined-outer-name
    max_rate95 = 0
    for _, e in filtered_engines.items():
        h = histogram('engine', e.name, 'time', 'total')
        median = round(h.percentage(50), 1) if h.count > 0 else None
        rate80 = round(h.percentage(80), 1) if h.count > 0 else None
        rate95 = round(h.percentage(95), 1) if h.count > 0 else None

        max_rate95 = max(max_rate95, rate95 or 0)

        result_count_sum = histogram('engine', e.name, 'result', 'count').sum
        successful_count = counter('engine', e.name, 'search', 'count', 'successful')
        result_count = int(result_count_sum / float(successful_count)) if successful_count else 0

        stats[e.name] = {
            'time': median,
            'rate80': rate80,
            'rate95': rate95,
            'warn_timeout': e.timeout > settings['outgoing']['request_timeout'],
            'supports_selected_language': _is_selected_language_supported(e, request.preferences),
            'result_count': result_count,
        }
    # end of stats

    # reliabilities
    reliabilities = {}
    engine_errors = get_engine_errors(filtered_engines)
    checker_results = checker_get_result()
    checker_results = (
        checker_results['engines'] if checker_results['status'] == 'ok' and 'engines' in checker_results else {}
    )
    for _, e in filtered_engines.items():
        checker_result = checker_results.get(e.name, {})
        checker_success = checker_result.get('success', True)
        errors = engine_errors.get(e.name) or []
        if counter('engine', e.name, 'search', 'count', 'sent') == 0:
            # no request
            reliablity = None
        elif checker_success and not errors:
            reliablity = 100
        elif 'simple' in checker_result.get('errors', {}):
            # the basic (simple) test doesn't work: the engine is broken accoding to the checker
            # even if there is no exception
            reliablity = 0
        else:
            # pylint: disable=consider-using-generator
            reliablity = 100 - sum([error['percentage'] for error in errors if not error.get('secondary')])

        reliabilities[e.name] = {
            'reliablity': reliablity,
            'errors': [],
            'checker': checker_results.get(e.name, {}).get('errors', {}).keys(),
        }
        # keep the order of the list checker_results[e.name]['errors'] and deduplicate.
        # the first element has the highest percentage rate.
        reliabilities_errors = []
        for error in errors:
            error_user_text = None
            if error.get('secondary') or 'exception_classname' not in error:
                continue
            error_user_text = exception_classname_to_text.get(error.get('exception_classname'))
            if not error:
                error_user_text = exception_classname_to_text[None]
            if error_user_text not in reliabilities_errors:
                reliabilities_errors.append(error_user_text)
        reliabilities[e.name]['errors'] = reliabilities_errors

    # supports
    supports = {}
    for _, e in filtered_engines.items():
        supports_selected_language = _is_selected_language_supported(e, request.preferences)
        safesearch = e.safesearch
        time_range_support = e.time_range_support
        for checker_test_name in checker_results.get(e.name, {}).get('errors', {}):
            if supports_selected_language and checker_test_name.startswith('lang_'):
                supports_selected_language = '?'
            elif safesearch and checker_test_name == 'safesearch':
                safesearch = '?'
            elif time_range_support and checker_test_name == 'time_range':
                time_range_support = '?'
        supports[e.name] = {
            'supports_selected_language': supports_selected_language,
            'safesearch': safesearch,
            'time_range_support': time_range_support,
        }

    return render(
        # fmt: off
        'preferences.html',
        selected_categories = get_selected_categories(request.preferences, request.form),
        locales = LOCALE_NAMES,
        current_locale = request.preferences.get_value("locale"),
        image_proxy = image_proxy,
        engines_by_category = engines_by_category,
        stats = stats,
        max_rate95 = max_rate95,
        reliabilities = reliabilities,
        supports = supports,
        answerers = [
            {'info': a.self_info(), 'keywords': a.keywords}
            for a in answerers
        ],
        disabled_engines = disabled_engines,
        autocomplete_backends = autocomplete_backends,
        shortcuts = {y: x for x, y in engine_shortcuts.items()},
        themes = themes,
        plugins = plugins,
        doi_resolvers = settings['doi_resolvers'],
        current_doi_resolver = get_doi_resolver(request.preferences),
        allowed_plugins = allowed_plugins,
        preferences_url_params = request.preferences.get_as_url_params(),
        locked_preferences = settings['preferences']['lock'],
        preferences = True
        # fmt: on
    )


def _is_selected_language_supported(engine, preferences: Preferences):  # pylint: disable=redefined-outer-name
    language = preferences.get_value('language')
    if language == 'all':
        return True
    x = match_language(
        language, getattr(engine, 'supported_languages', []), getattr(engine, 'language_aliases', {}), None
    )
    return bool(x)


@app.route('/image_proxy', methods=['GET'])
def image_proxy():
    # pylint: disable=too-many-return-statements, too-many-branches

    url = request.args.get('url')
    if not url:
        return '', 400

    if not is_hmac_of(settings['server']['secret_key'], url.encode(), request.args.get('h', '')):
        return '', 400

    maximum_size = 5 * 1024 * 1024
    forward_resp = False
    resp = None
    try:
        request_headers = {
            'User-Agent': gen_useragent(),
            'Accept': 'image/webp,*/*',
            'Accept-Encoding': 'gzip, deflate',
            'Sec-GPC': '1',
            'DNT': '1',
        }
        set_context_network_name('image_proxy')
        resp, stream = http_stream(method='GET', url=url, headers=request_headers, allow_redirects=True)
        content_length = resp.headers.get('Content-Length')
        if content_length and content_length.isdigit() and int(content_length) > maximum_size:
            return 'Max size', 400

        if resp.status_code != 200:
            logger.debug('image-proxy: wrong response code: %i', resp.status_code)
            if resp.status_code >= 400:
                return '', resp.status_code
            return '', 400

        if not resp.headers.get('Content-Type', '').startswith('image/') and not resp.headers.get(
            'Content-Type', ''
        ).startswith('binary/octet-stream'):
            logger.debug('image-proxy: wrong content-type: %s', resp.headers.get('Content-Type', ''))
            return '', 400

        forward_resp = True
    except httpx.HTTPError:
        logger.exception('HTTP error')
        return '', 400
    finally:
        if resp and not forward_resp:
            # the code is about to return an HTTP 400 error to the browser
            # we make sure to close the response between searxng and the HTTP server
            try:
                resp.close()
            except httpx.HTTPError:
                logger.exception('HTTP error on closing')

    def close_stream():
        nonlocal resp, stream
        try:
            if resp:
                resp.close()
            del resp
            del stream
        except httpx.HTTPError as e:
            logger.debug('Exception while closing response', e)

    try:
        headers = dict_subset(resp.headers, {'Content-Type', 'Content-Encoding', 'Content-Length', 'Length'})
        response = Response(stream, mimetype=resp.headers['Content-Type'], headers=headers, direct_passthrough=True)
        response.call_on_close(close_stream)
        return response
    except httpx.HTTPError:
        close_stream()
        return '', 400


@app.route('/engine_descriptions.json', methods=['GET'])
def engine_descriptions():
    locale = get_locale().split('_')[0]
    result = ENGINE_DESCRIPTIONS['en'].copy()
    if locale != 'en':
        for engine, description in ENGINE_DESCRIPTIONS.get(locale, {}).items():
            result[engine] = description
    for engine, description in result.items():
        if len(description) == 2 and description[1] == 'ref':
            ref_engine, ref_lang = description[0].split(':')
            description = ENGINE_DESCRIPTIONS[ref_lang][ref_engine]
        if isinstance(description, str):
            description = [description, 'wikipedia']
        result[engine] = description

    # overwrite by about:description (from settings)
    for engine_name, engine_mod in engines.items():
        descr = getattr(engine_mod, 'about', {}).get('description', None)
        if descr is not None:
            result[engine_name] = [descr, "SearXNG config"]

    return jsonify(result)


@app.route('/stats', methods=['GET'])
def stats():
    """Render engine statistics page."""
    sort_order = request.args.get('sort', default='name', type=str)
    selected_engine_name = request.args.get('engine', default=None, type=str)

    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))
    if selected_engine_name:
        if selected_engine_name not in filtered_engines:
            selected_engine_name = None
        else:
            filtered_engines = [selected_engine_name]

    checker_results = checker_get_result()
    checker_results = (
        checker_results['engines'] if checker_results['status'] == 'ok' and 'engines' in checker_results else {}
    )

    engine_stats = get_engines_stats(filtered_engines)
    engine_reliabilities = get_reliabilities(filtered_engines, checker_results)

    if sort_order not in STATS_SORT_PARAMETERS:
        sort_order = 'name'

    reverse, key_name, default_value = STATS_SORT_PARAMETERS[sort_order]

    def get_key(engine_stat):
        reliability = engine_reliabilities.get(engine_stat['name'], {}).get('reliablity', 0)
        reliability_order = 0 if reliability else 1
        if key_name == 'reliability':
            key = reliability
            reliability_order = 0
        else:
            key = engine_stat.get(key_name) or default_value
            if reverse:
                reliability_order = 1 - reliability_order
        return (reliability_order, key, engine_stat['name'])

    engine_stats['time'] = sorted(engine_stats['time'], reverse=reverse, key=get_key)
    return render(
        # fmt: off
        'stats.html',
        sort_order = sort_order,
        engine_stats = engine_stats,
        engine_reliabilities = engine_reliabilities,
        selected_engine_name = selected_engine_name,
        searx_git_branch = GIT_BRANCH,
        # fmt: on
    )


@app.route('/stats/errors', methods=['GET'])
def stats_errors():
    filtered_engines = dict(filter(lambda kv: request.preferences.validate_token(kv[1]), engines.items()))
    result = get_engine_errors(filtered_engines)
    return jsonify(result)


@app.route('/stats/checker', methods=['GET'])
def stats_checker():
    result = checker_get_result()
    return jsonify(result)


@app.route('/robots.txt', methods=['GET'])
def robots():
    return Response(
        """User-agent: *
Allow: /info/en/about
Disallow: /stats
Disallow: /image_proxy
Disallow: /preferences
Disallow: /*?*q=*
""",
        mimetype='text/plain',
    )


@app.route('/opensearch.xml', methods=['GET'])
def opensearch():
    method = request.preferences.get_value('method')
    autocomplete = request.preferences.get_value('autocomplete')

    # chrome/chromium only supports HTTP GET....
    if request.headers.get('User-Agent', '').lower().find('webkit') >= 0:
        method = 'GET'

    if method not in ('POST', 'GET'):
        method = 'POST'

    ret = render('opensearch.xml', opensearch_method=method, autocomplete=autocomplete)
    resp = Response(response=ret, status=200, mimetype="application/opensearchdescription+xml")
    return resp


@app.route('/favicon.ico')
def favicon():
    theme = request.preferences.get_value("theme")
    return send_from_directory(
        os.path.join(app.root_path, settings['ui']['static_path'], 'themes', theme, 'img'),  # pyright: ignore
        'favicon.png',
        mimetype='image/vnd.microsoft.icon',
    )


@app.route('/clear_cookies')
def clear_cookies():
    resp = make_response(redirect(url_for('index', _external=True)))
    for cookie_name in request.cookies:
        resp.delete_cookie(cookie_name)
    return resp


@app.route('/config')
def config():
    """Return configuration in JSON format."""
    _engines = []
    for name, engine in engines.items():
        if not request.preferences.validate_token(engine):
            continue

        supported_languages = engine.supported_languages
        if isinstance(engine.supported_languages, dict):
            supported_languages = list(engine.supported_languages.keys())

        _engines.append(
            {
                'name': name,
                'categories': engine.categories,
                'shortcut': engine.shortcut,
                'enabled': not engine.disabled,
                'paging': engine.paging,
                'language_support': engine.language_support,
                'supported_languages': supported_languages,
                'safesearch': engine.safesearch,
                'time_range_support': engine.time_range_support,
                'timeout': engine.timeout,
            }
        )

    _plugins = []
    for _ in plugins:
        _plugins.append({'name': _.name, 'enabled': _.default_on})

    return jsonify(
        {
            'categories': list(categories.keys()),
            'engines': _engines,
            'plugins': _plugins,
            'instance_name': settings['general']['instance_name'],
            'locales': LOCALE_NAMES,
            'default_locale': settings['ui']['default_locale'],
            'autocomplete': settings['search']['autocomplete'],
            'safe_search': settings['search']['safe_search'],
            'default_theme': settings['ui']['default_theme'],
            'version': VERSION_STRING,
            'brand': {
                'PRIVACYPOLICY_URL': get_setting('general.privacypolicy_url'),
                'CONTACT_URL': get_setting('general.contact_url'),
                'GIT_URL': GIT_URL,
                'GIT_BRANCH': GIT_BRANCH,
                'DOCS_URL': get_setting('brand.docs_url'),
            },
            'doi_resolvers': list(settings['doi_resolvers'].keys()),
            'default_doi_resolver': settings['default_doi_resolver'],
        }
    )


@app.errorhandler(404)
def page_not_found(_e):
    return render('404.html'), 404


# see https://flask.palletsprojects.com/en/1.1.x/cli/
# True if "FLASK_APP=searx/webapp.py FLASK_ENV=development flask run"
flask_run_development = (
    os.environ.get("FLASK_APP") is not None and os.environ.get("FLASK_ENV") == 'development' and is_flask_run_cmdline()
)

# True if reload feature is activated of werkzeug, False otherwise (including uwsgi, etc..)
#  __name__ != "__main__" if searx.webapp is imported (make test, make docs, uwsgi...)
# see run() at the end of this file : searx_debug activates the reload feature.
werkzeug_reloader = flask_run_development or (searx_debug and __name__ == "__main__")

# initialize the engines except on the first run of the werkzeug server.
if not werkzeug_reloader or (werkzeug_reloader and os.environ.get("WERKZEUG_RUN_MAIN") == "true"):
    locales_initialize()
    _INFO_PAGES = infopage.InfoPageSet()
    redis_initialize()
    plugin_initialize(app)
    search_initialize(enable_checker=True, check_network=True, enable_metrics=settings['general']['enable_metrics'])


def run():
    logger.debug('starting webserver on %s:%s', settings['server']['bind_address'], settings['server']['port'])
    app.run(
        debug=searx_debug,
        use_debugger=searx_debug,
        port=settings['server']['port'],
        host=settings['server']['bind_address'],
        threaded=True,
        extra_files=[get_default_settings_path()],
    )


application = app
patch_application(app)

if __name__ == "__main__":
    run()
